function validity = checkGUIValid( varargin )

% Name: checkGUIValid.m
% Location: MALT/GUI/checkGUIValid.m
% Purpose:  Checks that all the required inputs are set in the GUI,
%           in order to create a successful session
% Input Parameters:  handles structure of the GUI
% Output Parameters: a validity bit

guiHandles = varargin{1}; % Take the handles of the GUI

validity = 1;
% First check that at least one game has been created
if ( length( guiHandles.agentList ) < 1 )
	% ie. No agent added
	error_gui('Title', 'Incorrect GUI information set', 'Need to add at least one agent in the GUI' );
	validity = 0;
else
	% Next check the game list
	if ( length( guiHandles.gameList ) < 1 )
		error_gui('Title', 'Incorrect GUI information set', 'Need to add at least one game in the GUI' );
		validity = 0;
	else
		% Next check that at least one metric has been selected
		if ( length( guiHandles.metricList ) < 1 )
			error_gui('Title', 'Incorrect GUI information set', 'Need to add at least one metric in the GUI' );
			validity = 0;
		else
			% Check the parameter is correctly set - should only be one element each
			tParamStruct = guiHandles.paramStruct;
			if ( ~isnumeric( tParamStruct.runs ) || ~isnumeric( tParamStruct.totalIterations) || ~isnumeric( tParamStruct.settleIterations ) )
				error_gui('Title', 'Incorrect GUI information set', 'One of the parameter values incorrectly set' );
				validity = 0;
			else
				% Check that a session type has been selected
				if isempty( guiHandles.sessionType )
					error_gui('Title', 'Incorrect GUI information set', 'Need to select a session type' );
					validity = 0;
				end % sessionType checking
			end % Param checking
		end % Metric checking
	end % Game checking
end % Agent checking
