function validity = checkGameValid( varargin )

% Name: checkGameValid.m
% Location: MALT/GUI/checkGameValid.m
% Purpose:  Checks that the current number of actions selected, 
%           is in the valid range of minimum and maximum number of actions for the game
% Input Parameters:  temporary game structure
% Output Parameters: Validity bit specifying whether the number of actions,
%                        is valid for this game or not

currGame = varargin{1};

currentActions = currGame.totalActions(1);

% Get the descriptions of the game
% This includes the minimum and maximum number of actions,
% which we use here
[defString, gameDescrip, funcsDescrip, minGmActions, maxGmActions] = game_default( currGame.name );

validity = 1; % Set the validity bit
if ( ( currentActions < minGmActions ) || ( currentActions > maxGmActions ) )
   msgText = {['Warning: Current action number is outside of valid range [' num2str( minGmActions ) ', ' num2str( maxGmActions ) '] for this game.'] ['Please change number of actions.']};
	error_gui( 'Title', 'Warning', msgText );
	validity = 0; % Set the validity bit back to 0, since game is not valid
end
