function returnCell = createAgentDisplayNames( agentCells )

% Name: createAgentDisplayNames.m
% Location: MALT/GUI/createAgentDisplayNames.m
% Purpose:  Adds display names to the agents - made up of algorithm name and a number
% Input Parameters:  Cell list of agent structures
% Output Parameters: Updated cell list of agent structures, with displaynames set

algorithms = {};

nAgents = length( agentCells );

% This ensures that algorithms are added for identification as:
% 'GIGA-WoLF_1', 'GIGA-WoLF_2', rather than having multiple 'GIGA-WoLF'
% Loop over all the agents 
for cAgent = 1:nAgents
	currAgent = agentCells{cAgent};
	nAlgs = length( algorithms );
	nFound = 0;
	cAlg = 1;
	% Either the algorithm has previously been added or not
	while ( ( cAlg <= nAlgs ) && ( ~nFound ) )
		if isequal( algorithms{cAlg}, currAgent.algorithm )
			nFound = 1;
		else
			cAlg = cAlg + 2; % We add two, to skip over the number
		end
	end
	if ( nFound == 1)
		% Algorithm was found at cAlg
			cValue = algorithms{cAlg + 1};
			currAgent.displayName = [currAgent.algorithm '_' num2str( cValue+1 )];
			algorithms(cAlg + 1) = {cValue + 1};
	else
		% Algorithm title not included previously
		currAgent.displayName = [currAgent.algorithm '_' num2str( 1 )];
		algorithms = {algorithms{1:end} currAgent.algorithm 1 };
	end
	agentCells{cAgent} = currAgent; % Return back to the original cell set
end

returnCell = agentCells;
