function [plot_dataStruct, visualObj] = createAggData( whichAgents, condAgents1, condAgents2, condGames, condRuns, condIterations, condFree, condDepObj, visualObj, condAgg, file_3dList, errorBarStatus )

% Name: createAggData.m
% Location: MALT/GUI/createAggData.m
% Purpose:  Takes all the conditioned data, aggregates the needed data and returns a matrix (2d or 3d depending), with the data that is to be visualised
%
% Input Parameters:  10 Parameters - number indicating agent or row/col conditioning
%                                   First set of agents (either all or row)
%                                   Second set of agents (either all or column)
%                                   Cell list of games
%                                   From and To runs
%                                   From and To iterations
%                                   Cell list of selected free data
%                                   Dependent variable object (metric)
%                                   Visualisation object
%                                   Type of aggregation wanted
%                                   The file list in 3d, mapped 
%                                       as agents x agents x game
%                                   Status of errorbars - on (1) or off (0)
%
% Output Parameters: Array with the values of the data to visualise

nGames = length( condGames );
nAgnt1 = length( condAgents1 );
nAgnt2 = length( condAgents2 );
nRuns = length( [condRuns(1):condRuns(2)] );
nIterations = length( [condIterations(1):condIterations(2)] );
nFree = zeros(1, length( condFree ) );  % Array to store the lengths of each free variable
val4dFree = zeros(1, length( condFree ) ); % Array to give a value/number to the free variables, 
                                           % corresponding to the dimension
                                           % of the 4d matrix
freeNames = cell(1, length( condFree ) );
agntSeen = 0;

nFreeAgents = 0; % Counter to tell whether agents is used 0, 1 or 2 times as a free variable
for freeCount = 1:length( condFree )
	% Loop through all the selected free variables
	% Update counters assigned to the free variables
	switch lower( condFree{ freeCount } )
	case 'agent'
		if ( ~agntSeen ) % First agent we have seen as a free variables
			nFree( freeCount ) = nAgnt1;
         freeNames( freeCount ) = {condAgents1};
			nFreeAgents = 1;
         val4dFree( freeCount ) = 1;
			agntSeen = 1; % We have now seen an agent
		else % We have two agents as free variables
			nFree( freeCount ) = nAgnt2;
         freeNames( freeCount ) = {condAgents2};
 			nFreeAgents = 2;
         val4dFree( freeCount ) = 2;
		end
	case 'row agent'
		nFree( freeCount ) = nAgnt1;
      freeNames( freeCount ) = {condAgents1};
      val4dFree( freeCount ) = 1;
	case 'column agent'
		nFree( freeCount ) = nAgnt2;
      freeNames( freeCount ) = {condAgents2};
      val4dFree( freeCount ) = 2;
	case 'runs'
      tNum1 = condRuns(1);
      tNum2 = condRuns(2);
      nFree( freeCount ) = nRuns;

% July 12 2005 Change made: added the ' transpose in line below
		freeNames( freeCount ) = { cellstr( num2str( [tNum1:tNum2]' ) ) };
		val4dFree( freeCount ) = 4;		

   case 'iterations'
		tNum1 = condIterations(1);
		tNum2 = condIterations(2);
		nFree( freeCount ) = nIterations;

% July 12 2005 Change made: added the ' transpose in line below
      freeNames( freeCount ) = {num2str( [tNum1:tNum2]' ) };

% ??? Why not included: val4dFree( freeCount ) = 5; ??? %
		
	case 'games'
		nFree( freeCount ) = nGames;
      freeNames( freeCount ) = {condGames};
      val4dFree( freeCount ) = 3;
	end
end

if ( length( nFree ) > 1 ) % Check for the number of free variables
	if ( nFree(1) < nFree(2) ) 
	% If the first free variable has less "values" than the second,
	% then swop them around
		% swop the number of values in each selected free variable
		tmpSwop = nFree(1);
		nFree(1) = nFree(2);
		nFree(2) = tmpSwop;
		% Swop the names of the selected free variables
		tmpSwop = condFree{1};
		condFree(1) = {condFree{2}};
		condFree(2) = {tmpSwop};
      % Swop the values as references in the 4d array
      tmpSwop = val4dFree(1);
      val4dFree(1) = val4dFree(2);
      val4dFree(2) = tmpSwop;
		% Swop the free variable names
		tmpSwop = freeNames{1};
		freeNames{1} = freeNames{2};
		freeNames{2} = tmpSwop;
	end
end

% Get the format of the data storage unit
[plot_data visualObj] = plot_data_format( visualObj, nFree, freeNames, condFree, condAgg, errorBarStatus, {nAgnt1, nAgnt2, nGames, nRuns}, condDepObj );

% Variables for counting the position of the free variables
if ( length( nFree ) == 1 )
    % Only using a single free variable. To make life easier, 
    % we can still assume we are storing in a 1xnDims array
    % thus set the value/position of the "second selected" 
    % free variable to be 1
    freeWhere = zeros(1, 2 );
    freeWhere(1, 2) = 1;
else
    freeWhere = zeros(1, length( nFree ) );
end

for cAgnt1 = 1:nAgnt1
	% Set the freeWhere counter, if needed
	if ( whichAgents )
		% Using the agents, not row and column agents
		if ( nFreeAgents == 1 )
			whereAgnt = find( strcmp( 'agent', lower( condFree ) ) );
			freeWhere( whereAgnt ) = cAgnt1;
		elseif ( nFreeAgents == 2 )
			freeWhere( 1 ) = cAgnt1;
		end
	else
		% Using the row or column agents
		whereAgnt = find( strcmp( 'row agent', lower( condFree ) ) );
      if ~isempty( whereAgnt )
	      % ie. only if 'row agent' is found as one of the free
         % variables, should we update the variable counter
         freeWhere( whereAgnt ) = cAgnt1;
      end
	end

	for cAgnt2 = 1:nAgnt2
		% Set the freeWhere counter, if needed
		if ( whichAgents )
			% Using the agents, not row and column agents
			if ( nFreeAgents == 2 )
				freeWhere( 2 ) = cAgnt2;
			end
		else
			% Using the row or column agents
			whereAgnt = find( strcmp( 'column agent', lower( condFree ) ) );
         if ~isempty( whereAgnt )
            %ie. only if 'column agent' is found as one of the free
            %variables, should we update the variable counter
            freeWhere( whereAgnt ) = cAgnt2;
         end
		end

		for cGame = 1:nGames
			possFind = find( strcmp( 'Games', condFree ) );
			if ~isempty( possFind )
				freeWhere( possFind ) = cGame;
			end
			% fNameDetails contains the details of the file
			% fNameDetails(2) is the file name and
			% fNameDetails(1) is the id number for cAgnt1, in this file
			fNameDetailsStruct = file_3dList{ cAgnt1, cAgnt2, cGame };
			fName = fNameDetailsStruct.fileName; % Name of the file to load
         whichOrder = fNameDetailsStruct.order; % Order that agents were saved
			load( fName );	% Load the file

			for cRun = condRuns(1):condRuns(2)
				possFind = find( strcmp( 'Runs', condFree ) );
				if ~isempty( possFind )
					freeWhere( possFind ) = cRun;
				end

				if ( whichAgents )
					% ie. in the agent part of things
					% Get the data from the statistics file for run 'cRun, flip '1'
					% and the data generated by metric get( condDepObj, 'name' )
                    % need to get position 'fNameDetails{1}' from the metStat
               metStat = get_from_statistics( statsObj, get( condDepObj, 'name' ), 1, cRun );

					% July 11: Changes made below. Added the condRuns parameter
               [plot_data, visualObj] = agg_visual( visualObj, plot_data, condAgg, freeWhere, condFree, val4dFree, metStat, whichOrder, {cAgnt1, cAgnt2, cGame, cRun}, errorBarStatus, condIterations, condRuns );

               metStat = get_from_statistics( statsObj, get( condDepObj, 'name' ), 2, cRun ); % Get the data for flip '2'
               [plot_data, visualObj] = agg_visual( visualObj, plot_data, condAgg, freeWhere, condFree, val4dFree, metStat, whichOrder, {cAgnt1, cAgnt2, cGame, cRun}, errorBarStatus, condIterations, condRuns );
				else
					% it is the row and column agent case
					% We only want to load one of the 'flip' statistic
               % This is the flip given by fNameDetails{1}
               % We also only want to load the data for our agent and
               % this position is also given by fNameDetails{1}
               metStat = get_from_statistics( statsObj, get( condDepObj, 'name' ), whichOrder, cRun );
               [plot_data, visualObj] = agg_visual( visualObj, plot_data, condAgg, freeWhere, condFree, val4dFree, metStat, whichOrder, {cAgnt1, cAgnt2, cGame, cRun}, errorBarStatus, condIterations, condRuns );
				end % if ( whichAgents )
			end % for: cRun
		end % for: cGame
	end % for: cAgnt2
end % for: cAgnt1

% Setup a quick structure to give numbers to the fields of a 4d array

[plot_dataStruct visualObj] = agg_visual_final( visualObj, plot_data, condAgg, condFree, freeNames, nFree, val4dFree, errorBarStatus, {nAgnt1 nAgnt2 nGames nRuns nIterations}, whichAgents );
