function returnCell = createGameFileNames( gameCells )

% Name: createGameFileNames.m
% Location: MALT/GUI/createGameFileNames.m
% Purpose:  Adds file names to the games 
%           - game name and the number of the generator, if repeated
% Input Parameters:  Cell list of game structures
% Output Parameters: Updated cell list of game structures, with filenames set

generators = {};

nGames = length( gameCells );

% This ensures that if we have more than one game of Chicken,
% then the games are labeled as 'Chicken_1', 'Chicken_2', 'Chicken_3'

% Loop over all the games 
for cGame = 1:nGames
	currGame = gameCells{cGame};
	nGens = length( generators );
	nFound = 0;
	cGen = 1;
	% Either the generator has previously been added or not
	while ( ( cGen <= nGens ) && ( ~nFound ) )
		if isequal( generators{cGen}, currGame.name )
			nFound = 1;
		else
			cGen = cGen + 2; % We add two, to skip over the number
		end
	end
	if ( nFound == 1)
		% Generator was found at cGen
			cValue = generators{cGen + 1};
			currGame.fileName = [currGame.name '_' num2str( cValue+1 )];
			generators(cGen + 1) = {cValue + 1};
	else
		% Generator title not included previously
		currGame.fileName = [currGame.name '_' num2str( 1 )];
		generators = {generators{1:end} currGame.name 1 };
	end
	gameCells{cGame} = currGame; % Return back to the original cell set
end

returnCell = gameCells;
