function [metricsObjCell, whatToSave] = createMetricsObjs( varargin )

% Name: createMetricsObjs.m
% Location: MALT/GUI/createMetricObjs.m
% Purpose:  Creates cell list of metric objects from the details of the GUI
%           Also creates a list of what types of items/values need to be
%           saved
% Input Parameters:  handles structure of the GUI
% Output Parameters: Cell list of metric objects and a list of what items
%                    to save (a unique list)

guiHandles = varargin{1}; % Take the handles of the GUI

whatToSave = {};
metricsObjCell = {};

% Get the list of metrics
allMetrics = guiHandles.metricList;
for cMetric = 1:length(allMetrics)
    currMetric = allMetrics{cMetric}; % Gives us the metric structure
    funcHandle = str2func( currMetric.functionHandle ); % Create a function handle
    metObj = feval( funcHandle, currMetric.frequency );
    metricsObjCell = {metricsObjCell{1:end} metObj};
	 neededDataList = metObj.needed_data;
	 % Update the list of what data items/features need to be saved
	 % This may cause the list to have repetitions
	 for needD = 1:length(neededDataList)
	 	whatToSave = {whatToSave{1:end} neededDataList{needD}};
	 end
end

% Make the list of what data items we want to save, unique
% Uses a builtin matlab command - 'unique', which also sorts them alphabetically,
% Though the alphabetical sorting does not matter to us
whatToSave = unique( whatToSave );
