function paramObj = createParamObj( varargin )

% Name: createParamObj.m
% Location: MALT/GUI/createParamObj.m
% Purpose:  Creates a parameter object from the details selected in the GUI
% Input Parameters:  handles structure of the GUI
% Output Parameters: a parameter object

guiHandles = varargin{1}; % Take the handles of the GUI

% Obtain a list of the gamut commands
allGames = guiHandles.gameList;
listGamutCommands = {};
for cGame = 1:length( allGames )
	currGame = allGames{cGame}; % Pick the game structure
	listGamutCommands = {listGamutCommands{1:end} [currGame.name ' : ' currGame.gamutCommand]};
end

% Obtain the list of agent algorithms
allAgents = guiHandles.agentList;
listAlgorithms = {};
for cAgent = 1:length( allAgents )
	currAgent = allAgents{cAgent}; % Pick the agent structure
	cAgentFields = [];
	allFields = fieldnames( currAgent );
	% Create a string containing the field names and their values for this agent, for later display
	for fieldName = 1:length( allFields )
        fieldValue = getfield( currAgent, allFields{fieldName} );
        if isnumeric( fieldValue )
            cAgentFields = [cAgentFields ' ' allFields{fieldName} ': ' num2str( fieldValue ) ' . '];
        else
            cAgentFields = [cAgentFields ' ' allFields{fieldName} ': ' fieldValue ' . '];
        end
	end
	listAlgorithms = {listAlgorithms{1:end} cAgentFields};
end

% Obtain a list of the metric names
allMetrics = guiHandles.metricList;
listMetrics = {};
for cMetric = 1:length( allMetrics )
	currMetric = allMetrics{cMetric};
	listMetrics = {listMetrics{1:end} currMetric.name};
end

tParam = guiHandles.paramStruct;

% Instantiate a parameter object
paramObj = parameter( listGamutCommands, listAlgorithms, tParam.settleIterations, tParam.totalIterations, tParam.runs, guiHandles.sessionType, listMetrics );
