function file_3dList = get_3dFilelist( whichAgents, allAgents, condAgents1, condAgents2, condGames )

% Name: get_3dFilelist.m
% Location: MALT/GUI/get_3dFilelist.m
% Purpose:  Takes the list of agents and games
%             and puts them into a 3d cell array,
%             with the value of each cell being the 
%             filename and the idnumber for the row agent
%           Potentially the filelist of the SessionObject
%             will be changed to this
% Input Parameters:  5 Parameters - number indicating agent or row/col conditioning
%                                   Cell list of all the original agents
%                                   First set of agents (either all or row)
%                                   Second set of agents (either all or column)
%                                   Cell list of games
%
% Output Parameters: 3d cell array of agent x agent x game, containing the file name for that combination

% Get number of games, number of agents selected
nGames = length( condGames );
nAgnt1 = length( condAgents1 );
nAgnt2 = length( condAgents2 );
whereFind1 = zeros(1, nAgnt1 );
whereFind2 = zeros(2, nAgnt2 );
file_3dList = cell( nAgnt1, nAgnt2, nGames ); % Precreate empty cell array

for agnt1 = 1:nAgnt1 % Loop over agents or row agents
	whereFind1( agnt1 ) = find( strcmp( allAgents, condAgents1{agnt1} ) );
	
	for agnt2 = 1:nAgnt2 % Loop over agents or column agents
		whereFind2( agnt2 ) = find( strcmp( allAgents, condAgents2{agnt2} ) );
		for gm = 1:nGames
			if ( whereFind1( agnt1 ) > whereFind2( agnt2 ) )
				% agnt1 comes after agnt2 in the original list
				% filename of form agent2.name_agent1.name ...
				actGame = condGames{gm};
				gName = actGame(1:end-2);
				fName =  create_file_name( condAgents2{agnt2}, condAgents1{agnt1}, gName, 'data' );
				fName = [fName(1:end-8) 'stats.mat'];

				file_3dList( agnt1, agnt2, gm ) = { struct( 'order', 2, 'fileName', fName ) };
			else
				% agnt1 comes before agnt2 in the original agent list
				% filename of form agent1.name_agent2.name ...
				actGame = condGames{gm};
				gName = actGame(1:end-2);
				fName =  create_file_name( condAgents1{agnt1}, condAgents2{agnt2}, gName, 'data' );
				fName = [fName(1:end-8) 'stats.mat'];
				file_3dList( agnt1, agnt2, gm ) = { struct( 'order', 1, 'fileName', fName ) };
			end
		end
	end
end
