function whatReturned = get_lists( whatToGet )

% Name: get_lists.m
% Location: MALT/GUI/get_lists.m
% Purpose:  Essentially a lookup function for cell lists of information
%           that are used in various places in GUIs
%           This is being used instead of manually inputting 
%           the cell lists into Matlab's Guide program.
%           Thus people can edit this file, instead of having to use Guide
% Input Parameters:  String name of the information requested
% Output Parameters: Cell list corresponding to the string name requested

switch( lower( whatToGet ) )
case 'visualisations'
	% This actually returns a cell list containing the different visualisation objects
	whatReturned = {bar_visual boxplot_visual plot_visual scatter_visual}; % plot_matrix_visual
% currently not available: boxplot, heat, scatter3_visual
case 'free variables'
	whatReturned = {'Agent' 'Row agent' 'Column agent' 'Games' 'Iterations' 'Runs'};

% The next three cases are for combining the colour, type of mark and the line style for use in any plots. This is to ensure we automatically plot with different colours and linestyles to make it easier to view graphs
case 'colourlineup-line-type'
	type = {'.' 'o' 'x' '+' '*' 's' 'd' '^' '<' '>' 'p' 'h'};
	ln = {'-' ':' '-.' '--'};
	col = {'b' 'g' 'r' 'c' 'm' 'k'};
	emptyAll = {};
	for c = 1:length( col )
		for l = 1:length( ln )
			for t = 1:length( type )
				emptyAll = {emptyAll{1:end} [col{c} type{t} ln{l}]};
			end
		end
	end
	
	whatReturned = emptyAll;

case 'colourlineup-line-col'
	type = {'.' '+' 'x' '^' '*' 's' 'd' 'o' '<' '>' 'p' 'h'};
	ln = {'-' ':' '-.' '--'};
	col = {'b' 'g' 'r' 'c' 'm' 'k'};

	emptyAll = {};
	for b=0:length(type)-1
		for l=1:length(type)
			emptyAll={emptyAll{1:end} [col{1+mod(l+b-1,length(col))} type{l} ln{1+mod(l+b-1,length(ln))} ]};
		end
	end

	whatReturned = emptyAll;
	
case 'colourlineup-line-line'
	type = {'.' 'o' 'x' '+' '*' 's' 'd' '^' '<' '>' 'p' 'h'};
	ln = {'-' ':' '-.' '--'};
	col = {'b' 'g' 'r' 'c' 'm' 'k'};
	emptyAll = {};
	for t = 1:length( type )
		for c = 1:length( col )
			for l = 1:length( ln )
				emptyAll = {emptyAll{1:end} [col{c} type{t} ln{l}]};
			end
		end
	end
	
	whatReturned = emptyAll;

case 'colourlineup'
	type = {'.' 'o' 'x' '+' '*' 's' 'd' '^' '<' '>' 'p' 'h'};
	col = {'b' 'g' 'r' 'c' 'm' 'k'};
	emptyAll = {};
	for b=0:length(col)-1
		for c=1:length(col)
			emptyAll={emptyAll{1:end} [col{c} type{  1+mod( c+b-1,length(type) ) }]};
		end
	end	
	whatReturned = emptyAll;

otherwise
	printOut( ['Error: GUI\get_lists.m: No string name matching ' whatToGet ' found'] );
end
