function [metricsAvailable, metricFuncHandles] = metric_selection( measurementType )

% Name: metric_selection.m
% Location: MALT/GUI/metric_selection.m
% Purpose:  Provide a list of metrics available for a specific `type of measurement'
% Input Parameters:	Selected measurement type
% Output Parameters: List of metrics available for that `type of measurement'
%                    cell list of the implemented names of those metrics, to be used as function handles

switch lower( measurementType )
case 'best response'
	metricsAvailable = {'K-competitiveness', 'Sum of incentives to deviate'};
	metricFuncHandles = {'k_competitiveness_metric', 'deviation_incentive_metric'};
case 'nash equilibrium'
	metricsAvailable = {'L1-Norm convergence sum' 'L2-Norm convergence'};
	metricFuncHandles = {'nash_l1_metric' 'nash_l2_metric'};
case 'rewards obtained'
	metricsAvailable = {'Expected value' 'Number of wins' 'Regret' 'Reward obtained' 'Reward vs guaranteed payoff' };
	metricFuncHandles = { 'expected_value_metric', 'wins_metric', 'regret_metric', 'reward_metric', 'actual_vs_guaranteed_metric' };
case 'strategy tracking'
	metricsAvailable = { '1-norm' '2-norm' 'infinity-norm' 'Action causing infinity-norm' };
	metricFuncHandles = { 'track_l1_metric' 'track_l2_metric' 'track_linf_metric' 'track_linf_action_metric' };
end
