function agnt = agent( varargin )

% Name: agent.m
% Location: MALT/agentClasses/@agent/agent.m
% Purpose:  Constructor for the base agent class
%           Class is not instanced directly, but used by child objects
% Input Parameters:  no Parameters - defaults used
%                    1 Parameter - object to copy or name of algorithm
%                    3 Parameter - name of algorithm
%                                  agent number
%                                  total number of actions for both agents
%                    5 Parameter - name of algorithm
%                                  agent number
%                                  total number of actions for both agents
%                                  type of belief wanted
%                                  display name for the agent
% Output Parameters: Created object

switch nargin
case 0 % Create default object
	agnt.date = date;
	agnt.algorithm = 'base_agent';
	% This may be a bit of a hack, but...
	% We use two agent numbers, idNumber and number.
	% 'idNumber' is set when the agent is instantiated and
	% is not changed, regardless of which flip (whether agent is a row or column player) 
	% is being run. This is used to identify the agent's value in a reward matrix,
	% since they are stored according to original numbers, rather than the flipped numbers.
	%
	% 'number' is used to identify during the various flips. This is done to ensure the correct
	% values and payoff matrices are taken during the running of the codes.
	%
	% These differences are particularly important for the giga_wolf and q_agent agents,
	% which use the 'idNumber' to access the reward structure each iteration, 
	% but use the 'number' to access their payoff matrices.
	agnt.idNumber = 1;
	agnt.number = 1;
	totalActions = [2 2];
	agnt.actions = totalActions( agnt.number );
	agnt.strategy = create_beliefs( totalActions );
	agnt.displayName = '';
	agnt = class( agnt, 'agent' );
case 1 % Copy object or set name of object
	if ( isa(varargin{1}, 'agent') )
		agnt = varargin{1};
	elseif ( isa(varargin{1}, 'char') )
			agnt.date = date;
			agnt.algorithm = varargin{1};
			agnt.idNumber = 1;
			agnt.number = 1;
			totalActions = [2 2];
			agnt.actions = totalActions( agnt.number );
			agnt.strategy = create_beliefs( totalActions );
			agnt.displayName = '';
			agnt = class( agnt, 'agent' );
		else
			error('agent.m: Wrong argument type');
	end
case 3 % Setup all parameters except for beliefs
	agnt.date = date;
	agnt.algorithm = varargin{1};
	agnt.idNumber = 1; 
	agnt.number = varargin{2};
	totalActions = varargin{3};
	agnt.actions = totalActions( agnt.number );
	agnt.strategy = create_beliefs( totalActions );
	agnt.displayName = '';
	agnt = class( agnt, 'agent' );
case 5 % Setup all parameters including beliefs and display name
	agnt.date = date;
	agnt.algorithm = varargin{1};
	agnt.number = varargin{2};
	agnt.idNumber = 1;
	totalActions = varargin{3};
	agnt.actions = totalActions( agnt.number );
	agnt.strategy = create_beliefs( totalActions, varargin{4} );
	agnt.displayName = varargin{5};
	agnt = class( agnt, 'agent' );
otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or name of algorithm\n3 Parameter - name of algorithm, agent number, total number of actions for both agents\n4 Parameter - name of algorithm, agent number, total number of actions for both agents, type of belief wanted, display name for the agent' );

	printOut( error_disp );
	error( 'agent.m: Wrong number of input arguments' );
end
