function determined_agnt_ret = updatestrategy( varargin )

% Name: updatestrategy.m
% Location: MALT/agentClasses/@determined_agent/updatestrategy.m
% Purpose: Updates determined agent's strategy
% Input Parameters:  determined_agent object
%                    number of game being played
%                    current iteration
% Output Parameters: determined_agent object with updated strategy

% Obtain the highest payoff equilibrium strategy if it is the first iteration
% otherwise assume we already have it and play off of it

determined_agnt = varargin{1}; % Obtain the determined agent object
nGame = varargin{2}; % Get the number of the game being played
iteration = varargin{3}; % Take the number of the iteration being played

% If this is the first iteration, then we need to set the equilibrium
% strategy as the strategy for the determined agent

if (iteration == 1)
	agntStrat = get( determined_agnt, 'strategy' );
	agntNumb = get( determined_agnt, 'number' );

	% Obtain the highest equilibrium
	high_eqm = return_highest_equilibrium( nGame, agntNumb );
	% Check if the game was updated and returned in the output structure

	agntStrat( agntNumb, : ) = high_eqm;
	
	% Update determined agent object
	determined_agnt = set( determined_agnt, 'strategy', agntStrat );
	% Set the output variable to be the agent object
	determined_agnt_ret = determined_agnt;

else
	% Past the first iteration, strategy has already been set
	% Output the updated agent object
	determined_agnt_ret = determined_agnt;
end
