function fict_agnt = fictitious_agent( varargin )

% Name: fictitious_agent.m
% Location: MALT/agentClasses/@fictitious_agent/fictitious_agent.m
% Purpose:      Constructor for the fictitious agent class
% Input Parameters: no Parameters - defaults used
%                   1 Parameter - object to copy || agent structure
% Output Parameters: created fictitious agent object

switch nargin
case 0 % Create default gradient agent
	fict_agnt.count = zeros(2, 2); % Assumes a single opponent, with two actions
	% Fictitious agent inherits from the base 'agent' class
	agnt = agent( 'fictitious_agent' );
	fict_agnt = class( fict_agnt, 'fictitious_agent', agnt );

case 1 % Copy object
	if ( isa(varargin{1}, 'fictitious_agent') )
		gradient_agnt = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		agntStruct = varargin{1};
		% Create the counts - want to track itself as well, ie, numAgents X actions size
		fict_agnt.count = zeros( length( agntStruct.actions ), max( agntStruct.actions ) );
		
		% Agent structure instantiation for inheritance
		agnt = agent( agntStruct.algorithm, agntStruct.number, agntStruct.actions, agntStruct.strategy, agntStruct.displayName );
		
		fict_agnt = class( fict_agnt, 'fictitious_agent', agnt );
	
	else
		error('fictitious_agent.m: Input argument is not a fictitious_agent object');
	end
otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or agent structure' ); 
	printOut( error_disp );
	error( 'fictitious_agent.m: Wrong number of input arguments' );
end
