function actionTaken = selectaction( fict_agnt, varargin )

% Name: selectaction.m
% Location: MALT/agentClasses/@fictitious_agent/selectaction.m
% Purpose: 	Selects the action that is the best response to the estimate of the opponent's strategy
% Input Parameters:  fictitious_agent object 
%                    Number of the game being played
% Output Parameters: action taken by the fictitious_agent this round

% Make sure the global object is available
global SessionObject;

nGame = varargin{1}; % Take the number of the game being played

% Get the value of the parameters from the fictitious agen object
allStrats = get( fict_agnt, 'strategy' );
nActions = get( fict_agnt, 'actions' );
agNumb = get( fict_agnt, 'number' );
tAllStrats = allStrats;

% Create a pure strategy matrix of number of actions x number of actions
% Each row has a 1 in the element equal to the row number and
% has 0s everywhere else
pureStrat = eye( nActions );
valLst = zeros( 1, nActions );

% Loop over all actions
for cAct = 1:nActions
	% Make the agent's strategy be a pure strategy on that action
	tAllStrats( agNumb, : ) = pureStrat( cAct, : );
	% Get the expected value of the game for that agent,
	% using the current estimate for the opponent's strategy
	valLst(1, cAct) = value( nGame, tAllStrats, agNumb );
end

% Find the action that obtains the highest payoff
maxActions = ( valLst == max(valLst) );
maxActions = maxActions/sum( maxActions );
actionTaken = draw_sample( maxActions );
