function fict_agnt_da = fictitious_agent_da( varargin )

% Name: fictitious_agent_da.m
% Location: MALT/agentClasses/@fictitious_agent_da/fictitious_agent_da.m
% Purpose:      Constructor for the fictitious agent discounted average class
%               Inherits from fictitious play agent,
%               but now uses the discounted averaging to estimate opponent's strategies
% Input Parameters: no Parameters - defaults used
%                   1 Parameter - object to copy || agent structure
% Output Parameters: created fictitious agent object

switch nargin
case 0 % Create default gradient agent
	fict_agnt_da.beliefUpdateRate = 0.9;
	fict_agnt_da.beliefDecayRate = 0.999911;
	fict_agnt = fictitious_agent;
	fict_agnt.algorithm = 'fictitious_agent_da';
	fict_agnt_da = class( fict_agnt_da, 'fictitious_agent_da', fict_agnt );

case 1 % Copy object
	if ( isa(varargin{1}, 'fictitious_agent_da') )
		gradient_agnt = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		agntStruct = varargin{1};

		% Setup the belief rates
		fict_agnt_da.beliefUpdateRate = agntStruct.beliefUpdateRate;
		fict_agnt_da.beliefDecayRate = agntStruct.beliefDecayRate;
		% Create fictitious play agent & update algorithm name
		fict_agnt = fictitious_agent( agntStruct );
		fict_agnt = set( fict_agnt, 'algorithm', 'fictitious_agent_da' );
		% Set class details
		fict_agnt_da = class( fict_agnt_da, 'fictitious_agent_da', fict_agnt );
		
	else
		error('fictitious_agent_da.m: Input argument is not a fictitious_agent_da object');
	end

otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or agent structure' ); 
	printOut( error_disp );
	error( 'fictitious_agent_da.m: Wrong number of input arguments' );
end
