function fict_agnt_da = updatebeliefs( fict_agnt_da, actionsTaken )

% Name: updatebeliefs.m
% Location: MALT/agentClasses/@fictitious_agent_da/updatebeliefs.m
% Purpose: Updates the fictitious agent da's beliefs about its opponents
%          This uses the discounted averaging method, 
%          NOT the undiscounted averaging method that is usually used
% Input Parameters:	fictitious_agent_da object
%							actiont taken vector
% Output Parameters: Updated fictitious_agent_da object

agntNumb = get( fict_agnt_da, 'number' );
agntID = get( fict_agnt_da, 'idNumber' );
agntCount = get( fict_agnt_da, 'count' );
agntStrat = get( fict_agnt_da, 'strategy' );

if ( agntID == 1 )
	oppID = 2;
else
	oppID = 1;
end

for agnts = 1:length( actionsTaken )
	if (agnts ~= agntNumb ) % ie. we do not want to update the agent's beliefs about itself
		currBeliefs = agntStrat( agnts, : ); % This takes the belief distribution for a SINGLE agent,
		                                    % hence we only need to look at currBeliefs(1, action)
		currBeliefs( 1, actionsTaken( oppID, 1 ) ) = ( 1 - fict_agnt_da.beliefUpdateRate )*currBeliefs( 1, actionsTaken( oppID, 1 ) ) + fict_agnt_da.beliefUpdateRate;

		currBeliefs = currBeliefs / sum( currBeliefs );
		agntStrat( agnts, : ) = currBeliefs;
	end
end

fict_agnt_da = set( fict_agnt_da, 'strategy', agntStrat );

% Decay the belief update rate
blfRate = get( fict_agnt_da, 'beliefUpdateRate' );
blfDecy = get( fict_agnt_da, 'beliefDecayRate' );
fict_agnt_da = set( fict_agnt_da, 'beliefUpdateRate', blfRate * blfDecy );
