function giga_wolf = giga_wolf_agent( varargin )

% Name: giga_wolf_agent.m
% Location: MALT/agentClasses/@giga_wolf_agent/giga_wolf_agent.m
% Purpose:  Constructor for the GIGA-WoLF class
%           M. Bowling 'Convergence and No-Regret in Multiagent Learning'
%           NIPS 2004
%
% Input Parameters: no Parameters - defaults used
%                   1 Parameter - object to copy || agent structure
%                   7 Parameters - Name of algorithm, agent number, total number of actions for all agents, initial action distribution for itself and the other agents, step size, belief update rate, belief decay rate
% Output Parameters: created giga_wolf_agent

global SessionObject

switch nargin
case 0 % Create default GIGA-WoLF agent
	giga_wolf.z = create_beliefs( [2 2] ); % just default this to two actions per agent; 
	% note: bigA is not a parameter defined in the paper, but is rather introduced in order
	% to obtain a good stepsize
	giga_wolf.bigA = 0.05 * 100000;
	
	% GIGA-WoLF inherits from the gradient_agent class
	gradient_agnt = gradient_agent;
	gradient_agnt.algorithm = 'giga_wolf_agent';
	giga_wolf = class( giga_wolf, 'giga_wolf_agent', gradient_agnt );

case 1 % Copy object or create object from agent structure
	if ( isa( varargin{1}, 'giga_wolf_agent' ) )
		giga_wolf = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		agntStruct = varargin{1};
		% Agent structure instantiation

		% Get the parameter from the session and obtain the total number of iterations
		tParam = get( SessionObject, 'parameter' );
		tIterations = get( tParam, 'totalIterations' );

		giga_wolf.bigA = 0.05 * tIterations; % We set bigA to 5% of the total iterations

		gradient_agnt = gradient_agent( agntStruct );
		% Create the 'z' parameter, initially making it equal to the created strategy
		tStrat = get( gradient_agnt, 'strategy' );
		giga_wolf.z = tStrat( get( gradient_agnt, 'number' ), : );
		gradient_agnt = set( gradient_agnt, 'algorithm', 'giga_wolf_agent' );

		% We do not need to 'reset' the step size, since this is done each iteration,
		% in the updatestrategy method

		giga_wolf = class( giga_wolf, 'giga_wolf_agent', gradient_agnt );
	else
		error( 'giga_wolf_agent.m: Input argument is not a giga_wolf_agent object or an agent structure' );
	end

otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or agent structure' );
	printOut( error_disp );
	error( 'giga_wolf_agent.m: Wrong number of input arguments' );
end
