function gradient_agnt = gradient_agent( varargin )

% Name: gradient_agent.m
% Location: MALT/agentClasses/@gradient_agent/gradient_agent.m
% Purpose:      Constructor for the gradient agent class
%    	        	 Class is equivalent to the IGA algorithm given in:
%					 S. Singh, M. Kearns and Y. Mansour. 'Nash Convergence of Gradient
% 					 Dynamics in General-Sum Games', UAI 2000
% Input Parameters: no Parameters - defaults used
%	                 1 Parameter - object to copy || agent structure
% Output Parameters: created gradient agent object

switch nargin
case 0 % Create default gradient agent
	gradient_agnt.stepSize = 0.2;
	gradient_agnt.beliefUpdateRate = 0.9;
	gradient_agnt.beliefDecayRate = 0.999911;

	% Gradient agent inherits from the default 'agent' class
	agnt = agent( 'gradient_agent' );
	gradient_agnt = class( gradient_agnt, 'gradient_agent', agnt );

case 1 % Copy object
	if ( isa(varargin{1}, 'gradient_agent') )
		gradient_agnt = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		agntStruct = varargin{1};
		% Structure instantiation
		gradient_agnt.stepSize = agntStruct.stepSize;
		gradient_agnt.beliefUpdateRate = agntStruct.beliefUpdateRate;
		gradient_agnt.beliefDecayRate = agntStruct.beliefDecayRate;
		agnt = agent( agntStruct.algorithm, agntStruct.number, agntStruct.actions, agntStruct.strategy, agntStruct.displayName );
		agnt = set( agnt, 'algorithm', 'gradient_agent' );
		gradient_agnt = class( gradient_agnt, 'gradient_agent', agnt );

	elseif ( isa( varargin{1}, 'char' ) )
	   gradient_agnt.stepSize = 0.2;
	   gradient_agnt.beliefUpdateRate = 0.9;
	   gradient_agnt.beliefDecayRate = 0.999911;
	   agnt = agent( varargin{1} );
	   gradient_agnt = class( gradient_agnt, 'gradient_agent', agnt );
	else
		error( 'gradient_agent.m: Input argument is not a gradient_agent object' );
	end

otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or agent structure' );
	printOut( error_disp );
	error( 'gradient_agent.m: Wrong number of input arguments' );
end
