function gradient = ufd_approx( gradient_agnt, nGame, iteration )

% Name: ufd_approx.m
% Location: MALT/agentClasses/gradient_agent/ufd_approx.m
% Purpose: Compute a forward difference approximation of the gradient
% 			  This method allows the thetaPlus step to go outside of 
%			  the valid probability space
% Input Parameters: gradient_agent object (or from some sub class)
%						  number of game being played (used to obtain value of a strategy)
%						  current iteration

% Get the strategy of the agent and the agent number
thetaAll = get( gradient_agnt, 'strategy' );
theta = returnstrategy( gradient_agnt );
agntNumb = get( gradient_agnt, 'number' );

nActions = get( gradient_agnt, 'actions' );

% Take the correct parameters
c = 0.2145;
gamma = 0.101;
ck = c/(iteration + 1)^gamma;

gradient = zeros(1, nActions);
yplus = zeros(1, nActions);
y = zeros(1, nActions);

% Each parameter gets its own gradient update,
% with all other parameters staying the same
for act = 1:nActions
	esp = zeros(1, nActions);
	esp(1, act) = 1;

	thetaAllPlus = thetaAll;
	thetaAllPlus( agntNumb, : ) = theta + esp*ck;

	% Values of the strategies (value of the function call)
	yplus(1, act) = value( nGame, thetaAllPlus, agntNumb );
   y(1, act) = value( nGame, thetaAll, agntNumb );
	% Forward difference call to determine gradient
	% in the direction of the action
	gradient(1, act) = ( yplus(1, act) - y(1, act) )/(ck);
end
