function gradient_agnt = updatebeliefs( gradient_agnt, actionsTaken )

% Name: updatebeliefs.m
% Location: MALT/agentClasses/@gradient_agent/updatebeliefs.m
% Purpose: Updates gradient agent's beliefs about the strategy that the opponent is playing
% Input Parameters: 	gradient_agent object
%							list of actions taken
% Output Parameters: gradient_agent object with updated beliefs

% Take the agent's number, ID and strategy from the object
agntNumb = get( gradient_agnt, 'number' );
agntStrat = get( gradient_agnt, 'strategy' );
agntID = get( gradient_agnt, 'idNumber' );

% Determine what the opponent's ID number is for referencing the actionsTaken
if ( agntID == 1 )
	oppID = 2;
else
	oppID = 1;
end

for agnts = 1:length( actionsTaken )
	if ( agnts ~= agntNumb ) % We don't want to update the agent's strategy
		currBeliefs = agntStrat( agnts, : ); % This takes the belief distribution for a SINGLE agent,
		                                     % hence we only need to look at currBeliefs(1, action)
		currBeliefs( 1, actionsTaken( oppID, 1 ) ) = ( 1 - gradient_agnt.beliefUpdateRate )*currBeliefs( 1, actionsTaken( oppID, 1 ) ) + gradient_agnt.beliefUpdateRate; % Update the beliefs - stochastic approximation technique 

		currBeliefs = currBeliefs / sum( currBeliefs );
		agntStrat( agnts, : ) = currBeliefs; % Save the new strategy
	end
end

% Set the strategy
gradient_agnt = set( gradient_agnt, 'strategy', agntStrat );

% Decay the belief update rate
blfRate = get( gradient_agnt, 'beliefUpdateRate' );
blfDecy = get( gradient_agnt, 'beliefDecayRate' );
gradient_agnt = set( gradient_agnt, 'beliefUpdateRate', blfRate * blfDecy );
