function gsa_agnt = gsa_agent( varargin )

% Name: gsa_agent.m
% Location: MALT/agentClasses/@gsa_agent/gsa_agent.m
% Purpose: Constructor for a Global version of Stochastic Approximation
%          James C. Spall. 'Introduction to Stochastic Search and Optimization"
%          Section 8.4, p221
% Input Parameters: no Parameters - defaults used
%                   1 Parameter - object to copy || agent structure

global SessionObject

switch nargin
case 0 % Create default gsa agent
	gsa_agnt.bigA = 0.05 * 100000;
	% GSA agent inherits from the gradient_agent class
	gradient_agnt = gradient_agent;
	gradient_agnt = set( gradient_agnt, 'algorithm', 'gsa_agent' );
	gsa_agnt = class( gsa_agnt, 'gsa_agent', gradient_agnt );
case 1 % Copy object
	if ( isa( varargin{1}, 'gsa_agent' ) )
		gsa_agnt = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		agntStruct = varargin{1};
		% Agent structure instantiation

		% Get the parameter from the session and obtain the number of iterations
		tParam = get( SessionObject, 'parameter' );
		tIterations = get( tParam, 'totalIterations' );
		
		gsa_agnt.bigA = 0.05 * tIterations; % We set bigA to 5% of the total iterations
		gradient_agnt = gradient_agent( agntStruct );
		gradient_agnt = set( gradient_agnt, 'algorithm', 'gsa_agent' );
		gsa_agnt = class( gsa_agnt, 'gsa_agent', gradient_agnt );
	else
		error('gsa_agent.m: Input argument is not a gsa_agent object');
	end

otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or agent structure' );
   printOut( error_disp );
	error('gsa_agent.m: Wrong number of input arguments');
end

