function gsa_agnt_ret = updatestrategy( varargin )

% Name: updatestrategy.m
% Location: MALT/agentClasses/@gsa_agent/updatestrategy.m
% Purpose: Updates gsa agent's strategy
% Input Parameters:  gsa_agent object
%                    number of game being played
%                    current iteration
% Output Parameters: gsa_agent object with updated strategy

gsa_agnt = varargin{1}; % agent being updated
nGame = varargin{2}; % Number of game being played
iteration = varargin{3}; % The current iteration

% Obtain the current gradient using the unbounded forward difference formula
gradient = ufd_approx( gsa_agnt, nGame, iteration );

% Set parameters for a_{k} and b_{k} as per details in the Spall book
alpha = 0.602;
a = 10;
a_k = 1/( gsa_agnt.bigA + 1 + iteration)^alpha;

b = 0.3;
b_k = b/( (iteration + 1)^(alpha/2)*log(iteration + 1) );

nAction = get( gsa_agnt, 'actions' );
% Draw Gaussian generated term to act as random input
% w is in [-1, 1]
w = (rand(1, nAction).*( (round(rand(1, nAction))*2) - 1 ));

% Update the strategy (theta) using the original strategy and the two parameters, a_{k} and b_{k}
theta = returnstrategy( gsa_agnt );
theta = theta + a_k*gradient + b_k*w;
theta = gw_projection( theta ); % Project back to valid space

agntNumb = get( gsa_agnt, 'number' );
agntStrat = get( gsa_agnt, 'strategy' );
agntStrat( agntNumb, : ) = theta;
gsa_agnt = set( gsa_agnt, 'strategy', agntStrat );

gsa_agnt_ret =  gsa_agnt;
