function mm_agnt = minimax_agent( varargin )

% name: minimax_agent.m
% Location: MALT/agentClasses/@minimax_agent/minimax_agent.m
% Purpose:	Contructore for the minimax-Q agent class
%           Class is equivalent to the minimax-Q algorithm described in:
%           M.L. Littman. 'Markov games as a framework for multi-agent 
%           reinforcement learning', ICML 1994
% Input Parameters: no Parameters - defaults used
%                   1 Parameter - object to copy || agent structure
% Output Parameters: created minimax-Q agent object

switch nargin
case 0 % Create default minimax-Q agent
	mm_agnt.oppActions = 2; % Assumes opponent has two actions
	% minimax_agent inherits from q_agent (Q-learning)
	q_agnt = q_agent;
	q_agnt = set( q_agnt, 'algorithm', 'minimax_agent' );
	q_agnt = set( q_agnt, 'Q', ones(2, 2) ); % Assumes two agents, each with two actions
	mm_agnt = class( mm_agnt, 'minimax_agent', q_agnt );

case 1 % Copy object
	if ( isa( varargin{1}, 'minimax_agent' ) )
		mm_agnt = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		agntStruct = varargin{1};
		% Agent structure instantiation
		totActions = agntStruct.actions;
		mm_agnt.oppActions = totActions(1);
		q_agnt = q_agent( agntStruct );
		
		% Reset the Q matrix to the form we require
		% It is now of the form (Number of agents actions) X ( opponent's number of actions )
		q_agnt = set( q_agnt, 'Q', ones( max( agntStruct.actions ), max( agntStruct.actions ) ) );
		q_agnt = set( q_agnt, 'algorithm', 'minimax_agent' );
		mm_agnt = class( mm_agnt, 'minimax_agent', q_agnt );
	else
		error('minimax_agent.m: Input argument is not a minimax_agent object')
	end

otherwise
   error_disp = sprintf( 'Valid Parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or agent structure' );
   printOut( error_disp );
   error( 'minimax_agent.m: Wrong number of input arguments' );
end
