function mm_agnt = update_q( mm_agnt, stage_cellList )

% Name: update_q.m
% Location: MALT/agentClasses/@minimax_agent/update_q.m
% Purpose: Updates Q for the minimax-Q agent
% Input Parameters:	minimax_agent object,
%							cell list from the stage game of {actions rewards}
% Output Parameters: updated minimax_agent object

% Obtain all the parameter values from the minimax-Q agent object
agntGamma = get( mm_agnt, 'gamma' );
agntAlpha = get( mm_agnt, 'alpha' );
agntAlphaD = get( mm_agnt, 'alphaDecay' );
agntQ = get( mm_agnt, 'Q' );
agntV = get( mm_agnt, 'V' );
agntNumb = get( mm_agnt, 'number' );

% Get the agent's ID number and determine the opponent's ID number
% This is needed, since we need to obtain the actions and rewards in this round
% These are stored according to ID number, not according to the flip-changed number
IDNumber = get( mm_agnt, 'idNumber' );
if ( IDNumber == 1 )
	oppID = 2;
else
	oppID = 1;
end

nAgents = ndims( agntQ );

allActions = stage_cellList{1};
allRew = stage_cellList{2};

agntAction = allActions( IDNumber );
agntRew = allRew( agntNumb );
oppAction = allActions( oppID );

% Update the value of the Q matrix
maxAns = agntAlpha * ( agntRew + agntGamma*agntV );
agntQ( agntAction, oppAction ) = ( 1 - agntAlpha ) * agntQ( agntAction, oppAction ) + maxAns;

mm_agnt = set( mm_agnt, 'Q', agntQ );
mm_agnt = set( mm_agnt, 'alpha', agntAlpha * agntAlphaD );
