function mm_idr_agnt_ret = updatestrategy( varargin )

% Name: updatestrategy.m
% Location: MALT/agentClasses/@minimax_idr_agent/updatestrategy.m
% Purpose: Updates Q, V and the stategy for the minimax-Q-IDR agent
% Input Parameters:  minimax_idr_agent object
%                    number of game being played
%                    iteration
%                    stage_cellList
% Output Parameters: Updated minimax_idr_agent object

global SessionObject; % Make the global object visible

mm_idr_agnt = varargin{1}; % minimax-Q-IDR agent object
nGame = varargin{2}; % Number of game
iteration = varargin{3}; % Number of iteration being played
stage_cellList = varargin{4};

% If in the first iteration, correct set the strategy
if ( iteration == 1 )
	% Check to see that we are using the correct strategy
	agntStrat = get( mm_idr_agnt, 'strategy' );
	agntNumb = get( mm_idr_agnt, 'number' );
	agntActions = get( mm_idr_agnt, 'actions' );

	needToUpdate = 0;

	% Obtain the strategy of undominated actions
	undominated_strategy = return_idr_strategy( nGame, agntNumb );
	% Update the agent's strategy with the undominated actions
	agntStrat( agntNumb, : ) = undominated_strategy;
	% Normalise this to properly act as a probability over actions
	agntStrat( agntNumb, : ) = agntStrat( agntNumb, : ) / sum( agntStrat( agntNumb, : ) );
	
	gamesAll = get( SessionObject, 'gameList' );
	cGame = gamesAll{nGame};

	% Get the list of undominated actions from the game
	allUndom = get( cGame, 'undominated_actions' );
	mm_idr_agnt = set( mm_idr_agnt, 'strategy', agntStrat );
	mm_idr_agnt = set( mm_idr_agnt, 'allowedActions', allUndom{agntNumb} );
end

mm_idr_agnt = update_q( mm_idr_agnt, stage_cellList ); % Update Q matrix

mm_idr_agnt = update_pi( mm_idr_agnt, nGame ); % Update strategy

mm_idr_agnt_ret = mm_idr_agnt;

