function pareto_agnt = obtain_pareto_strategy( varargin )

% Name: obtain_pareto_strategy.m
% Location: MALT/agentClasses/@pareto_agent/obtain_pareto_strategy.m
% Purpose: Updates the pareto_agnt strategy by selecting a pure strategy
%          that corresponds to the highest pareto optimal outcome
% Input Parameters:  pareto_agent object
%                    number of the game being played
% Output Parameters: pareto_agnt object with updated strategy

pareto_agnt = varargin{1}; % Take pareto_agent object
nGame = varargin{2}; % Take number of the game being played

agntNumber = get( pareto_agnt, 'number' );
nActions = get( pareto_agnt, 'actions' );

cList = {};

% Brute force calculation of pareto outcomes
% This is a (number of actions)^4 complexity
for act1Out = 1:nActions
	for act2Out = 1:nActions
		acts = [act1Out act2Out];
		tempStrat = [generate_pure( act1Out, nActions ); generate_pure( act2Out, nActions )];
		agt1Rew = value( nGame, tempStrat, 1 );
		agt2Rew = value( nGame, tempStrat, 2 );
	 	cFound = 0;
		for act1 = 1:nActions
			for act2 = 1:nActions
				tempStrat = [generate_pure( act1, nActions ); generate_pure( act2, nActions )];
				agt1RewNew = value( nGame, tempStrat, 1 );
				agt2RewNew = value( nGame, tempStrat, 2 );

				if ( ( agt1RewNew >= agt1Rew ) && ( agt2RewNew >= agt2Rew ) )
					acts = [act1 act2];
					agt1Rew = agt1RewNew;
					agt2Rew = agt2RewNew;
					cFound = 1;
				end
			end
		end

		if ( cFound )
			 cList = {cList{1:end} acts};
		end

	end
end

% Run through the list of pareto outcomes and find the one that returns the highest reward to the agent
maxValue = -100;
for cPareto = 1:length( cList )
	paretoStrat = cList{ cPareto };

	tempStrat = [generate_pure( paretoStrat(1), nActions ); generate_pure( paretoStrat(2), nActions )];

	agntRew = value( nGame, tempStrat, agntNumber );

	if ( agntRew > maxValue )	
		cAct = paretoStrat( agntNumber );
		maxValue = agntRew;
	end
	
end % for: cPareto

% Generate a pure strategy corresponding to the action that plays the pareto outcome that returns the highest reward to the agent
pStrat = generate_pure( cAct, nActions );

allStrats = get( pareto_agnt, 'strategy' );
allStrats( agntNumber, : ) = pStrat;

pareto_agnt = set( pareto_agnt, 'strategy', allStrats );
