function q_agnt = q_agent( varargin )

% Name: q_agent.m
% Location: MALT/agentClasses/@q_agent/q_agent.m
% Purpose:	Constructor for the Q-learning agent class
%    	      Class is equivalent to the Q-learning algorithm described in:
%				L.P. Kaelbling, M.L. Littman and A.W. Moore. 'Reinforcement Learning:
%				A survey'. JAIR 4:1996
% Input Parameters: no Parameters - defaults used
%                   1 Parameter - object to copy || agent structure
% Output Parameters: created Q-learning agent object

switch nargin
case 0 % Create default Q-learning agent
	q_agnt.explore = 0.2; 
	q_agnt.exploreDecay = 0.999941;
	q_agnt.alpha = 0.9;
	q_agnt.alphaDecay = 0.999913;
	q_agnt.gamma = 0.9;
	q_agnt.Q = ones(1, 2); % Defaults to 2 actions
	q_agnt.V = 1; % Only a single state game, since in a repeated game
	% Q-agent inherits from the default 'agent' class
	agnt = agent( 'q_agent' );
	q_agnt = class( q_agnt, 'q_agent', agnt );
case 1 % Copy object
	if ( isa( varargin{1}, 'q_agent' ) )
		q_agnt = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		agntStruct = varargin{1};
		% Agent structure instantiation
		% Take the variables 
		q_agnt.explore = agntStruct.explore;
		q_agnt.exploreDecay = agntStruct.exploreDecay;
		q_agnt.alpha = agntStruct.alpha;
		q_agnt.alphaDecay = agntStruct.alphaDecay;
		q_agnt.gamma = agntStruct.gamma;
		
		% Now construct the Q and V variables.
		q_agnt.Q = ones(1, max( agntStruct.actions ) );
		q_agnt.V = 1;
		% Construct the parent class
		agnt = agent( agntStruct.algorithm, agntStruct.number, agntStruct.actions, agntStruct.strategy, agntStruct.displayName );
		q_agnt = class( q_agnt, 'q_agent', agnt );
	else	
		error('q_agent.m: Input argument is not a q_agent object');
	end
otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or agent structure' ); 
	printOut( error_disp );
	error( 'q_agent.m: Wrong number of input arguments' );
end
