function q_agnt = update_pi( varargin )

% Name: update_pi.m
% Location: MALT/agentClasses/@q_agent/update_pi.m
% Purpose:	Updates the strategy, pi and value V, for the Q-learning agent
%				Assumes it is only playing a pure strategy 
%				(unless more than one action gives the minmax value)
% Input Parameters: q_agent object
% Output Parameters: updated q_agent object

q_agnt = varargin{1}; % Get the Q-learning agent object

nActions = get( q_agnt, 'actions' ); % Get the number of actions
numb = get( q_agnt, 'number' ); % Get the agent number

agntStrategy = get( q_agnt, 'strategy' ); % Get the agent strategy

% Create matrix of pure strategies
pureStrats = eye( nActions );

pi = q_agnt.Q;
highPay = (pi == max(pi) ); % Find where maximum value action occurs
highPay = highPay/sum(highPay); % Force those actions to be a distribution

% Sample an action off of the actions that return the highest payoff
agntStrategy( numb, : ) = generate_pure( draw_sample( highPay), nActions );

q_agnt = set( q_agnt, 'strategy', agntStrategy );

q_agnt = set( q_agnt, 'v', max( q_agnt.Q ) );
