function san_agnt = san_agent( varargin )

% Name: san_agent.m
% Location: MALT/agentClasses/@san_agent/san_agent.m
% Purpose:	Constructor for the simulated annealing agent class
%				From "Introduction to Stochastic Search and Optimization
% 				by James C. Spall. See section 8.2 p212
% 				Also in "Stochastic optimization, stochastic approximation 
%				and simulate annealing" by James C. Spall, p539 [2]
%
% 				Note: This differs from the versions described by Spall, 
%				which are gradient DESCENT. The versions implemented here are 
%				gradient ASCENT, though one can easily convert between the two types
% Input Parameters: no Parameters - defaults used
%                   1 Parameter - object to copy || object structure
% Output Parameters: created simulated annealing object

switch nargin
case 0 % Create default random agent
	san_agnt.beliefUpdateRate = 0.9;
	san_agnt.beliefDecayRate = 0.999911;
	san_agnt.budget = 5; % Number of times strategy changes are made
	% Simulated annealing agent inherits from the default 'agent' class
	agnt = agent;
	agnt.algorithm = 'san_agent';
	san_agnt = class( san_agnt, 'san_agent', agnt );
case 1 % Copy object
	if ( isa( varargin{1}, 'san_agent' ) )
		san_agnt = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		agntStruct = varargin{1};
		% Agent structure instantiation
		san_agnt.beliefUpdateRate = agntStruct.beliefUpdateRate;
		san_agnt.beliefDecayRate = agntStruct.beliefDecayRate;
		san_agnt.budget = agntStruct.budget;

		agnt = agent( agntStruct.algorithm, agntStruct.number, agntStruct.actions, agntStruct.strategy, agntStruct.displayName );
		agnt = set( agnt, 'algorithm', 'san_agent' );
		san_agnt = class( san_agnt, 'san_agent', agnt );
		
	else
		error('san_agent.m: Input argument is not a san agent object');
	end
otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or agent structure' );
	printOut( error_disp );
	error( 'san_agent.m: Wrong number of input arguments' );
end
