function san_agnt = updatebeliefs( san_agnt, actionsTaken )

% Name: updatebeliefs.m
% Location: MALT/agentClasses/@san_agent/updatebeliefs.m
% Purpose: Updates san agent's beliefs about the strategy that the opponent is playing
% Input Parameters: 	san_agent object
%							list of actions taken
% Output Parameters: san_agent object with updated beliefs

agntNumb = get( san_agnt, 'number' );
agntID = get( san_agnt, 'idNumber' );
agntStrat = get( san_agnt, 'strategy' );
agntBeliefUpdateRate = get( san_agnt, 'beliefUpdateRate' );
agntBeliefDecayRate = get( san_agnt, 'beliefDecayRate' );

% Determine what the opponent's ID number is for referencing the actionsTaken
if ( agntID == 1 )
	oppID = 2;
else
	oppID = 1;
end

% Update beliefs about opponent's strategy,
% Using the stochastic approximation technique to update
for agnts = length( actionsTaken )
	if ( agnts ~= agntNumb ) % Do not apply to own agent
		currBeliefs = agntStrat( agnts, : );
		currBeliefs( 1, actionsTaken( oppID, 1 ) ) = ( 1 - agntBeliefUpdateRate )*currBeliefs( 1, actionsTaken( oppID, 1 ) ) + agntBeliefUpdateRate;

		currBeliefs = currBeliefs / sum( currBeliefs );
		agntStrat( agnts, : ) = currBeliefs;
	end
end

% Decay the belief update rate
san_agnt = set( san_agnt, 'strategy', agntStrat );
san_agnt = set( san_agnt, 'beliefUpdateRate', agntBeliefUpdateRate * agntBeliefDecayRate);
