function san_agnt_ret = updatestrategy( varargin )

% Name: updatestrategy.m
% Location: MALT/agentClasses/@san_agent/updatestrategy.m
% Purpose: 	Updates san agent's strategy
% Input Parameters: 	san agent object
%							number of game being played
%							iteration
% Output Parameters: Updated san agent object

global SessionObject;

san_agnt = varargin{1};
nGame = varargin{2};
iteration = varargin{3};
% Take the number of actions and strategy of the agent
theta = get( san_agnt, 'strategy' );
nAction = get( san_agnt, 'actions' );
agntNumber = get( san_agnt, 'number' );

% Obtain the expected value of the agent's current strategy
L_curr = value( nGame, theta, agntNumber ); % Value of current strategy
% Dummy variable for storing the current "best strategy"
end_theta = theta;

% Step 1
T = 1/log( iteration + 1 ); % Set temperature
% Could also use 1/( iteration ) OR 1/log( iteration )

for nEval = 1:san_agnt.budget % Step 4. Repeats steps 2. and 3.
	% Step 2.
	% Vector of Gaussian generated random perturbations
	pert = (rand(1, nAction).*( (round(rand(1, nAction))*2) - 1 ));

	newTheta = theta;
	% Add the perturbations
	newAgentTheta = newTheta( agntNumber, [1:nAction] ) + pert;
	% Project back to valid probability space
	newAgentTheta = gw_projection( newAgentTheta );
	newTheta( agntNumber , [1:nAction] ) = newAgentTheta;

	L_new = value( nGame, newTheta, agntNumber ); % Value of new strategy

	% Step 3.
	delt = L_new - L_curr;
	if ( delt > 0 ) % i.e. L_new is better
		end_theta( agntNumber, : ) = newTheta( agntNumber, : );
	else % delt < 0
		U = rand(1, 1); % Monte Carlo generated random variable?
		if ( U <= (exp(-delt/T)) )
			end_theta( agntNumber, : ) = newTheta( agntNumber, : );
		end
	end
end % for: nEval

% Step 5. Done during game playing

% Set the end_theta to be the agent's new strategy
san_agnt = set( san_agnt, 'strategy', end_theta );

% Return the updated simulated annealing agent
san_agnt_ret = san_agnt;
