function wolf_agnt_ret = updatestrategy( varargin )

% Name: updatestrategy.m
% Location: MALT/agentClasses/@wolf_agent/updatestrategy.m
% Purpose: Updates wolf agent's strategy
% Input Parameters: 	wolf_agent object
%							number of game being played
%							iteration
% Output Parameters: wolf_agent object with updated strategy

global SessionObject;

wolf_agnt = varargin{1};
nGame = varargin{2};
iteration = varargin{3};

agntStrat = get( wolf_agnt, 'strategy' );
agntNumber = get( wolf_agnt, 'number' );
wolfSlow = get( wolf_agnt, 'slow' );
wolfFast = get( wolf_agnt, 'fast' );
wolfStep = get( wolf_agnt, 'stepSize' );
wolfDecay = get( wolf_agnt, 'decay' );

% Obtain the current gradient using the unbounded forward difference formula
gradient = ufd_approx( wolf_agnt, nGame, iteration );

needToCreate = 0;
eqmStrat = return_equilibria( nGame, 1 );

theta = agntStrat;
thetaEqm = agntStrat;
% Take the WoLF agent's equilibrium strategy
thetaEqm( agntNumber, : ) = eqmStrat( agntNumber, : );

% Calculate value of current strategy and the equilibrium strategy
eqmValue = value( nGame, thetaEqm, agntNumber );
thetaValue = value( nGame, theta, agntNumber );
% Compare these values
if ( thetaValue > eqmValue )
	% Learn with slow learning rate if equilibrium payoff is worse
	theta( agntNumber, : ) = theta( agntNumber, : ) + (wolfSlow * wolfStep) * gradient;
else
	% Learn with fast learning rate if equilibrium payoff is better
	theta( agntNumber, : ) = theta( agntNumber, : ) + wolfFast * wolfStep * gradient;
end

% Project the strategy to the valid probability space
theta( agntNumber, : ) = gw_projection( theta( agntNumber, : ) );

% Include/save the agent's strategy
wolf_agnt = set( wolf_agnt, 'strategy', theta );

% Decay the learning rate
wolf_agnt_ret = set( wolf_agnt, 'stepSize', wolfStep * wolfDecay );
