function wolf_agnt = wolf_agent( varargin )

% Name: wolf_agent.m
% Location: MALT/agentClasses/@wolf_agent/wolf_agent.m
% Purpose: Constructor for the wolf agent class
%          M. Bowling and M. Veloso. 'Convergence of Gradient Dynamics with a
%         Variable Learning Rate', ICML 2001
% Input Parameters: no Parameters - defaults used
%                   1 Parameter - object to copy || agent structure
% Output Parameters: created wolf agent object

switch nargin
case 0 % Create default gradient agent
	wolf_agnt.slow = 0.008;
	wolf_agnt.fast = 0.16;
	wolf_agnt.decay = 0.999945;
	% Wolf_agent inherits from the 'gradient_agent' class
	gradient_agnt = gradient_agent;
	gradient_agnt.stepSize = 1;
	gradient_agnt.algorithm = 'wolf_agent';
	wolf_agnt = class( wolf_agnt, 'wolf_agent', gradient_agnt );

case 1 % Copy object or create object from agent structure
	if ( isa( varargin{1}, 'wolf_agent' ) )
		wolf_agnt = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		agntStruct = varargin{1};
		% Agent structure instantiation
		wolf_agnt.slow = agntStruct.slow;
		wolf_agnt.fast = agntStruct.fast;
		wolf_agnt.decay = agntStruct.decay;

		gradient_agnt = gradient_agent( agntStruct );
		gradient_agnt = set( gradient_agnt, 'stepSize', 1, 'algorithm', 'wolf_agent' );
		wolf_agnt = class( wolf_agnt, 'wolf_agent', gradient_agnt );
	else
		error( 'gradient_agent.m: Input argument is not a gradient_agent object or an agent structure' );
	end	
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy or agent structure' );
	printOut( error_disp );
	error( 'wolf_agent.m: Wrong number of input arguments' );
end
