function [avg, dt] = obtain_data_average( dt, whichData )

% Name: obtain_data_average.m
% Purpose: Obtain the average of some data item over all runs and iterations
% Input Parameters:  data object
%                    name of the data item for which the average is requested
% Output Parameters: the average of the data item over the runs and iterations

dtList = get( dt, 'dataList' );

% First check if the data item exists in this data
foundData = 0;
for dtItem = 1:length( dtList )

	if isequal( dtList{dtItem}, whichData )
		foundData = dtItem;
	end
end
if ( foundData == 0 )
	avg = -1;
else
	% Now first check that the average doesn't already exist and hasn't been computed
	allAvgs = get( dt, 'avgData' );
	if ( isempty( allAvgs{1, foundData} ) )
	% Need to create the average, since it doesn't exist

		allRuns = get( dt, 'allData' );
		[flips, nRuns] = size( allRuns );

		% We assume all the stored data items for which we want to average,
		% are in 2D of agent x iteration

		% Get the first stored propery, for both agents
		initialAvg = obtain_property( allRuns{1, 1}, whichData ) + obtain_property( allRuns{2, 1}, whichData );
		% Since the data should be stored in the correct ordering in the series_data,
		% we do not need to worry about which flip we are taking it from
		for rns = 2:nRun
			intialAvg = initialAvg + obtain_property( allRuns{1, rns}, whichData ) + obtain_property( allRuns{2, runs}, whichData );
		end
		% Average it all by dividing by the number of runs and 
		% occurences of both agents playing as the row and column agents
		avg = initialAvg / (2*nRuns);
		allAvgs(1, foundData) = avg;
		dt = set( dt, 'avgData', allAvgs );
	else
	% Have already created the average and can just return it
		avg = allAvgs{1, foundData};
	end
end
