function ev_data = expected_value_data( varargin )

% Name: expected_value_data.m
% Location: MALT/dataClasses/@expected_value_data/expected_value_data.m
% Purpose:  Constructor for the expected_value_data class
%           Child class of the snapshot_data class
%           Adds the storing of the expected value of the game for both agents
% Input Parameters: no Parameters - defaults used
%1 Parameter -  object to copy
%5 Parameters - Number of agents
%               Maximum number of actions over the agents
%               Number of iterations
%               Identification of which run this is storing data for
%               Cell list of what data items are saved
% Output Parameters: created expected_value_data object

switch nargin
case 0 % Create default expected_value_data object
	
	ev_data.expectedValue = zeros(2, 0); % Assume 2 agents, storing 0 iterations
	% Expected_value_data object inherits from the 'snapshot_data' class
	sd_dt = snapshot_data;
	tStore = get( sd_dt, 'storing' );
	% Add the extra data item 'expectedValue' and also the extra frequency descriptor
	tStore( length( tStore ) + 1 ) = {'expectedValue'};
	sd_dt = set( sd_dt, 'storing', tStore );
	ev_data = class( ev_data, 'expected_value_data', sd_dt );

case 1
	if ( isa(varargin{1}, 'expected_value_data') )
		ev_data = varargin{1};
	else
		error( 'expected_value_data.m: Input argument is not an expected_value_data object' );
	end

case 5
	tNag = varargin{1};
	tAct = varargin{2};
	tIter = varargin{3};
	tRunN = varargin{4};
	pList = varargin{5};

	expFound = 0;
	% Make sure that expectedValue is included in the list of data items
	for tDt = 1:length( pList )
		if ( isequal( lower( pList{tDt} ), 'expectedvalue' ) )
			expFound = tDt;
		end
	end
	if ( expFound == 0 ) % ie. expectedValue is not included in list of data items stored
		% Need to add a "pseudo" counter to allow this process to continue
		expFound = length( pList );
	end
	sendThrough = [1:(expFound - 1) (expFound + 1):length( pList )];

	% setup the expectedValue field
	ev_data.expectedValue = zeros( tNag, tIter );

	sd_dt = snapshot_data( tNag, tAct, tIter, tRunN, pList( sendThrough ) );

	sd_dt = set( sd_dt, 'storing', pList );
	% Add the extra data item 'expectedValue' and also the extra frequency descriptor
	ev_data = class( ev_data, 'expected_value_data', sd_dt );

otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy\n5 Parameters - Number of agents, maximum number of actions over the agents, Number of iterations, Number of the run being stored, Cell list of what data items are being stored\n' );
	disp( error_disp );
	error( 'expected_value_data.m: Wrong number of input arguments' );
end
