function agntProp = obtain_property( series_dt, varargin )

% Name: obtain_property.m
% Location: MALT/dataClasses/dataClasses/@series_data/obtain_property.m
% Purpose: Returns the property of agent agNumber, over all the iterations
% Input Parameter: series data object
%		   property that is wanted
%		   * optional * number of the agent
%		   * optional * Iteration wanted
% Output Parameter:  Property of agent agNumber for this series data

property = varargin{1};
nargin = length( varargin );

switch nargin
case 1 % Want to get the property for all agents and iterations
	switch lower( property )
	case 'rewards'
		allRewards = get( series_dt, 'rewards' );
		agntProp = allRewards( :, : );
	case 'actionstaken'
		allActions = get( series_dt, 'actionsTaken' );
		agntProp = allActions( :, : );
	case 'strategies'
		allStrategies = get( series_dt, 'strategies' );
		agntProp = allStrategies( :, :, : );
	otherwise
		error( '@series_data/obtain_property.m: Unknown agent property requested' );
	end	

case 2 % Want to get the property for a specific agent, all iterations
	agNumber = varargin{2};
	switch lower( property )
	case 'rewards'
		allRewards = get( series_dt, 'rewards' );
		agntProp = allRewards( agNumber, : );
	case 'actionstaken'
		allActions = get( series_dt, 'actionsTaken' );
		agntProp = allActions( agNumber, : );
	case 'strategies'
		allStrategies = get( series_dt, 'strategies' );
		agntProp = allStrategies( agNumber, :, : );
	otherwise
		error( '@series_data/obtain_property.m: Unknown agent property requested' );
	end
case 3 % Want to get the property for a specific agent and iteration
	agNumber = varargin{2};
	itnWanted = varargin{3};
	switch lower( property )
	case 'rewards'
		allRewards = get( series_dt, 'rewards' );
		agntProp = allRewards( agNumber, itnWanted );
	case 'actionstaken'
		allActions = get( series_dt, 'actionsTaken' );
		agntProp = allActions( agNumber, itnWanted );
	case 'strategies'
		allStrategies = get( series_dt, 'strategies' );
		agntProp = allStrategies( agNumber, :, itnWanted );
	otherwise
		error( '@series_data/obtain_property.m: Unknown agent property requested' );
	end
otherwise
	error( '@series_data.obtain_property.m: Incorrect number of parameters specified' );
end
