function series_dt = series_data( varargin )

% Name: series_data.m
% Location: MALT/dataClasses/@series_data/series_data.m
% Purpose:	Constructor for the series_data class
%				Stores the results of a set of iterations
% Input Parameters:	no Parameters - defaults used
%			  				1 Parameter - 	Object to copy
%						 	5 Parameters -	Number of agents
%												Maximum number of actions over the agents
%								    			Number of iterations
%												Number identifying which run it is
%												Cell list of what things are saved
% Output Parameters:	Created series_data object

switch nargin
case 0 % Create default series_data object.
	% Assumes rewards, actions taken and strategies are saved
	tNag = 2; % Assume two agents playing the game
	tAct = 2; % Assume maximum of two actions
	tIters = 0; % Don't know number of iterations, so leave empty
	series_dt.nAgents = tNag; % Assume two agents playing the game
	series_dt.iterations = tIters;
	series_dt.rewards = []; % zeros(tNag, tIters);
	series_dt.actionsTaken = []; % zeros(tNag, tIters);
	series_dt.strategies = []; % zeros( tNag, tAct, tIters );
	series_dt.runNumber = 1; % Assume this is the first run that is being recorded
	series_dt.storing = {'rewards'; 'actionsTaken'; 'strategies'};
	series_dt = class( series_dt, 'series_data' );
case 1
	if ( isa(varargin{1}, 'series_data') )
		series_dt = varargin{1};
	else
		error('series_data.m: Input argument is not a series_data object');
	end
case 5 % Constructor takes in number of agents, maximum number of actions
	tNag = varargin{1};
	tAct = varargin{2};
	tIters = varargin{3};
	series_dt.nAgents = tNag;
	series_dt.iterations  = tIters;
	tLst = varargin{5};
	if ( ~isa(tLst, 'cell') )
		error( 'series_data.m: Fifth parameter needs to be a cell array' ); 
	end
	% Create empty arrays/cells of everything we might use,
	% even if we don't use them, then still need to exist in the object 
	series_dt.rewards = [];
	series_dt.actionsTaken = [];
	series_dt.strategies = [];
	
	% Determine which data items we want to store
	for svs = 1:length(tLst)
		switch lower( tLst{svs} )
		case 'rewards'
			series_dt.rewards = zeros(tNag, tIters);
		case 'actionstaken'
			series_dt.actionsTaken = zeros(tNag, tIters);
		case 'strategies'
			series_dt.strategies = zeros( tNag, tAct, tIters );
		otherwise
			error( 'series_data.m: Unknown initialisation string' );
		end
	end
	series_dt.runNumber = varargin{4};
	[rCell, cCell] = size( tLst );
	if (rCell > cCell) % i.e. list is a single row
		series_dt.storing = tLst'; % Convert to a single column
	else
		series_dt.storing = tLst; % Take list as is -- a column
	end
	series_dt = class( series_dt, 'series_data' );
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy\n5 Parameters - Number of agents, maximum number of actions over the agents, number of iterations, number of the run being stored here, list of what data items are being stored' );
	disp( error_disp );
	error( 'series_data.m: Incorrect number of input arguments' );
end
