function tb_data = track_belief_data( varargin )

% Name: track_belief_data.m
% Location: MALT/dataClasses/@track_belief_data/track_belief_data.m
% Purpose:	Constructor method for the track_belief_data class
%		Child class of the expected_value_data class
%		Adds the storing of the agent's belief tracking,
%		with one able to specify which agents are doing tracking
% Input Parameters: no Parameters - defaults used
%		1 Parameter - 	object to copy
%     5 Parameters - Number of agents
%							Maximum number of actions over the agents
%							Number of iterations
%							Identification of which run this is storing data for
%							Cell list of what data items are saved
% Output Parameters: created track_belief_data object

switch nargin
case 0 % Create default track_belief_data object
	tNag = 2; % Assumes two agents playing the game
	tAct = 2; % Assumes maximum of two actions
	tIter = 0; % Assume default of storing 0 iterations
	tb_data.trackBeliefs = zeros( tNag, tAct, tIter ); % Assumes both agents are doing tracking
	tb_data.actualStrats = zeros( tNag, tAct, tIter ); % Actual strategy of agents being tracked
	
	% Change default parent class to be the expected_value_data
	exp_dt = expected_value_data;
	tStore = get( exp_dt, 'storing' );
   % Add the extra data item 'trackBeliefs' and also the extra frequency descriptor
   tStore( length( tStore ) + 1 ) = {'trackBeliefs'};
	exp_dt = set( exp_dt, 'storing', tStore );
	tb_data = class( tb_data, 'track_belief_data', exp_dt );
	
case 1
	if ( isa(varargin{1}, 'track_belief_data') )
		tb_data = varargin{1};
	else
		error( 'track_belief_data.m: Input argument is not a track_belief_data object' );
	end

case 5
	tNag = varargin{1};
	tAct = varargin{2};
	tIter = varargin{3};
	tRunN = varargin{4};
	pList = varargin{5};
	tFreq = ones(1, length(pList) ); % Assume default and every data item is stored every iteration

	tBeliefFound = 0;
	eValueFound = 0;
	% Make sure that trackBeliefs is included in the list of data items
	for tDt = 1:length( pList )
		if ( isequal( lower( pList{tDt} ), 'trackbeliefs' ) )
			tBeliefFound = tDt;
		end
	end
	if ( tBeliefFound == 0 ) % ie. trackBeliefs is not included in the list of data items stored
		error( 'track_belief_data.m: To use track_belief_data objects, you must include "trackBeliefs" in the list of data items stored' );
	end
   sendThrough = [1:(tBeliefFound - 1) (tBeliefFound + 1):length( pList )];
	tb_data.trackBeliefs = zeros( tNag, tAct, tIter ); % Assumes both agents are doing tracking
	tb_data.actualStrats = zeros( tNag, tAct, tIter ); % Actual strategy of agents being tracked
	
	% ie. we are storing the expected value, so need to instantiate it as a parent
	ev_data = expected_value_data( tNag, tAct, tIter, tRunN, pList( sendThrough ) );

	tStore = get( ev_data, 'storing' );
	% Add the extra data item 'trackBeliefs'
	ev_data = set( ev_data, 'storing', pList );
	tb_data = class( tb_data, 'track_belief_data', ev_data );

otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - object to copy\n' );
	disp( error_disp );
	error( 'track_belief_data.m: Wrong number of input arguments' );
end
