function [nfg_gm, whatReturned] = call_gambit_eqm( nfg_gm, gambitFile )

% Name: call_gambit_eqm.m
% Location: MALT/gameClasses/@nfg_game/call_gambit_eqm.m
% Purpose:  Calls the Gambit suite to obtain the equilibria 
%           and undominated strategies of a game
% Input Parameters:  normal form game object
%                    name of the gambit code file that we want to create and read from
% Output Parameters: Updated normal form game object, 
%                    with undominated strategies and equilibria parameters updated

global MALT_HOME

% Link to running Gambit (note the './' for Linux)
gambitCommand = '/cs/public/lib/pkg/gambit-0.97.0.6/bin/./gcl ';

% Generate the gambit Code file
generateGambitCode( nfg_gm, gambitFile, 'eqm' )

% Make the call to gambit to calculate equilibria
returnDir = pwd;
cd( '/cs/public/lib/pkg/gambit-0.97.0.6/bin' );
[callS, returnedDet] = system( [gambitCommand gambitFile] );
cd( returnDir );

tActs = get(nfg_gm, 'totalActions');

% Reads the equilibrium from the created file and saves it
gambEqa = eqmReader( get(nfg_gm, 'nAgents'), max( tActs ), tActs, [MALT_HOME 'extProgs/' get( nfg_gm, 'fileName' ) '.eqm'] );

% Set the equilibrium in the nfg_game object
nfg_gm = set( nfg_gm, 'eqa', gambEqa );
whatReturned = gambEqa;
