function nfg_gm = call_gamut( nfg_gm, gamutCommands )

% Name: call_gamut.m
% Location: MALT/gameClasses/@nfg_game/call_gamut.m
% Purpose:	Calls the gamut game generator to construct normal form games
% Input Parameters:	normal form game object
%							gamut pameters
% Output Parameters:	Updated normal form game object, with payoff matrices

global MALT_HOME; % Global variable for home directory of MALT

gamutFName = get( nfg_gm, 'fileName' );
if isequal( gamutFName, '' )
	% Using the non-cluster version of malt
	% The Gamut file name has not been specified
	fSimple = [MALT_HOME 'extProgs/nfg_game.simple']; % File name for simple output
	fGambit = [MALT_HOME 'extProgs/nfg_game.gambit']; % File name for Gambit output
	% Update the normal form game file name as well
	nfg_gm = set( nfg_gm, 'fileName', 'nfg_game' );
else
	% Using the cluster version of malt
	% Use the Gamut file name that has been specified
	fSimple = [MALT_HOME 'extProgs/' gamutFName '.simple']; % File name for simple output
	fGambit = [MALT_HOME 'extProgs/' gamutFName '.gambit']; % File name for Gambit output
end

% Set the java command for running gamut
% gamut.jar file found in extProgs directory
javaCommands = ['java -jar ' MALT_HOME 'extProgs/gamut.jar ' ];

% Set the gamutCall to create a simple output file
gamutCall = [javaCommands ' -g ' get(nfg_gm, 'name') ' -normalize -min_payoff -1 -max_payoff 1 -f ' fSimple ' ' gamutCommands ' -output SimpleOutput'];
[callSuccess, returnedDet] = system( gamutCall );

% If the call is not a success, then we return the error message and exit
if ( callSuccess ~= 0 )
	returnedDet
	error( sprintf( '\n@nfg_game\call_gamut.m: Unsuccessful in calling gamut with the parameters %s to generate %s', gamutCommands, fSimple ) );
end

% Obtain the payoffs and random seed from the generated game
[ payoffs, gamutSeed ] = payOffReader( fSimple );
gamutSeed = sprintf('%10.0f', gamutSeed);

% Run gamut, but this time producing an output file in the gambit format
% This time we run it with the random_seed that was from the previous game
% generation. This ensures the game is the same in both output formats
gamutCall = [javaCommands ' -random_seed ' gamutSeed ' -g ' get(nfg_gm, 'name') ' -normalize -min_payoff -1 -max_payoff 1 -f ' fGambit ' ' gamutCommands ' -output GambitOutput'];

[callSuccess, returnedDet] = system( gamutCall );
% Again if the call to gamut was not a success,
% then we output the error message and exit
if ( callSuccess ~= 0 )
	returnedDet
	error( sprintf( '\n@nfg_game\call_gamut.m: Unsuccessful in calling gamut with the parameters %s to generate %s', gamutCommands, fGambit ) );
end

% Set the payoffs and random seed in this object
nfg_gm = set( nfg_gm, 'payoffs', payoffs, 'random_seed', gamutSeed );
