function nfg_gm_ret = call_guaranteed( nfg_gm )

% Name: call_guaranteed.m
% Location: MALT/gameClasses/@nfg_game/call_guaranteed.m
% Purpose: Obtain the guaranteed value of a payoff matrix for both agents,
% Input Parameters:  Normal form game object
% Output Parameters: Updated normal form game with 
%                    an updated array of guaranteed values per agent

nAgents = get( nfg_gm, 'nAgents' );
allPayMats = get( nfg_gm, 'payoffs' );
totActions = get( nfg_gm, 'totalActions' );

actionDist = zeros( nAgents, max( totActions ) );
valueLst = zeros(1, nAgents);
value = 0;

% Calculates the guaranteed value for each agent
for cAgnt = 1:nAgents
	cPayMat = allPayMats{cAgnt};
	for agMin = 1:nAgents
		if ( agMin ~= cAgnt )
			cPayMat = min( cPayMat, [], agMin );
		end
	end
	% Get the maximum value after all the minimisation calls
	value = max( cPayMat );
	valueLst( 1, cAgnt ) = value; % Set that agent's guaranteed value
   % Put a one in all action places where the guaranteed value is found
	% 'reshape' is used because the vector could be in any orientation
	findG = reshape( cPayMat == value, 1, max( totActions ) );
	
	% Obtain a uniform distribution over the actions that produce the guaranteed value
	actionDist( cAgnt, : ) = findG;
	actionDist( cAgnt, : ) = actionDist( cAgnt, : ) / sum( actionDist( cAgnt, : ) );
end

% Update the values in the nfg_game, of the guaranteed value and 
% distribution over actions that produce that value for both agents
nfg_gm = set( nfg_gm, 'guaranteed', valueLst );
nfg_gm = set( nfg_gm, 'guaranteed_strategies', actionDist );

nfg_gm_ret = nfg_gm;
