function nfg_gm = nfg_game( varargin )

% Name: nfg_game.m
% Location: MALT/gameClasses/@nfg_game/nfg_game.m
% Purpose:	Constructor for the normal form game class
%				Inherits from the game class
% Input Parameters:	No parameters -	default created
%							1 parameter	-		object to copy
%							5 parameters -		name of the game
%													number of agents
%													number of actions for each agent (in an array)
%                                      name of the Gamut file
%													command line for Gamut (incl. actions, agents)
% Output Parameters: Create normal form game object

switch nargin
case 0 % Create default normal form game object
	nfg_gm.payoffs = {};
	nfg_gm.eqa = [];
	nfg_gm.guaranteed = [];
	nfg_gm.guaranteed_strategies = [];
	nfg_gm.random_seed = 0;
	nfg_gm.gamutCommand = '';
	% The nfg_game class inherits from the game class
	gm = game;
	nfg_gm = class( nfg_gm, 'nfg_game', gm );

case 1 % Copy the nfg_game object
	if ( isa(varargin{1}, 'nfg_game') )
		nfg_game = varargin{1};
	else
		error( sprintf( 'nfg_game.m: Wrong argument type. \nnfg_game object expected, found %s', class( varargin{1} ) ) );
	end

case 5
	nfg_gm.payoffs = {};
	nfg_gm.eqa = [];
	nfg_gm.guaranteed = [];
	nfg_gm.guaranteed_strategies = [];
	nfg_gm.random_seed = 0;
	nfg_gm.gamutCommand = varargin{4};

% Create base game object
	gm = game( varargin{1}, varargin{2}, varargin{3}, varargin{4} );
	nfg_gm = class( nfg_gm, 'nfg_game', gm );
	
	% Generate a game and save the payoffs and random seed
	printOut( 'Calling gamut game generator to construct payoffs and random seed...' );
	nfg_gm = call_gamut( nfg_gm, varargin{5} );

otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo parameters - default created\n1 parameter - object to copy\n5 parameters - name of the game, number of agents, number of actions for each agent (in an array), name of the Gamut generated file, command line for Gamut (incl. actions, agents)' );

	disp( error_disp );
	error( 'nfg_game.m: Wrong number of input arguments' );
end
