function nfg_gm_idr_ret = call_guaranteed_idr( nfg_gm_idr )

% Name: call_guaranteed_idr.m
% Location: MALT/gameClasses/@nfg_game_idr/call_guaranteed_idr.m
% Purpose:  Obtain the guaranteed value of the IDR payoff matrix for both agents,
%           as well as a distribution over the action(s) that produce that value
% Input Parameters:  Normal form game with iterated dominance removal properties
% Output Parameters: Updated normal form idr game with an 
%                    updated array of guaranteed values per agent from the idr game

nAgents = get( nfg_gm_idr, 'nAgents' );
allPayMats = get( nfg_gm_idr, 'payoffs_idr' );
allUnDom = get( nfg_gm_idr, 'undominated_actions' );
totActions = get( nfg_gm_idr, 'totalActions' );

actionDist = zeros( nAgents, max( totActions ) );
valueLst = zeros(1, nAgents);
value = 0;

% Calculate the guaranteed value for each agent after IDR
for cAgnt = 1:nAgents
	cPayMat = allPayMats{cAgnt};
	for agMin = 1:nAgents
		if ( agMin ~= cAgnt )
			cPayMat = min( cPayMat, [], agMin );
		end
	end
	% After all of the minimisation applications, apply the max step
	value = max( cPayMat );
	valueLst( 1, cAgnt ) = value;
	% Find which actions have the guaranteed value
	lstMaxFind = find( cPayMat == value );
	[lRow, lCol] = size( lstMaxFind );

	if ( lRow > lCol )
		lstMaxFind = lstMaxFind';
	end
	% Need to convert from actions on IDR matrix to actions on full matrix
	converts = allUnDom{cAgnt};
	prodMin = converts( lstMaxFind );
	actionDist( cAgnt, prodMin ) = 1;
	actionDist( cAgnt, : ) = actionDist( cAgnt, : )/sum( actionDist( cAgnt, : ) );
end

% Update the values in the nfg_game_idr, of the guaranteed IDR value and 
% the distribution over actions that produces that value for both agents
nfg_gm_idr = set( nfg_gm_idr, 'guaranteed_idr', valueLst );
nfg_gm_idr = set( nfg_gm_idr, 'guaranteed_idr_strategies', actionDist );

nfg_gm_idr_ret = nfg_gm_idr;

