function nfg_gm_idr = call_idr( nfg_gm_idr )

% Name: call_idr.m
% Location: MALT/gameClasses/@nfg_game_idr/call_idr.m
% Purpose:  Obtains the equilibria and undominated strategies,
%           from a Gambit produced file and converts it to a Matlab matrix format
% Input Parameters:  normal form game (with IDR properties) object
% Output Parameters: Udated normal form idr game,
%                    with undominated actions and strategy parameters updated

global MALT_HOME % Make the home path accessible

% Read in the undominated actions from the file
undomActs = idrReader( get(nfg_gm_idr, 'nAgents'), [MALT_HOME 'extProgs/' get( nfg_gm_idr, 'fileName' ) '.idr'] );

% Get the payoffs
allPays = get( nfg_gm_idr, 'payoffs' );
a1Pay = allPays{1};
a2Pay = allPays{2};

% Create payoff matrices left after iterated dominance removal
ag1IDR_pay = a1Pay( undomActs{1}, undomActs{2} );
ag2IDR_pay = a2Pay( undomActs{1}, undomActs{2} );

IDR_pay = {ag1IDR_pay, ag2IDR_pay};

% Calculate an array with a '1' in the position of undominated actions
totActs = get( nfg_gm_idr, 'totalActions' );
maxActions = max( totActs );
ag1Strat = zeros(1, maxActions );
ag2Strat = zeros(1, maxActions );
ag1Strat( 1, undomActs{1} ) = 1;
ag2Strat( 1, undomActs{2} ) = 1;
agStrats = [ag1Strat; ag2Strat];

% Set those values
nfg_gm_idr = set( nfg_gm_idr, 'undominated_actions', undomActs, 'payoffs_idr', IDR_pay, 'undominated_strategies', agStrats );

