function nfg_gm_idr = nfg_game_idr( varargin )

% Name: nfg_game_idr.m
% Location: MALT/gameClasses/@nfg_game_idr/nfg_game_idr.m
% Purpose:  Constructor for the normal form game with 'iterated dominated removal (IDR) parameters' class
%           Inherits from the normal form game class
% Input Parameters:	No parameters - default created
%                    1 parameter	-   object to copy || game structure
%                    5 parameters -  name of the game
%                                    number of agents
%                                    number of actions for each agent (in an array)
%                                    name of Gamut generated file
%                                    command line for Gamut (incl. actions, agents)
% Output Parameters: Create normal form game with IDR parameters object

switch nargin
case 0 % Create default normal form game object
	nfg_gm_idr.guaranteed_idr = [];
	nfg_gm_idr.guaranteed_idr_strategies = [];
	nfg_gm_idr.undominated_actions = {};
	nfg_gm_idr.undominated_strategies = [];
	nfg_gm_idr.payoffs_idr = {};
	% The nfg_game_idr class inherits from the nfg_game class	
	nfg_gm = nfg_game;
	nfg_gm_idr = class( nfg_gm_idr, 'nfg_game_idr', nfg_gm );
case 1 % Copy a nfg_game_idr object
	if ( isa( varargin{1}, 'nfg_game_idr' ) )
		nfg_gm_idr = varargin{1};
	elseif ( isa( varargin{1}, 'struct' ) )
		% Game is being instantiated as a structure
		gameStruct = varargin{1};
		
	   nfg_gm_idr.guaranteed_idr = [];
	   nfg_gm_idr.guaranteed_idr_strategies = [];
	   nfg_gm_idr.undominated_actions = {};
	   nfg_gm_idr.undominated_strategies = [];
	   nfg_gm_idr.payoffs_idr = {};

	   % Hack to handle multiple versions of TwoByTwoGame in Gamut
		% This ensures that a random TwoByTwo game is created for each instance
	   if isequal( gameStruct.name, 'TwoByTwoGame' )
		   randomType = 0;
		   while ( ( randomType > 85 ) || ( randomType < 1 ) ) 
		         randomType = round( rand(1, 1) * 100 );
		   end
		   gameStruct.gamutCommand = ['-type ' num2str( randomType )];
	   end

		% Create base nfg_game object
		nfg_gm = nfg_game( gameStruct.name, gameStruct.nAgents, gameStruct.totalActions, gameStruct.fileName, gameStruct.gamutCommand  );
		nfg_gm_idr = class( nfg_gm_idr, 'nfg_game_idr', nfg_gm );		
	else
		error( sprintf( 'nfg_game_idr.m: Wrong argument type. \nnfg_game_idr object expected, found %s', class( varargin{1} ) ) );
	end
case 5
	nfg_gm_idr.guaranteed_idr = [];
	nfg_gm_idr.guaranteed_idr_strategies = [];
	nfg_gm_idr.undominated_actions = {};
	nfg_gm_idr.undominated_strategies = [];
	nfg_gm_idr.payoffs_idr = {};
	
% Create base nfg_game object
	nfg_gm = nfg_game( varargin{1}, varargin{2}, varargin{3}, varargin{4}, varargin{5} );
	nfg_gm_idr = class( nfg_gm_idr, 'nfg_game_idr', nfg_gm );
	
	% The payoffs, random seed and equilibrium parameters 
	% are created by the call_gamut and call_gambit methods in @nfg_game
	
	%	Here, we just want to add the idr parameters
%	nfg_gm_idr = call_idr( nfg_gm_idr );
otherwise
	error_disp = sprintf( 'Valid Parameters:\nNo parameters - default created\n1 parameter - object to copy\n4 parameters - name of the game, number of agents, number of actions for each agent (in an array), name of Gamut generated file, command line for Gamut (incl. actions, agents)' );

	disp( error_disp );
	error( 'nfg_game_idr.m: Wrong number of input arguments' );
end
