function validity = check_cluster_run( )

% Name: check_cluster_run.m
% Location: MALT/general/check_cluster_run.m
% Purpose:  Checks that all files that were supposed to be 
%           produced by the cluster, were in fact produced
% Input Parameters:  None  
% Output Parameters: validity bit saying whether all file produced or not,
%                    validity=1 if all files produced, 0 otherwise

global SessionObject
global MALT_HOME
global SESSION_NAME
global STORAGE_DIRECTORY

% Open a file for writing the cluster script code to
% This is in the session directory that the user specified earlier

allAgentCombs = get( SessionObject, 'agentCombination' );
allGames = get( SessionObject, 'gameList' );
[nRuns, nGames] = size( allGames );
allAgents = get( SessionObject, 'agentList' );

nCombs = size( allAgentCombs, 2 );

totRuns = nCombs*nGames*nRuns*2;

validity = 1;

% Open the file and set the correct front part of the replacement string
newFile = 'missingData';
FID_MISSING = fopen( newFile, 'a' );
frontStart = ['cd ' MALT_HOME '; matlab -nodesktop -nodisplay -nojvm -nosplash -r "add_MALT_to_path; SESSION_NAME = ''24-Mar-2005_THESIS''; STORAGE_DIRECTORY = ''storedFiles''; tournament_cluster('];
toWrite = '';

totMissing = 0;

filePrefix = [MALT_HOME STORAGE_DIRECTORY '/' SESSION_NAME '/'];
runNumber = 0;
for cComb = 1:nCombs % Loop over all the agent combinations
	for cGame = 1:nGames % Loop over all the games
		for cRun = 1:nRuns % Loop over all the runs
		gme = allGames{ cRun, cGame };
			
		agnt1Numb = allAgentCombs(1, cComb );
		agnt2Numb = allAgentCombs(2, cComb );
		
		agnt1 = allAgents{ agnt1Numb };
		agnt2 = allAgents{ agnt2Numb };
			
		% Create file name for first flip
		fileName = create_file_name_cluster( agnt1.displayName, agnt2.displayName, get( gme, 'fileName' ), '', 1, 'metric_data' );
		
		% Check if file produced
		fid = fopen( [fileName], 'r' );
		if ( fid == -1 )
			% If it wasn't correctly produced, then:
			% display the file name to the screen, with the details
			disp( fileName );
			disp( ['Run number: ' num2str( runNumber ) ' with ' num2str( [cGame agnt1Numb agnt2Numb cRun 1] ) ] );

			% Setup the values and string to recreate the file
			% Write these details to the replacement file
			runValues = [num2str(cGame) ', ' num2str(agnt1Numb) ', ' num2str(agnt2Numb) ',' num2str(cRun) ', 1'];
			toWrite = [frontStart runValues '); exit"'];
			fprintf( FID_MISSING, '%s\n', toWrite );
			validity = 0;
			totMissing = totMissing + 1;
		else
			fclose( fid );
		end

		runNumber = runNumber + 1;
		
		% Create file name for second flip
		fileName = create_file_name_cluster( agnt1.displayName, agnt2.displayName, get( gme, 'fileName' ), '', 2, 'metric_data' );
		% Check if file produced
		fid = fopen( [fileName], 'r' );
		if ( fid == -1 )
			disp( fileName );
			disp( ['Run number: ' num2str( runNumber ) ' with ' num2str( [cGame agnt1Numb agnt2Numb cRun 2] ) ] );
			validity = 0;
			runValues = [num2str(cGame) ', ' num2str(agnt1Numb) ', ' num2str(agnt2Numb) ',' num2str(cRun) ', 2'];
			toWrite = [frontStart runValues '); exit"'];
			fprintf( FID_MISSING, '%s\n', toWrite );
			totMissing = totMissing + 1;
		else
			fclose( fid );
		end

		runNumber = runNumber + 1;
		
		end % cRun
		
	end % cGame
end % cComb

fclose( FID_MISSING )

disp( [' Total number of missing runs: ' num2str( totMissing )] )
disp( [' Checked a total of ' num2str( runNumber ) ' files/runs'] )
