function newSess = combine_session( sessionCellNames )

% Name: combine_session.m
% Location: MALT/general/combine_session.m
% Purpose: Combines multiple sessions together
% Input Parameters:  Cell list of names of sessions to combine
% Output Parameters: New/updated session object with the sessions combined

% Make the global variables visible
global SessionObject;
global MALT_HOME
global STORAGE_DIRECTORY
% Create a dummy session object
session;

nSessions = length( sessionCellNames ); % Get the number of sessions that need to be combined

% Setup the SessionObject to be the first Session
firstSessionName = sessionCellNames{1};
sessStruct = load( [MALT_HOME STORAGE_DIRECTORY '/' firstSessionName '/session.mat'] );
firstSession = sessStruct.SessionObject;

origAgents = get( firstSession, 'agentList' );
origGames = get( firstSession, 'gameList' );
origParam = get( firstSession, 'parameter' );
origFileList = get( firstSession, 'filelist' );
origSessType = get( origParam, 'sessionType' );

% Start creating the new session
largerAgents = origAgents;
largerGames = origGames;
largerParamGamutCommands = get( origParam, 'gamutCommand' );
largerFileList = origFileList;

for nextSessions = 2:nSessions;
    nextName = sessionCellNames{nextSessions};
    sessStruct = load( [MALT_HOME STORAGE_DIRECTORY '/' nextName '/session.mat'] );
    newSession = sessStruct.SessionObject
    newParam = get( newSession, 'parameter' );    
    newAgents = get( newSession, 'agentList' );
    if ~isequal( origSessType, get( newParam, 'sessionType' ) )
        disp( ['Unable to join session ' nextName ': Different session type'] );
        disp( ['Ignoring this session, continuing with the rest'] );
    else    
        if ( length( origAgents ) ~= length( newAgents ) )
            disp( ['Unable to join session ' nextName ': Different number of agents'] );
            disp( ['Ignoring this session, continuing with the rest'] );
        else
            % Check agents
            agnt = 1;
            stillEqual = 1;
            while ( ( agnt <= length( origAgents ) && ( stillEqual ) )
                if ~isequal( origAgents{agnt}, newAgents{agnt} )
                    disp( ['Unable to join session ' nextName ': Different agents'] );
                    disp( ['Ignoring this session, continuing with the rest'] );
                    stillEqual = 0;
                end
                agnt = agnt + 1;
            end
            if ( stillEqual )
                % Add the extra games into the larger games list
                newGames = get( newSession, 'gameList' );
                largerGames = { largerGames{:, :} newGames{:, :} };
                % Add the extra Gamut commands into the parameter
                newGamutCommands = get( newParam, 'gamutCommand' );
                largerParamGamutCommands = {largerParamGamutCommands{:, :} newGamutCommands{:, :} };
                % Add the filelist into the session
                newFileList = get( newSession, 'fileList' );
                largerFileList = {largerFileList{:, :} newFileList{:, :}};
            end % if: stillEqual
        end % if: ( length( origAgents ) ~= length( newAgents ) )
    end % ~isequal( origSessType, get( newParam, 'sessionType' ) )
end % for: nextSessions = 2:nSessions;

% set the Gamut commands into the parameter
param = origParam;
param = set( param, 'gamutCommands', largerParamGamutCommands );

% set the parameter into the SessionObject
SessionObject = set( SessionObject, 'parameter', param );
% set the games into the SessionObject
SessionObject = set( SessionObject, 'gamelist', largerGames );
% set the file list into the SessionObject
SessionObject = set( SessionObject, 'fileList', largerFileList );

newSess = SessionObject;
