function beliefs = create_beliefs( totalActions, varargin )%typeOfBeliefs )

% Name: create_beliefs
% Location: MALT/general/create_beliefs.m
% Purpose: Creates default belief distribution for an agent with 
%			  an equal likelihood of taking any action
% Input Parameters: total number of actions for all agents
%                   type of beliefs - a string
% Output Parameters: Uninformative belief distribution

% Take the number of actions and get the size
maxActions = max( totalActions );
[row nAgents] = size( totalActions );

% Create empty beliefs variable
beliefs = zeros( nAgents, maxActions );

% Depending on the type of beliefs wanted, create the relevant one
nargin = length( varargin );
if (nargin == 0)
	typeOfBeliefs = 'Uniform';
else
	typeOfBeliefs = varargin{1};
end

switch typeOfBeliefs
case 'Uniform' % Uniform probability over beliefs
	for agt = 1:nAgents
		cAgentAction = totalActions( 1, agt );
		beliefs( agt, [1:cAgentAction] ) = ones(1, cAgentAction)/cAgentAction;
	end

case 'Noisy Uniform' % Uniform probability over beliefs, with noise
	for agt = 1:nAgents
		cAgentAction = totalActions( 1, agt );
		permutation = (2*round( rand(1, cAgentAction ) ) - 1).*(rand(1, cAgentAction)/10);
		beliefs( agt, [1:cAgentAction] ) = ones(1, cAgentAction) + permutation;
		beliefs( agt, : ) = beliefs( agt, : )/sum( beliefs( agt, : ) );
	end
case 'Random' % Random probability over beliefs
	for agt = 1:nAgents
		cAgentAction = totalActions( 1, agt );
		beliefs( agt, [1:cAgentAction] ) = rand(1, cAgentAction );
		beliefs( agt, : ) = beliefs( agt, : ) / sum( beliefs( agt, : ) );
	end
case 'Random pure strategy' % Randomly select a pure strategy
	for agt = 1:nAgents
		cAgentAction = totalActions( 1, agt );
		randomShuffle = randperm( cAgentAction );
		beliefs( agt, randomShuffle(1) ) = 1;
	end
end
