function [fileName] = create_cluster_file( )

% Name: create_cluster_file.m
% Location: MALT/general/create_cluster_file.m
% Purpose:  Creates a file for use on a cluster, where the runs are split up
%           and each run is seperately listed
% Input Parameters:  
% Output Parameters:

% Make the global variables visible
global SessionObject
global MALT_HOME
global SESSION_NAME
global STORAGE_DIRECTORY

% Open a file for writing the cluster script code to
% This is in the session directory that the user specified earlier
fileName = [MALT_HOME STORAGE_DIRECTORY '/' SESSION_NAME '/cluster_file'];
fid = fopen( fileName, 'w' );

if ( fid == -1 )
	error( 'create_cluster_file.m: Unable to save cluster file' );
end

allAgentCombs = get( SessionObject, 'agentCombination' );
allGames = get( SessionObject, 'gameList' );
[nRuns, nGames] = size( allGames );

nCombs = size( allAgentCombs, 2 );

% Note the code below is specific to the Sun Grid Engine system
% Without '\n', use a ';' to break the shell commands instead
code1 = ['cd ' MALT_HOME '; ' sprintf( 'matlab -nodisplay -nojvm -nosplash -r "add_MALT_to_path; SESSION_NAME = ''%s''; STORAGE_DIRECTORY = ''%s''; tournament_cluster(', SESSION_NAME, STORAGE_DIRECTORY )];
useCommand = 'use matlab-7.0.1';

totRuns = nCombs*nGames*nRuns*2;

trackCounter = 1;

for cRun = 1:nRuns % Loop over all the runs
	for cComb = 1:nCombs % Loop over all the agent combinations
		for cGame = 1:nGames % Loop over all the games

			% Create a file id to a new file
			fileName = [MALT_HOME STORAGE_DIRECTORY '/' SESSION_NAME '/jobFile_' num2str( trackCounter )];
			fidRun = fopen( fileName, 'w' );
			% Write to that file the line requesting the correct terminal
			fprintf( fidRun, '%s \n\n', '#!/bin/sh' );

			% Include the 'use' command in the file,
			% to ensure correct version of Matlab is being used
			fprintf( fidRun, '%s\n', useCommand );
			
			% Produce a line for the agent combination cComb, the game cGame and the run cGame
			% First do this for the first flip
			fprintf( fidRun, '%s%d, %d, %d, %d, %d); exit"\n', code1, cGame, allAgentCombs(1, cComb), allAgentCombs(2, cComb), cRun, 1 );
			% Then do this for the second flip
	      fprintf( fidRun, '%s%d, %d, %d, %d, %d); exit"\n', code1, cGame, allAgentCombs(1, cComb), allAgentCombs(2, cComb), cRun, 2 );

			% close that file
			fclose( fidRun );

			% Append the command to the cluster file,
			% saying to add that file to the queuing system
			fprintf( fid, '%s\n', ['qsub -e /cs/SCRATCH/alipson/GRID_OUTPUT/ -o /cs/SCRATCH/alipson/GRID_OUTPUT/ ' 'jobFile_' num2str( trackCounter )] );

			% Increment the track counter
			trackCounter = trackCounter + 1;
		end % cGame
	end % cComb
end % cRun

% Close the cluster file
fclose( fid );
