function eqmAll = eqmReader(nAgents, maxActions, totalActions, fileName)

% Name: eqmReader.m
% Location: MALT/general/eqmReader.m
% Purpose:	Generate the Matlab matrix formats for all 
%				the equilibria of the normal form game
%				Reads files produced by version 0.97.0.6 of Gambit
% Input Parameters:	Number of agents
%							Maximum number of actions
%							Number of actions per agent
%							Name of Gambit created file
% Output Parameters:	Matrix of equilibria

eqmAll = zeros(nAgents, maxActions, 1);
eqmCount = 0;

% Open the file
fid = fopen( fileName );

if (fid == -1 )
	error( sprintf( 'Cannot open the file %s', fileName ) );
end

% The code below is parsing the text in the file
lRead = fgetl( fid );
while (lRead ~= -1)
	eqm = zeros(nAgents, maxActions);
	txtCount = 1;
	while ( ~isequal(lRead(1, txtCount), ')') )
		txtCount = txtCount + 1;
	end
	
	eqmCount = eqmCount + 1;
	for agnt = 1:nAgents % Over all agents
		while ( ~isequal(lRead(1, txtCount), '{') )
			txtCount = txtCount + 1;
		end % while: ~isequal
		txtCount = txtCount + 2; % Skips over the one space to the first number
		for acCount = 1:totalActions(1, agnt) % Over the actual number of actions for that agent
			val = '';
			while ( ~isequal(lRead(1, txtCount), ' ') )
				val = [val lRead(1, txtCount)]; % Append number element to value list
				txtCount = txtCount + 1;
			end % while: ~isequal

			eqm( agnt, acCount ) = str2num( val );
			txtCount = txtCount + 1;
		end % for: acCount
	end % for: agnt

	eqmAll(:, :, eqmCount) = eqm;
	lRead = fgetl( fid );
end % while: lRead ~= -1

% Close the file
fclose( fid );
