function generateGambitCode( nfg_gm, fileNameToCreate, wanted )

% Name: generateGambitCode.m
% Location: MALT/general/generateGambitCode.m
% Purpose:  Creates a file with Gambit code and saves it as fileNameToCreate
%           The file reads in the Gamut generated game and either does IDR or
%           determines the equilibrium of the game
% Input Parameters:  normal form game object
%                    name of the file in which to save the gambit code
%                    what feature is wanted, equilibrium or idr strategies
% Output Parameters: none

% Make path variable visible
global MALT_HOME

fid = fopen( fileNameToCreate, 'w' );

if ( fid == -1 )
	error( ['general/generateGambitCode.m: Unable to create gambit code file ' fileNameToCreate] );
end

gCode1 = ['n:=LoadNfg["' MALT_HOME 'extProgs/' get( nfg_gm, 'fileName' ) '.gambit"];'];
fprintf( fid, '%s\n', gCode1 );

switch( lower( wanted ) )
case 'eqm'
	gCode2 = 'd:=LcpSolve[n,0];';
	gCode3 = ['l:=Output["' MALT_HOME 'extProgs/' get( nfg_gm, 'fileName' ) '.eqm"];'];
	gCode4 = 'Write[l,d];';
	fprintf( fid, '%s\n%s\n%s\n', gCode2, gCode3, gCode4 );
	
case 'idr'
	gCode2 = 's:=IterativeUnDominated[n];';
	gCode3 = ['m:=Output["' MALT_HOME 'extProgs/' get( nfg_gm, 'fileName' ) '.idr"];'];
	gCode4 = 'Write[m,s];';
	fprintf( fid, '%s\n%s\n%s\n', gCode2, gCode3, gCode4 );
otherwise
	error( ['general/generateGambitCode.m: Unknown gambit operation, ' wanted ', requested'] );
end

fprintf( fid, '%s', 'Quit;' );

fclose( fid );
