function newDistribution = gw_projection( oldDistribution )

% Name: gw_projection.m
% Location MALT/general/gw_projection.m
% Purpose: Project a distribution back into valid probability space
%			  Implements a version of the retraction operator from:
% 			  Srihari Govindan and Robert Wilson -
%  		  "A Global Newton Method to compute Nash Equilibria"
% Input Parameters:	a probability distribution, possibly invalid
% Output Parameters: valid probability distribution

cntIters = 0;
sLngth = length( oldDistribution );

% Control check - all elements in the [0, 1] range
% Elements sum to 1 and the calculations will run for less than the maximum iterations
% We have a maximum iterations count because of Matlab's accuracy, which may not
% have the sum equal to exacly 1
while ((( sum( oldDistribution ) ~= 1 ) && ( cntIters < sLngth )) || (( sum( oldDistribution < 0 ) > 0 ) || ( sum( oldDistribution > 1 ) > 0 )))

% If the first iteration, then we want to project all elements, including the ones that equal zero (otherwise they are ignored - which is incorrect for the first iteration)
	if ( cntIters ~= 0 )
		whichNonZero = (oldDistribution ~= 0);
	else
		whichNonZero = ones(1, sLngth);
	end

if ( sum( whichNonZero ) ~= 0 )
	% Find all the non-zero elements to which we apply our correction
	findNonZero = find( whichNonZero );
	v_n = (sum( oldDistribution ) - 1) / sum( whichNonZero );

	% Take the maximum of the correction step or 0
	oldDistribution( findNonZero ) = max( oldDistribution( findNonZero ) - v_n, 0);
end

	cntIters = cntIters + 1;
end

newDistribution = oldDistribution;
