function [payOffMatrix, seedValue] = payOffReader( gamutName )

% Name: payOffReader.m
% Location: MALT/general/payOffReader.m
% Purpose:	Generate the Matlab matrix format of a Gamut generated normal form game
%				Also obtain the seed value for that created game
%				Reads files from version 1.0.1 of Gamut
% Input Parameters: Name of the Gamut file name
% Output Parameters: Cell of payoff matrices, value of the Gamut random seed

gamutName
fid = fopen( gamutName );
if ( fid == -1 )
	error( 'general/payOffReader.m: Unable to find Gamut generated file' );
end

actions = [];
payoffs = [];

lRead = fgetl( fid );

% The code below is for parsing the text in the file
while (lRead ~= -1)
    lnLength = length(lRead);
    strCop = '';
	 startSeen = 0;
	 colonSeen = 0;

	if ( length( lRead ) > 8 )
		% Read in the seed value
		if ( isequal( lRead(1, 1:8), '# Random' ) )
			seedValue = str2double( lRead(1, 16:end) );
		end
	end

	if ( lRead(1, 1) ~= '#')
		for ele = 1: lnLength
			switch ( lRead(1, ele) )
			case '['
				startSeen = 1;
				
			case ']'
				startSeen = 0;
				if ( colonSeen )
					payoffs = [payoffs; str2num( strCop )];
					strCop = '';
				else
					actions = [actions; str2num( strCop )];
					strCop = '';
				end
	
			case ':'
				colonSeen = 1;
	
			otherwise
				if ( startSeen )
					strCop = [strCop lRead(1, ele)];
				end % if: (startSeen)
			end % switch: lRead(1, ele)
		 end % for: ele
	 end
	 
	 lRead = fgetl(fid);
end % while: (lRead ~= -1) 

fclose( fid ); % close the file

% Now need to convert into appropriate format

% Take specification information
[actionPairs, nAgents] = size(actions);
actionTotal = max(actions); % Number of actions/agent
actionMax = max(actionTotal); % Maximum number of actions agents have

% Create empty payoffs matrix
payOffMatrix = cell(1, nAgents);

tAgentPay1 = zeros(actionTotal);
tAgentPay2 = zeros(actionTotal);
for pair = 1:actionPairs
	tAgentPay1( actions(pair, 1), actions(pair, 2) ) = payoffs( pair, 1 );
	tAgentPay2( actions(pair, 1), actions(pair, 2) ) = payoffs( pair, 2 );
end

payOffMatrix(1, 1) = {tAgentPay1};
payOffMatrix(1, 2) = {tAgentPay2};
