function recombine_cluster( )

% Name: recombine_cluster.m
% Location: MALT/general/recombine_cluster.m
% Purpose:  Recombines all of the separate cluster run files into the data files
% Input Parameters: none  
% Output Parameters: none

% Make the relevant global variables visible
global SessionObject
global MALT_HOME
global SESSION_NAME
global STORAGE_DIRECTORY

% *** we could do a precheck run that tries to open all files and printsup
%     the names of the files that don't exist

% Create a file to store the names of the data files
fNameFile = create_file_name( '', '', '', 'fileList' );

% Create dummy variables so that Matlab can use them
session;
dum1 = expected_value_data;
dum2 = series_data;
dum3 = track_belief_data;

% First we want to load the SessionObject
sessStruct = load( [MALT_HOME STORAGE_DIRECTORY '/' SESSION_NAME '/session.mat'] );
SessionObject = sessStruct.SessionObject;

% Get the fileList and list of data items to save
filesSvd = get( SessionObject, 'fileList' );
dataItms = get( SessionObject, 'dataItems' );

allAgentCombs = get( SessionObject, 'agentCombination' );
[tFlips totalCombinations] = size( allAgentCombs );
allGames = get( SessionObject, 'gameList' );
allAgents = get( SessionObject, 'agentList' );
[nRuns, nGames] = size( allGames );

nCombs = size( allAgentCombs, 2 );

for cComb = 1:nCombs % Loop over all the agent combinations
	agnt1 = allAgents{ allAgentCombs(1, cComb) }; % get the first agent
	agnt2 = allAgents{ allAgentCombs(2, cComb) }; % get the second agent

	agnt1DispName = agnt1.displayName;
	agnt2DispName = agnt2.displayName;
	
	for cGame = 1:nGames % Loop over all the games
		% Theoretically what I'm doing below isn't correct, 
		% since I just take the game in the first row of allGames
		% However, since we just want the game name, which is the same for all allGames( :, cGame )
		% we can ensure we get the correct game name, and do not care about the run number
		game = allGames{ 1, cGame };
		gameName = get( game, 'name' );

		fileName = get( game, 'fileName' );
  
% Note: the line below is commented out to prevent the recreation
% of the data file, which is currently not created
		% Create a data object for this agent combination and game
%%		dt_obj = data( nRuns, gameName, dataItms, { agnt1DispName agnt2DispName } );

		% Create a statistics object for this combination
		statsObj = statistics( 2, nRuns );
		% Create a file name for the stats data
		fNameStats = create_file_name( agnt1DispName, agnt2DispName, fileName(1:(end-2)), 'stats' );
		
		% Create a file name for this agent combination and game
		fNameData = create_file_name( agnt1DispName, agnt2DispName, fileName(1:(end-2)), 'data' )

		for cRun = 1:nRuns % Loop over all the runs
			% Generate the file name in which flip 1 is installed
% Note: the line below is commented out to prevent the recreation
% of the data file, which is currently not created
%			fName1 = create_file_name_cluster( agnt1DispName, agnt2DispName, fileName(1:(end-2)), cRun, 1, 'series_data' );
			% Load that file
%			sd_struct1 = load( fName1 );
%			sd_dt_obj1 = sd_struct1.sd_data;
%			dt_obj = add_to_data( dt_obj, sd_dt_obj1, 1 );

			% Generate the file name in which flip 2 is installed
%			fName2 = create_file_name_cluster( agnt1DispName, agnt2DispName, fileName(1:(end-2)), cRun, 2, 'series_data' );
			% Load that file
%			sd_struct2 = load( fName2 );
%			sd_dt_obj2 = sd_struct2.sd_data;
%			dt_obj = add_to_data( dt_obj, sd_dt_obj2, 2 );

			% DELETE THESE FILES
%			delete( fName1 );
%			delete( fName2 );
			
			% Including metric information
			% Now do the same for the metric_data files
			% First: create the file name where data was saved by the cluster
			fName1 = create_file_name_cluster( agnt1DispName, agnt2DispName, fileName(1:(end-2)), cRun, 1, 'metric_data' );
			% Second: load the file
			metStruct1 = load( fName1 );
			% Third: obtain the structure from the loaded file, in this case
			% the loaded file is also a structure
			metStructDat1 = metStruct1.metStatStruct;
			% Fourth: add the structure to the statistics object
			statsObj = add_to_statistics( statsObj, metStructDat1, 1, cRun );

			% Do the same for the second flip
			fName2 = create_file_name_cluster( agnt1DispName, agnt2DispName, fileName(1:(end-2)), cRun, 2, 'metric_data' );
			metStruct2 = load( fName2 );
			metStructDat2 = metStruct2.metStatStruct;
			statsObj = add_to_statistics( statsObj, metStructDat1, 2, cRun );

			% Delete these files
			delete( fName1 );
			delete( fName2 );
		end % end: for cRun

		% Save the data and statistics objects to a file
% Note: the line below is commented out to prevent the recreation
% of the data file, which is currently not created
		%		save( fNameData, 'dt_obj' );
		save( fNameStats, 'statsObj' );
		% Update the filelist and save the data object file name to the correct position
		filesSvd( (cGame-1)*totalCombinations + cComb ) = {fNameData};
	end % for: cGame 
end % for: cComb

% Resave the files list into the SessionObject
SessionObject = set( SessionObject, 'fileList', filesSvd );

% Save the SessionObject
save( [MALT_HOME STORAGE_DIRECTORY '/' SESSION_NAME '/session.mat'], 'SessionObject' );

% Save the fileList
save( fNameFile, 'filesSvd' );
