function recombine_cluster_for_combining( )

% Name: recombine_cluster_for_combiningm
% Location: MALT/general/recombine_cluster_for_combining.m
% Purpose:  Recombines all of the separate cluster run files into the data files
%           Additionally it updates the game file name
%           ie. Changes to game file for future combining of multiple sessions
% Input Parameters: none  
% Output Parameters: none

global SessionObject
global MALT_HOME
global SESSION_NAME
global STORAGE_DIRECTORY

% *** we could do a precheck run that tries to open all files and prints up
%     the names of the files that don't exist

% Create a file to store the names of the data files
fNameFile = create_file_name( '', '', '', 'fileList' );

% Create dummy variables so that Matlab can use them
session;
dum1 = expected_value_data;
dum2 = series_data;

% First we want to load the SessionObject
sessStruct = load( [MALT_HOME STORAGE_DIRECTORY '/' SESSION_NAME '/session.mat'] );
SessionObject = sessStruct.SessionObject;

% Get the fileList and list of data items to save
filesSvd = get( SessionObject, 'fileList' );
dataItms = get( SessionObject, 'dataItems' );

allAgentCombs = get( SessionObject, 'agentCombination' );
[tFlips totalCombinations] = size( allAgentCombs );
allGames = get( SessionObject, 'gameList' );
allAgents = get( SessionObject, 'agentList' );
[nRuns, nGames] = size( allGames );

nCombs = size( allAgentCombs, 2 );

generators = {};

for cGame = 1:nGames % Loop over all the games
	% Theoretically what I'm doing below isn't correct, 
	% since I just take the game in the first row of allGames
	% However, since we just want the game name, which is the same for all allGames( :, cGame )
	% we can ensure we get the correct game name, and do not care about the run number
	game = allGames{ 1, cGame };
	gameName = get( game, 'name' );

	fileName = get( game, 'fileName' );

	nGens = length( generators );
	nFound = 0;
	cGen = 1;

	% Either the generator has previously been added or not
	while ( ( cGen <= nGens ) && ( ~nFound ) )
		if isequal( generators{cGen}, gameName )
			nFound = 1;
		else
			cGen = cGen + 2; % We add two, to skip over the number
		end
	end
	if ( nFound == 1)
		% Generator was found at cGen
		cValue = generators{cGen + 1};
		newName = [gameName '_' num2str( cValue+1 )];
		generators(cGen + 1) = {cValue + 1};
	else
		% Generator title not included previously
		newName = [gameName '_' num2str( 1 )];
		generators = {generators{1:end} gameName 1 };
	end

	for cComb = 1:nCombs % Loop over all the agent combinations
		agnt1 = allAgents{ allAgentCombs(1, cComb) }; % get the first agent
		agnt2 = allAgents{ allAgentCombs(2, cComb) }; % get the second agent
	
		agnt1DispName = agnt1.displayName;
		agnt2DispName = agnt2.displayName;
	
		fNameData = create_file_name( agnt1DispName, agnt2DispName, newName, 'data' )

		% Create a data object for this agent combination and game
		dt_obj = data( nRuns, gameName, dataItms, { agnt1DispName agnt2DispName } );

		for cRun = 1:nRuns % Loop over all the runs

			fixedGame = allGames{cRun, cGame};
			fixedGame = set( fixedGame, 'fileName', [newName '_' num2str( cRun )] );
			allGames(cRun, cGame) = {fixedGame};
			
			% This is a bit of a hack to get the correct file name
			fName1 = create_file_name_cluster( agnt1DispName, agnt2DispName, fileName(1:(end-2)), cRun, 1, 'series_data' );           
% END NEW          
			% Load that file
			sd_struct1 = load( fName1 );
			sd_dt_obj1 = sd_struct1.sd_data;
			dt_obj = add_to_data( dt_obj, sd_dt_obj1, 1 );

			% Generate the file name in which flip 2 is installed
			fName2 = create_file_name_cluster( agnt1DispName, agnt2DispName, fileName(1:(end-2)), cRun, 2, 'series_data' );

			% Load that file
			sd_struct2 = load( fName2 );
			sd_dt_obj2 = sd_struct2.sd_data;
			dt_obj = add_to_data( dt_obj, sd_dt_obj2, 2 );

			% DELETE THESE FILES
			delete( fName1 );
			delete( fName2 );
		end % end: for cRun

		% Save the data object to a file
		save( fNameData, 'dt_obj' );
		% Update the filelist and save the data object file name to the correct position
		filesSvd( (cGame-1)*totalCombinations + cComb ) = {fNameData};
	end % for: cGame 
end % for: cComb

% Resave the files list into the SessionObject
SessionObject = set( SessionObject, 'fileList', filesSvd );

% Resave the games list into the SessionObject
SessionObject = set( SessionObject, 'gameList', allGames );

% Save the SessionObject
save( [MALT_HOME STORAGE_DIRECTORY '/' SESSION_NAME '/session.mat'], 'SessionObject' );

% Save the fileList
save( fNameFile, 'filesSvd' );
