function agm_met = actual_vs_guaranteed_metric( varargin )

% Name: actual_vs_guaranteed_metric.m
% Location: MALT/metricClasses/@actual_vs_guaranteed_metric/actual_vs_guaranteed_metric.m
% Purpose:  Constructor for the actual_vs_guaranteed_metric class
%           Measures the number of times that an agent scores above the guaranteed value
% Input Parameters:  no Parameters - defaults created
%                    1 Parameter - object to copy ||
%                                  frequency to store this metric at
% Output Parameters: actual_vs_guaranteed_metric object

switch nargin
case 0 % Create default actual_vs_guaranteed_metric object
	agm_met.name = 'actual_vs_guaranteed_metric';
	% Actual_vs_guaranteed_metric inherits from the metric class
	met = metric( 'actual_vs_guaranteed_metric',...
			'Doing better than or equalling security level (larger is better)', {'rewards'},...
			{'xlabel' 'Algorithms' 'ylabel' 'Scoring above the security level' 'title' 'Number of times obtaining a reward above the security level of a game'}, '', 1 );

	% We don't actually set the properties field in @metric,
	% since it isn't needed (at the moment)
	
	agm_met = class( agm_met, 'actual_vs_guaranteed_metric', met );
case 1 % Copy another actual_vs_guaranteed_metric object
	if ( isa( varargin{1}, 'actual_vs_guaranteed_metric' ) )
		agm_met = varargin{1};
	elseif isnumeric( varargin{1} )
		% Want to set the frequency of the metric ourselves
		agm_met.name = 'actual_vs_guaranteed_metric';
	   met = metric( 'actual_vs_guaranteed_metric',...
				'Doing better than or equalling security level (larger is better)', {'rewards'},...
				{'xlabel' 'Algorithms' 'ylabel' 'Scoring above the security level' 'title' ['Number of times obtaining a reward above the security level of a game, with frequency ' num2str( varargin{1} )]}, '', varargin{1} ); % This creates a metric with frequency varargin{1}
		agm_met = class( agm_met, 'actual_vs_guaranteed_metric', met );
	else
		error( 'actual_vs_guaranteed_metric.m: Input argument is not an actual_vs_guaranteed_metric object or a numeric singleton' );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy OR numeric value representing frequency' );
	disp( error_disp );
	error( 'actual_vs_guaranteed_metric.m: Incorrect number of input arguments' );
end
