function availMetData = run_metric_single( metObj, varargin )

% Name: run_metric_single.m
% Location: MALT/metricClasses/@actual_vs_guaranteed_metric/run_metric_single.m
% Purpose:  Adds the data that this metric requires, from this iteration
% Input Parameters: Metric object, for the metric being run
%                   Variable that is storing the data
%                   Data structure with information from this iteration
%                   First agent object
%                   Second agent object
%                   Number of the game being played
%                   Number of the current run
%                   Number of the current iteration *being saved* ie. relative number
% Output Parameter: Updated variable storing the data

% Make global variable visible
global SessionObject

% Copy parameters to variables
availMetData = varargin{1};
dataStructure = varargin{2};
agnt1 = varargin{3};
agnt2 = varargin{4};
cGame = varargin{5};
cRun = varargin{6};
cIteration = varargin{7};

% Now in the tournament / tournament_cluster files, we set 'gameList' to
% be a vector of games for the current run. Hence, we can just take '{cGame}'

% Get the guaranteed value for those agents
[g1Val, g1Strat] = return_guaranteed( cGame, get( agnt1, 'number' ) );
[g2Val, g2Strat] = return_guaranteed( cGame, get( agnt2, 'number' ) );
% Get the reward that the agents obtained this iteration
itsReward = dataStructure.rewards;
itsActions = dataStructure.actions;
% Vectorise the comparison between current reward and guaranteed values
% This will put a 1 in availMetData, where current reward is 
% *strictly* greater than the guaranteed value
% Though maybe this should be <, ie. strictly bigger  reward
availMetData( :, cIteration ) = [ g1Val; g2Val] <= itsReward;
