function di_met = deviation_incentive_metric( varargin )

% Name: deviation_incentive_metric.m
% Location: MALT/metricClasses/@deviation_incentive_metric/deviation_incentive_metric.m
% Purpose:  Constructor for the deviation_incentive_metric class
%           Score the agent could have received each iteration if they
%           had deviated to the best response
%           This would be zero if the agent always managed to somehow play 
%           a best response to its opponent at each step
% Input Parameters:  no Parameters - defaults created
%                    1 Parameter - object to copy ||
%                                  frequency to store this metric at
% Output Parameters: deviation_incentive_metric object

switch nargin
case 0 % Create default deviation_incentive_metric object
	di_met.name = 'deviation_incentive_metric';
	% This inhrits from the metric class
	met = metric( 'deviation_incentive_metric', 'Best response measure (smaller is better)',...
			{'rewards'}, {'xlabel' 'Algorithms' 'ylabel' 'Possible extra reward obtained' 'title' 'Extra reward obtained if always playing a best response'}, '', 1 );

	% We don't actually set the properties field in @metric,
	% since it isn't needed (at the moment)
	
	di_met = class( di_met, 'deviation_incentive_metric', met );
case 1 % Copy another deviation_incentive_metric object
	if ( isa( varargin{1}, 'deviation_incentive_metric' ) )
		di_met = varargin{1};
	elseif isnumeric( varargin{1} )
		% Want to set the frequency of the metric ourselves
		di_met.name = 'deviation_incentive_metric';
	   met = metric( 'deviation_incentive_metric', 'Best response measure (smaller is better)',...
				{'rewards'}, {'xlabel' 'Algorithms' 'ylabel' 'Possible extra reward obtained' 'title' ['Extra reward obtained if always playing a best response, with frequency ' num2str( varargin{1} )]}, '', varargin{1} );
		di_met = class( di_met, 'deviation_incentive_metric', met );
	else
		error( 'deviation_incentive_metric.m: Input argument is not a deviation_incentive_metric object or a numeric singleton' );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy OR numeric value representing frequency' );
	disp( error_disp );
	error( 'deviation_incentive_metric.m: Incorrect number of input arguments' );
end
