function availMetData = run_metric_single( metObj, varargin )

% Name: run_metric_single.m
% Location: MALT/metricClasses/@deviation_incentive_metric/run_metric_single.m
% Purpose:  Adds the data that this metric requires, from this iteration
% Input Parameters: Metric object, for the metric being run
%                   Variable that is storing the data
%                   Data structure with information from this iteration
%                   First agent object
%                   Second agent object
%                   Number of the game being played
%                   Number of the current run
%                   Number of the current iteration *being saved* ie. relative number
% Output Parameter: Updated variable storing the data

% Make global variable visible
global SessionObject

availMetData = varargin{1};
dataStructure = varargin{2};
agnt1 = varargin{3};
agnt2 = varargin{4};
cGame = varargin{5};
cRun = varargin{6};
cIteration = varargin{7};

% Now in the tournament / tournament_cluster files, we set 'gameList' to
% be a vector of games for the current run. Hence, we can just take '{cGame}'
allGames = get( SessionObject, 'gameList' );
currentGame = allGames{cGame};

% Get the set of actions that each agent played
% and the rewards that each agent received
itsActions = dataStructure.actions;
itsRewards = dataStructure.rewards;

% For the first agent
agnt1Numb = get( agnt1, 'number' );
payoffMat = return_payoff_matrix( currentGame, agnt1Numb );
maxValue1 = 0;
if ( agnt1Numb == 1 )
	maxValue1 = max( 0, max( payoffMat( :, itsActions(2) ) ) - itsRewards(1) );
else
	maxValue1 = max( 0, max( payoffMat( itsActions(2), : ) ) - itsRewards(1) );
end

% For the second agent
agnt2Numb = get( agnt2, 'number' );
payoffMat = return_payoff_matrix( currentGame, agnt2Numb );
maxValue2 = 0;
if ( agnt2Numb == 1 )
	maxValue2 = max( 0, max( payoffMat( :, itsActions(1) ) ) - itsRewards(2) );
else
	maxValue2 = max( 0, max( payoffMat( itsActions(1), : ) ) - itsRewards(2) );
end

% Assign these values back to the data for the metric
availMetData( :, cIteration ) = [ maxValue1; maxValue2 ];
