function stat_met = run_metric( met, dt, rowToFind, runToFind )

% Name: run_metric.m
% Location: MALT/metricClasses/@expected_value_metric/run_metric.m
% Purpose:  Method to run the metric on the available data
% Input Parameters: Metric object, for the metric being run
%                   Data object
%                   row that we want ( the flip )
%                   run that we want ( the column )
% Output Parameter: statistics_metric object

% Check whether the input is definitely a metric object
if ( ~isa( met, 'metric' ) )
	error( '@expected_value_metric/run_metric.m: First argument should be a metric object' );
end
% Check whether inputs also contains the date object
if ( ~isa( dt, 'data' ) )
	error( '@expected_value_metric/run_metric.m: Second argument should be a data object' );
end

% Request the wanted data from the data object
% Which call depends on whether averaging or not

allDataNeeded = get( met, 'needed_data' );
dataNeeded = allDataNeeded{1};
metFreq = get( met, 'frequency' ); % Get the frequency at which things need to be used

dtAll = get( dt, 'allData' ); % Take all the data - nRuns*2 series_data objects
sampData = dtAll{1,1}; % Take a sample of the series data
nIters = get( sampData, 'iterations' ); % Get the number of iterations

% Precreate the matrix
expValAll = zeros(2, nIters);
% Obtain the data we want
expValAll = obtain_data( dt, runToFind, rowToFind, dataNeeded );

% Create the statistics metric_object and save the data to it
allAlgs = get( dt, 'algList' );
extraLabels = {'gamename' get( dt, 'gamename' ) };

% Call the metric_statistics constructor
stat_met = metric_statistics( get( met, 'name'),...
				[get( met, 'labels') extraLabels], get( met, 'properties' ),...
				{allAlgs{1} allAlgs{2}}, expValAll,...
				'Generated by @expected_value_metric object' );
