function availMetData = run_metric_single( metObj, varargin )

% Name: run_metric_single.m
% Location: MALT/metricClasses/@k_competitiveness_metric/run_metric_single.m
% Purpose:  Adds the data that this metric requires, from this iteration
% Input Parameters: Metric object, for the metric being run
%                   Variable that is storing the data
%                   Data structure with information from this iteration
%                   First agent object
%                   Second agent object
%                   Number of the game being played
%                   Number of the current run
%                   Number of the current iteration *being saved* ie. relative number
% Output Parameter: Updated variable storing the data

% Make global variable visible
global SessionObject

% Copy the parameters to variables
availMetData = varargin{1};
dataStructure = varargin{2};
agnt1 = varargin{3};
agnt2 = varargin{4};
cGame = varargin{5};
cRun = varargin{6};
cIteration = varargin{7};

% Now in the tournament / tournament_cluster files, we set 'gameList' to
% be a vector of games for the current run. Hence, we can just take '{cGame}'
allGames = get( SessionObject, 'gameList' );
currentGame = allGames{cGame};

% Get the set of actions that each agent played
% and the rewards that each agent received at the previous iteration
itsActions = dataStructure.actions;
itsRewards = dataStructure.rewards + 1; % Change to range [0, 2]

% For the first agent
agnt1Numb = get( agnt1, 'number' );
payoffMat = return_payoff_matrix( currentGame, agnt1Numb );
kValue1 = 0;
if ( agnt1Numb == 1 )
	% Obtain the maximum possible value the action could have received and
	% then move from [-1, 1] range to [0, 2] range
	maxValue1 = max( payoffMat( :, itsActions(2) ) ) + 1;
else
	maxValue1 = max( payoffMat( itsActions(2), : ) ) + 1;
end
	
if ( maxValue1 == 0 )
	% In the case where the maximum value possible is also
	% the worst possible value for the agent
	if ( itsRewards(1) == 0 )
		kValue1 = 1; % Since obtained the maximum = 0
	else
		% Max value is 0, can't have anything else less than this, must be an error
		error( '@k_competitiveness_metric/run_metric_single.m' );
	end
else
	kValue1 = itsRewards(1)/maxValue1;
end

% For the second agent
agnt2Numb = get( agnt2, 'number' );
payoffMat = return_payoff_matrix( currentGame, agnt2Numb );
kValue2 = 0;
if ( agnt2Numb == 1 )
	% Obtain the maximum possible value the action would have received and
	% then move from [-1, 1] range to [0, 2] range
	maxValue2 = max( payoffMat( :, itsActions(1) ) ) + 1;
else
	maxValue2 = max( payoffMat( itsActions(1), : ) ) + 1;
end

if ( maxValue2 == 0 )
	% This is the case where the maximum value possible is also the worst
	% possible value for that agent
	if ( itsRewards(2) == 0 )
		kValue2 = 1; % Since obtained the maximum of 0
	else
		% Max value is 0, can't have anything else less than this, must be an error
		error( '@k_competitiveness_metric/run_metric_single.m' );
	end
else
	kValue2 = itsRewards(2)/maxValue2;
end

% Save the values back
availMetData( :, cIteration ) = [ kValue1; kValue2];
