function met = metric( varargin )

% Name: metric.m
% Location: MALT/metricClasses/@metric/metric.m
% Purpose:  Constructor for the metric class
%           Specifies different types of metrics that one can run
% Input Parameters:  no Parameters - defaults created
%                    1 Parameter - object to copy || numeric with frequency
%                    6 Parameters - Actual name of metric
%                                   Display name of metric
%                                   Data needed for this metric
%                                   Labels for use in graphs
%                                   Properties used in plotting the graph
%                                   Frequency at which metric should be stored
% Output Parameter:	metric object

switch nargin
case 0 % Create default metric object
	met.name = '';				% Name of the metric
	met.displayName = '';	% Name used to display the metric
	met.needed_data = {};	% Data needed for this metric
	met.labels = {};			% x-, y- and z-labels, title for graphs/plots
	met.properties = {};		% Properties used in plotting the graph - linewidth, etc
	met.frequency = 1;		% Frequency at which the metric is stored
	met = class( met, 'metric' );
case 1 % Copy another metric object
	if ( isa( varargin{1}, 'metric' ) )
		met = varargin{1};
	else
		error( 'metric.m: Input argument is not a metric object' );
	end
case 6
		% Providing the frequency value
	   met.name = varargin{1};          % Actual name of the metric
		met.displayName = varargin{2};  	 % Display name of the metric
	   met.needed_data = varargin{3};    % Data needed for this metric
	   met.labels = varargin{4};         % x-, y- and z-labels, title for graphs/plots
	   met.properties = varargin{5};    % Properties used in plotting the graph - linewidth, etc
	   met.frequency = varargin{6};    % Granularity at which the metric is stored
	   met = class( met, 'metric' );
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy\n6 Parameters - Actual name of metric\n\tDisplay name of metric\n\tData needed for this metric\n\tLabels for use in graphs\n\nProperties used in plotting the graph\n\tFrequency at which metric should be stored' );
	disp( error_disp );
	error( 'metric.m: Incorrect number of input arguments' );
end
