function l1_met = nash_l1_metric( varargin )

% Name: nash_l1_metric.m
% Location: MALT/metricClasses/@nash_l1_metric/nash_l1_metric.m
% Purpose:  Constructor for the nash_l1_metric class
%           Gives a percentage of best response at each iteration
% Input Parameters: no Parameters - defaults created
%                   1 Parameter - object to copy
%                              || frequency to store this metric at
% Output Parameters: nash_l1_metric object

switch nargin
case 0 % Create default nash_l1_metric object
	l1_met.name = 'nash_l1_metric';
	% nash_l1_metric inherits from the metric class
	met = metric( 'nash_l1_metric', 'L1-norm measure for Nash convergence (smaller is better)',...
			{'rewards'}, {'xlabel' 'iterations' 'ylabel' 'L1 distance to a Nash equilibrium' 'title' 'Nash convergence as measured by the L1-norm'}, '', 1 );

	l1_met = class( l1_met, 'nash_l1_metric', met );
case 1 % Copy another nash_l1_metric object
	if ( isa( varargin{1}, 'nash_l1_metric' ) )
		l1_met = varargin{1};
	elseif isnumeric( varargin{1} )
		% Want to set the frequency of the metric ourselves
		l1_met.name = 'nash_l1_metric';
		met = metric( 'nash_l1_metric', 'L1-norm measure for Nash convergence (smaller is better)',...
				{'rewards'}, {'xlabel' 'iterations' 'ylabel' 'L1 distance to a Nash equilibrium' 'title' ['Nash convergence as measured by the L1-norm, with frequency ' num2str( varargin{1} )]}, '', varargin{1} );
				
		l1_met = class( l1_met, 'nash_l1_metric', met );
	else
		error( 'nash_l1_metric.m: Input argument is not an nash_l1_metric object or a numeric singleton' );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy OR numeric value representing frequency' );
	disp( error_disp );
	error( 'nash_l1_metric.m: Incorrect number of input arguments' );
end
