function availMetData = run_metric_single( metObj, varargin )

% Name: run_metric_single.m
% Location: MALT/metricClasses/@nash_l1_metric/run_metric_single.m
% Purpose:  Adds the data that this metric requires, from this iteration
% Input Parameters: Metric object, for the metric being run
%                   Variable that is storing the data
%                   Data structure with information from this iteration
%                   First agent object
%                   Second agent object
%                   Number of the game being played
%                   Number of the current run
%                   Number of the current iteration *being saved* ie. relative number
% Output Parameter: Updated variable storing the data

% Make global variable visible
global SessionObject

% Copy parameters to variables
availMetData = varargin{1};
dataStructure = varargin{2};
agnt1 = varargin{3};
agnt2 = varargin{4};
cGame = varargin{5};
cRun = varargin{6};
cIteration = varargin{7};

% Now in the tournament / tournament_cluster files, we set 'gameList' to
% be a vector of games for the current run. Hence, we can just take '{cGame}'

% Get ALL the equilibrium for this game
% and get some size information
allEqa = return_equilibria( cGame, 0 );
nEqm = size( allEqa, 3 );
nActions = size( allEqa, 2 );

% For agent 1 - get into a single matrix form.
allEqaAgnt1 = allEqa( get( agnt1, 'number' ), :, : );
allEqaAgnt1 = reshape( allEqaAgnt1, nActions, nEqm );
allEqaAgnt1 = allEqaAgnt1';
currStrat = returnstrategy( agnt1 );

% Replicate and tile the agent's current strategy, 
% so that we can vectorise the computation
repStrat = repmat( currStrat, size( allEqaAgnt1, 1 ), 1 );

% L1-norm value of the absolute differences between current strategy and all other equilibria
l1Agnt1 = sum( abs( repStrat - allEqaAgnt1 ), 2 );

% Now for agent 2
% For agent 2 - get into a single matrix form.
allEqaAgnt2 = allEqa( get( agnt2, 'number' ), :, : );
allEqaAgnt2 = reshape( allEqaAgnt2, nActions, nEqm );
allEqaAgnt2 = allEqaAgnt2';
currStrat = returnstrategy( agnt2 );

% Replicate and tile the agent's current strategy, 
% so that we can vectorise the computation
repStrat = repmat( currStrat, size( allEqaAgnt2, 1 ), 1 );

% L1-norm value of the absolute differences between current strategy and all other equilibria
l1Agnt2 = sum( abs( repStrat - allEqaAgnt2 ), 2 );

% So what we now store is:
% the minimum total distance from any equilibrium
minDistAway = min( l1Agnt1 + l1Agnt2 );

% Now return the data
availMetData( :, cIteration ) = [ minDistAway; minDistAway ];
