function l2_met = nash_l2_metric( varargin )

% Name: nash_l2_metric.m
% Location: MALT/metricClasses/@nash_l2_metric/nash_l2_metric.m
% Purpose:  Constructor for the nash_l2_metric class
%           Gives a percentage of best response at each iteration
% Input Parameters: no Parameters - defaults created
%                   1 Parameter - object to copy
%                              || frequency to store this metric at
% Output Parameters: nash_l2_metric object

switch nargin
case 0 % Create default nash_l2_metric object
	l2_met.name = 'nash_l2_metric';
	% nash_l2_metric inherits from metric class
	met = metric( 'nash_l2_metric', 'L2-norm measure for Nash convergence (smaller is better)',...
			{'rewards'}, {'xlabel' 'iterations' 'ylabel' 'L2 distance to a Nash equilibrium' 'title' 'Nash convergence as measured by the L2-norm'}, '', 1 );

	l2_met = class( l2_met, 'nash_l2_metric', met );
case 1 % Copy another nash_l2_metric object
	if ( isa( varargin{1}, 'nash_l2_metric' ) )
		l2_met = varargin{1};
	elseif isnumeric( varargin{1} )
		% Want to set the frequency of the metric ourselves
		l2_met.name = 'nash_l2_metric';
		met = metric( 'nash_l2_metric', 'L2-norm measure for Nash convergence (smaller is better)',...
				{'rewards'}, {'xlabel' 'iterations' 'ylabel' 'L2 distance to a Nash equilibrium' 'title' ['Nash convergence as measured by the L2-norm, with frequency ' num2str( varargin{1} )]}, '', varargin{1} );
				
		l2_met = class( l2_met, 'nash_l2_metric', met );
	else
		error( 'nash_l2_metric.m: Input argument is not an nash_l2_metric object or a numeric singleton' );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy OR numeric value representing frequency' );
	disp( error_disp );
	error( 'nash_l2_metric.m: Incorrect number of input arguments' );
end
