function r_met = regret_metric( varargin )

% Name: regret_metric.m
% Location: MALT/metricClasses/@regret_metric/regret_metric.m
% Purpose:  Constructor for the regret_metric class
%           Regret value of an agent in a game
%           This is taken from: Convergence and no-regret in multiagent learning,
%           Michael Bowling. In Advances in Neural Information Processing Systems , 2004
% Input Parameters:  no Parameters - defaults created
%                    1 Parameter - object to copy ||
%                                  frequency to store this metric at
% Output Parameters: regret_metric object

switch nargin
case 0 % Create default regret_metric object
	r_met.name = 'regret_metric';
	% regret_metric inherits from the metric class
	met = metric( 'regret_metric', 'Measure of regret (lower is better)',...
			{'rewards'}, {'xlabel' 'Algorithms' 'ylabel' 'Total regret' 'title' 'Total regret'}, '', 1 );

	% We don't actually set the properties field in @metric,
	% since it isn't needed (at the moment)
	
	r_met = class( r_met, 'regret_metric', met );
case 1 % Copy another regret_metric object
	if ( isa( varargin{1}, 'regret_metric' ) )
		r_met = varargin{1};
	elseif isnumeric( varargin{1} )
		% Want to set the frequency of the metric ourselves
		r_met.name = 'regret_metric';
	   met = metric( 'regret_metric', 'Measure of regret (lower is better)',...
				{'rewards'}, {'xlabel' 'Algorithms' 'ylabel' 'Total regret' 'title' ['Total regret on a frequency of ' num2str( varargin{1} )]}, '', varargin{1} );
		r_met = class( r_met, 'regret_metric', met );
	else
		error( 'regret_metric.m: Input argument is not a regret_metric object or a numeric singleton' );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy OR numeric value representing frequency' );
	disp( error_disp );
	error( 'regret_metric.m: Incorrect number of input arguments' );
end
