function availMetData = run_metric_single( metObj, varargin )

% Name: run_metric_single.m
% Location: MALT/metricClasses/@regret_metric/run_metric_single.m
% Purpose:  Adds the data that this metric requires, from this iteration
% Input Parameters: Metric object, for the metric being run
%                   Variable that is storing the data
%                   Data structure with information from this iteration
%                   First agent object
%                   Second agent object
%                   Number of the game being played
%                   Number of the current run
%                   Number of the current iteration *being saved* ie. relative number
% Output Parameter: Updated variable storing the data

% Make global variable visible
global SessionObject

% Copy parameters to variables
availMetData = varargin{1};
dataStructure = varargin{2};
agnt1 = varargin{3};
agnt2 = varargin{4};
cGame = varargin{5};
cRun = varargin{6};
cIteration = varargin{7};

% Get the set of actions that each agent played
% and the rewards that each agent received
itsActions = dataStructure.actions;
itsRewards = dataStructure.rewards;
itsStrats = dataStructure.strategies;
[nAgnts, nActions] = size( itsStrats );

agnt1Numb = get( agnt1, 'number' );
agnt2Numb = get( agnt2, 'number' );
agnt1Acts = get( agnt1, 'actions' );
agnt2Acts = get( agnt2, 'actions' );

% For the first agent
agnt1Data = availMetData.agent1;
agntStrat = zeros( 2, max( agnt1Acts, agnt2Acts ) );
agntStrat( agnt1Numb, : ) = returnstrategy( agnt1 );
agntStrat( agnt2Numb, : ) = generate_pure( itsActions(2), agnt2Acts );
origStrat = agntStrat;
origValue = value( cGame, origStrat, agnt1Numb );

for cAct = 1:agnt1Acts
	agntStrat( agnt1Numb, : ) = generate_pure( cAct, agnt1Acts );
	newVal = value( cGame, agntStrat, agnt1Numb );
	agnt1Data( 1, cAct ) = agnt1Data( 1, cAct ) + newVal - origValue;
end

% For the second agent
agnt2Data = availMetData.agent2;
agntStrat = zeros( 2, max( agnt1Acts, agnt2Acts ) );
agntStrat( agnt2Numb, : ) = returnstrategy( agnt2 );
agntStrat( agnt1Numb, : ) = generate_pure( itsActions(1), agnt1Acts );
origStrat = agntStrat;
origValue = value( cGame, origStrat, agnt2Numb );

for cAct = 1:agnt2Acts
	agntStrat( agnt2Numb, : ) = generate_pure( cAct, agnt2Acts );
	newVal = value( cGame, agntStrat, agnt2Numb );
	agnt2Data( 1, cAct ) = agnt2Data( 1, cAct ) + newVal - origValue;
end

availMetData = struct( 'agent1', agnt1Data, 'agent2', agnt2Data );
