function r_met = reward_metric( varargin )

% Name: reward_metric.m
% Location: MALT/metricClasses/@reward_metric/reward_metric.m
% Purpose:  Constructor for the reward_metric class
%           Gives a percentage of best response at each iteration
% Input Parameters: no Parameters - defaults created
%                   1 Parameter - object to copy
%                              || frequency to store this metric at
% Output Parameters: reward_metric object

switch nargin
case 0 % Create default reward_metric object
	r_met.name = 'reward_metric';
	% reward_metric inherits from the metric class
	met = metric( 'reward_metric', 'Reward obtained (larger is better)', {'rewards'},...
			{'labelx' 'iterations' 'labely' 'Reward' 'title' 'Rewards obtained'}, '', 1 );

	r_met = class( r_met, 'reward_metric', met );
case 1 % Copy another reward_metric object
	if ( isa( varargin{1}, 'reward_metric' ) )
		r_met = varargin{1};
	elseif isnumeric( varargin{1} )
		% Want to set the frequency of the metric ourselves
		r_met.name = 'reward_metric';
		met = metric( 'reward_metric', 'Reward obtained (larger is better)', {'rewards'},...
				{'labelx' 'iterations' 'labely' 'Reward' 'title' ['Rewards obtained, with frequency ' num2str( varargin{1} )]}, '', 1 );

		r_met = class( r_met, 'reward_metric', met );
	else
		error( 'reward_metric.m: Input argument is not an reward_metric object or a numeric singleton' );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy OR numeric value representing frequency' );
	disp( error_disp );
	error( 'reward_metric.m: Incorrect number of input arguments' );
end
