function stat_met = run_metric( met, dt, rowToFind, runToFind )

% Name: run_metric.m
% Location: MALT/metricClasses/@reward_metric/run_metric.m
% Purpose:	Method to run the metric on the available data
% Input Parameters: Metric object, for the metric being run (reward metric)
%                   Data object
%                   row that we want ( the flip )
%                   run that we want ( the column )
% Output Parameter: statistics_metric object

% Check that we have a metric object and data object being passed as parameters
if ( ~isa( met, 'metric' ) )
	error( '@reward_metric/run_metric.m: First argument should be a metric object' );
end
if ( ~isa( dt, 'data' ) )
	error( '@reward_metric/run_metric.m: Second argument should be a data object' );
end

% Request the wanted data from the data object
% Which call depends on whether averaging or not

allDataNeeded = get( met, 'needed_data' ); % What data is needed by the metric
dataNeeded = allDataNeeded{1};
metFreq = get( met, 'frequency' ); % Get the frequency to run the metric

dtAll = get( dt, 'allData' ); % Takes all the series_data objects from data object
sampleData = dtAll{1, 1}; % Gets us a sample files
nIters = get( sampleData, 'iterations' ); % Gets the number of iterations

% Obtain the data we want from the series_data object
runRewards = obtain_data( dt, runToFind, rowToFind, dataNeeded );

% Create the statistics metric_object and save the data to it
allAlgs = get( dt, 'algList' );
extraLabels = {'gamename' get( dt, 'gamename' )};

% Call the metric_statistics constructor
stat_met = metric_statistics( get( met, 'name' ),...
			  	[get( met, 'labels' ) extraLabels], get( met, 'properties' ),...
			  	{allAlgs{1} allAlgs{2}}, runRewards,...
				'Generated by @reward_metric object' );
