function l2_met = track_l2_metric( varargin )

% Name: track_l2_metric.m
% Location: MALT/metricClasses/@track_l2_metric/track_l2_metric.m
% Purpose:  Constructor for the track_l2_metric class
%           The l2 norm value of the agent's estimate of its opponent's strategy 
%           and the actual strategy of its opponent
%           Lower value means a better estimate
% Input Parameters:  no Parameters - defaults created
%                    1 Parameter - object to copy ||
%                                  frequency to store this metric at
% Output Parameters: track_l2_metric object

switch nargin
case 0 % Create default track_l2_metric object
	l2_met.name = 'track_l2_metric';
	% track_l2_metric inherits from the metric class
	met = metric( 'track_l2_metric', '2-norm on estimating opponent''s strategy',...
			       {'trackbeliefs'}, {'xlabel' 'Algorithms' 'ylabel'...
					 '2-norm value'...
					 'title' '2-norm value between estimated and actual strategy'}, '', 1 );

	% We don't actually set the properties field in @metric,
	% since it isn't needed (at the moment)
	
	l2_met = class( l2_met, 'track_l2_metric', met );
case 1 % Copy another track_l2_metric object
	if ( isa( varargin{1}, 'track_l2_metric' ) )
		l2_met = varargin{1};
	elseif isnumeric( varargin{1} )
		% Want to set the frequency of the metric ourselves
		l2_met.name = 'track_l2_metric';
		met = metric( 'track_l2_metric', '2-norm on estimating opponent''s strategy',...
		  		       {'trackbeliefs'}, {'xlabel' 'Algorithms' 'ylabel'...
						 '2-norm value', 'title'...
						 ['2-norm value between estimated and actual strategy, with frequency' num2str(varargin{1} )]}, '', varargin{1} );

		l2_met = class( l2_met, 'track_l2_metric', met );
	else
		error( 'track_l2_metric.m: Input argument is not a track_l2_metric object or a numeric singleton' );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy OR numeric value representing frequency' );
	disp( error_disp );
	error( 'track_l2_metric.m: Incorrect number of input arguments' );
end
