function availMetData = run_metric_single( metObj, varargin )

% Name: run_metric_single.m
% Location: MALT/metricClasses/@track_linf_action_metric/run_metric_single.m
% Purpose:  Adds the data that this metric requires, from this iteration
% Input Parameters: Metric object, for the metric being run
%                   Variable that is storing the data
%                   Data structure with information from this iteration
%                   First agent object
%                   Second agent object
%                   Number of the game being played
%                   Number of the current run
%                   Number of the current iteration *being saved* ie. relative number
% Output Parameter: Updated variable storing the data

% Make global variable visible
global SessionObject

% Save relevant input parameters to variables
availMetData = varargin{1};
dataStructure = varargin{2};
cIteration = varargin{7};

% Take data
itsEst = dataStructure.trackEst;
itsAct = dataStructure.trackActual;

% pre norm calculation step - determine the differences
preNorm = itsEst - itsAct;
% Then calculate the linf-norm for the two agents on this iteration and save it
% This is the largest absolute value in the preNorm
% ie. the largest difference between the estimated and actual probability of taking any single action

% The next couple of lines is a hack, in order to test equality properly with the precision. Matlab's precision is a bit off, so we calculate these values to the 10th decimal place

multValue = 10^10;
preNorm1 = round( norm( preNorm( 1, : ), inf )*multValue );
preNorm2 = round( norm( preNorm( 2, : ), inf )*multValue );

linfNormAgnt1 = find( preNorm1 == abs(round( preNorm( 1, : )*multValue ) ) );
linfNormAgnt2 = find( preNorm2 == abs(round( preNorm( 2, : )*multValue ) ) );

% Save the data
availMetData(1, cIteration ) = linfNormAgnt1(1);
availMetData(2, cIteration ) = linfNormAgnt2(1);
