function linf_met = track_linf_metric( varargin )

% Name: track_linf_metric.m
% Location: MALT/metricClasses/@track_linf_metric/track_linf_metric.m
% Purpose:  Constructor for the track_linf_metric class
%           The linf norm value of the agent's estimate of its opponent's strategy 
%           and the actual strategy of its opponent
%           Lower value means a better estimate
% Input Parameters:  no Parameters - defaults created
%                    1 Parameter - object to copy ||
%                                  frequency to store this metric at
% Output Parameters: track_linf_metric object

switch nargin
case 0 % Create default track_linf_metric object
	linf_met.name = 'track_linf_metric';
	% track_linf_metric inherits from the metric class
	met = metric( 'track_linf_metric', 'infinity-norm on estimating opponent''s strategy',...
			       {'trackbeliefs'}, {'xlabel' 'Algorithms' 'ylabel'...
					 'infinity-norm value'...
					 'title' 'infinity-norm value between estimated and actual strategy'}, '', 1 );

	% We don't actually set the properties field in @metric,
	% since it isn't needed (at the moment)
	
	linf_met = class( linf_met, 'track_linf_metric', met );
case 1 % Copy another track_linf_metric object
	if ( isa( varargin{1}, 'track_linf_metric' ) )
		linf_met = varargin{1};
	elseif isnumeric( varargin{1} )
		% Want to set the frequency of the metric ourselves
		linf_met.name = 'track_linf_metric';
		met = metric( 'track_linf_metric', 'infinity-norm on estimating opponent''s strategy',...
		  		       {'trackbeliefs'}, {'xlabel' 'Algorithms' 'ylabel'...
						 'infinity-norm value', 'title'...
						 ['infinity-norm value between estimated and actual strategy, with frequency' num2str(varargin{1} )]}, '', varargin{1} );

		linf_met = class( linf_met, 'track_linf_metric', met );
	else
		error( 'track_linf_metric.m: Input argument is not a track_linf_metric object or a numeric singleton' );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy OR numeric value representing frequency' );
	disp( error_disp );
	error( 'track_linf_metric.m: Incorrect number of input arguments' );
end
