function stat_met = run_metric( met, dt, rowToFind, runToFind )

% Name: run_metric.m
% Location: MALT/metricClasses/@wins_metric/run_metric.m
% Purpose:	Method to run the metric on the available data
% Input Parameters: Metric object, for the metric being run
%                   Data object
%                   row that we want ( the flip )
%                   run that we want ( the column )
% Output Parameter: statistics_metric object

% Check that input parameters include metric and data objects
if ( ~isa( met, 'metric' ) )
	error( '@wins_metric/run_metric.m: First argument should be a metric object' );
end
if ( ~isa( dt, 'data' ) )
	error( '@wins_metric/run_metric.m: Second argument should be a data object' );
end

% Request the wanted data from the data object
% Which call depends on whether averaging or not
allDataNeeded = get( met, 'needed_data' ); % What data is needed by the metric
dataNeeded = allDataNeeded{1};
metFreq = get( met, 'frequency' ); % Get the frequency to run the metric

dtAll = get( dt, 'allData' ); % Takes all the series_data objects from data object
sampleData = dtAll{1, 1}; % Gets us a sample files
nIters = get( sampleData, 'iterations' ); % Gets the number of iterations

% Setup counters for the number of wins
winAgnt1 = zeros(1, nIters);
winAgnt2 = zeros(1, nIters);
nAdds = 0;

% Obtain the data we want from the series_data object
runRewards = obtain_data( dt, runToFind, rowToFind, dataNeeded );

% VECTORISED VERSION -- this is about 10x faster than the loop version
%-------------------
equalWins = runRewards(1, : ) == runRewards(2, : );
winAgnt1 = ( runRewards(1, : ) > runRewards( 2, : ) ) + (1/2)*equalWins;
winAgnt2 = ( runRewards(1, : ) < runRewards( 2, : ) ) + (1/2)*equalWins;

% LOOP VERSION
%--------------------
% Now run the metric
%for cIter = 1:metFreq:nIters % Only take the values needed by the frequency
%	if ( runRewards( 1, cIter ) > runRewards( 2, cIter ) )
%		% Agent 1 does better
%		winAgnt1 = winAgnt1 + 1;
%	elseif ( runRewards( 1, cIter ) < runRewards( 2, cIter ) )
%		% Agent 2 does better
%		winAgnt2 = winAgnt2 + 1;
%	else
%		winAgnt1 = winAgnt1 + 0.5;
%		winAgnt2 = winAgnt2 + 0.5;
%	end
%	nAdds = nAdds + 1;
%end % for: cIter;

%winAgnt1 = ( winAgnt1 / nAdds )*100;
%winAgnt2 = ( winAgnt2 / nAdds )*100;

% Create the statistics metric_object and save the relevant data to it
allAlgs = get( dt, 'algList' );
extraLabels = {'gamename' get( dt, 'gamename' )};

stat_met = metric_statistics( get( met, 'name' ),...
			  	[get( met, 'labels' ) extraLabels], get( met, 'properties' ),...
			  	{allAlgs{1} allAlgs{2}}, [winAgnt1; winAgnt2],...
				'Generated by @wins_metric object' );
