function wins_met = wins_metric( varargin )

% Name: wins_metric.m
% Location: MALT/metricClasses/@wins_metric/wins_metric.m
% Purpose:	Constructor for the wins_metric class
%				Counts the number of times that each agent obtained a larger reward than the other agent across all runs, iterations and flips of a game
% Input Parameters:  no Parameters - defaults created
%                    1 Parameter - object to copy ||
%                                  frequency to store this metric at
% Output Parameters: wins_metric object

switch nargin
case 0 % Create default wins_metric object
	wins_met.name = 'wins_metric';
	% wins_metric inherits from the metric class
	met = metric( 'wins_metric', 'Percentage of wins (larger is better)', {'rewards'},...
			{'xlabel' 'Algorithms' 'ylabel' 'Percentage of games won' 'title' 'Percentage of stage games won by each agent'}, '', 1 );

	% We don't actually set the properties field in @metric,
	% since it isn't needed (at the moment)
	
	wins_met = class( wins_met, 'wins_metric', met );
case 1 % Copy another wins_metric object
	if ( isa( varargin{1}, 'wins_metric' ) )
		wins_met = varargin{1};
	elseif isnumeric( varargin{1} )
		% Want to set the frequency of the metric ourselves
		wins_met.name = 'wins_metric';
	   met = metric( 'wins_metric', 'Percentage of wins (larger is better)', {'rewards'},...
				{'xlabel' 'Algorithms' 'ylabel' 'Percentage of games won' 'title' ['Percentage of stage games won by each agent, with frequency ' num2str( varargin{1} )]}, '', varargin{1} ); % This creates a metric with frequency varargin{1}
		wins_met = class( wins_met, 'wins_metric', met );
	else
		error( 'wins_metric.m: Input argument is not a wins_metric object or a numeric singleton' );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults used\n1 Parameter - Object to copy OR numeric value representing frequency' );
	disp( error_disp );
	error( 'wins_metric.m: Incorrect number of input arguments' );
end
