function param = parameter( varargin )

% Name: parameter.m
% Location: MALT/parameterClasses/@parameter/parameter.m
% Purpose:	Constructor for the parameter class
%           Is a single class that desribes an entire session
% Input Parameters: no Parameters - defaults used
%                   1 Parameter -   object to copy
%                   5 Parameters -  Cell list of gamut commands to create games
%                                   Cell list of algorithms used in the testing
%                                   Number of iterations to allow the algorithms to settle
%                                   Number of total iterations
%                                   Number of runs
%                                   Name of the type of session being run
%                                   Cell list of metric names
% Output Parameters: Created parameter object

switch nargin
case 0 % Create default parameter object - has no use, but required by matlab
	param.gamutCommand = {}; % The games' commands to run the game selected
	param.algmList = {}; % No algorithms selected
	param.settle = 0; % Algorithms run for Y iterations to settle into a pattern
	param.totalIterations = 0; % Algorithm run for a total of X iterations, where X-Y is stored
	param.runs = 0; % Number of repetitions per game
	param.sessionType = '';
	param.metricNames = {};
	param = class( param, 'parameter' );
case 1 % Copies the parameter object
	if ( isa(varargin{1}, 'parameter') )
		param = varargin{1};
	else
		error( 'parameter.m: Input argument is not a parameter object' );
	end
case 7
	param.gamutCommand = varargin{1};
	param.algmList = varargin{2};
	param.settle = varargin{3};
	param.totalIterations = varargin{4};
	param.runs = varargin{5};
	param.sessionType = varargin{6};
	param.metricNames = varargin{7};
	param = class( param, 'parameter' );
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - defaults use\n1 Parameter - object to copy\n5 Parameters - Cell list of gamut commands to create games, Cell list of algorithms used in the testing, Number of iterations to allow the algorithms to settle, Number of total iteration, Number of runs, Name of the type of session being run, Cell list of metric names' );
	disp( error_disp );
	error( 'parameter.m: Incorrect number of input arguments' );
end
