function createVisuals( sn, varargin )

% Name: create_statistics.m
% Location: MALT/sessionClasses/@session/createVisuals.m
% Purpose:  Takes in either a filename of a statistics object and runs all of
%           the visuals on the statistics
% Input Parameters:  session object
%                    filename (a string) or a statistics object
% Output Parameters: none

% Save input parameters to variables
inpt = varargin{1};
% Preallocate the cell array
visualsList = {};

% Check that input parameters is a statistics object
if ( isa( inpt, 'statistics' ) ) % Check if the input is a statistics object
	statsObject = inpt;
else	if ( ischar( inpt ) ) % Check if the input is a string - i.e. filename
	statsObject = load( inpt );
		else
			error( 'createVisuals: Unknown input. Expect a statistics object or filename as a string' );
		end
end

allMetrics = get( statsObject, 'metric_stats' ); % Obtain all the metric statistics
nMetricStats = length( allMetrics ); % Determine how many metric statistics there are
for cMetric = 1:nMetricStats
	statMet = allMetrics{cMetric}; % Obtain the current statistic metric
	% Check that the object is a metric_statistic
	if ~( isa( statMet, 'metric_statistics' ) )
		errPrnt = sprintf( '@session/createVisuals.m: Expected a metric_statistics in the list\nFound a %s', class( statMet ) );
		error( errPrnt ); 
	end % Check if statMet is a metric_statistic

	visualsList = get( statMet, 'valid_visuals' ); % Obtain the list of valid visuals
	nVisuals = length( visualsList ); % Obtain the number of valid visuals
	labels = get( statMet, 'labels' ); % Obtain the list of labels for the visuals
	properties = get( statMet, 'properties' ); % Obtain the list of properties
	legends = get( statMet, 'legends' ); % Obtain the list of legends	
	for cVisual = 1:nVisuals
		fHandle = str2func( visualsList{cVisual} ); % This creates a file handle
		% Evaluate the file handle - instantiate a visual object
		visualObj = feval( fHandle, labels, properties, legends )
		
		run_visual( visualObj, statMet ); % Run the visualisation object
	end % for: cVisual

end

