function return_eqm  = return_equilibria( nGame, howmany )

% Name: return_equilibria.m
% Location: MALT/sessionClasses/GlobalFiles/Normal_Form_Games/return_equilibria.m
% Purpose: Returns all or some of the equilibria for a normal form game
%          Does a creation on demand method. 
%          If the parameter has been previously created, then it returns it, else
%          it creates it and then returns it, along with the updated game
% Input Parameters:  Number of game being played
%                    howmany parameters: 1 = first equilibrium, 0 = all equilibria
% Output Parameters: the agent's strategy for the equilibrium 
%                    *optional* the global SessionObject may have been updated

% Make the global variables visible
global SessionObject
global MALT_HOME

% Get the list of games and the specific normal_form_game object
gamesAll = get( SessionObject, 'gameList' );
nfg_gm = gamesAll{nGame};

allEqa = get( nfg_gm, 'eqa' ); % Get the equilibria, possibly empty
needToCreate = 0;

if isempty( allEqa ) % Equilibrium hasn't been previously created
	needToCreate = 1;
	% Find the equilibrium and update the normal form game
	% This calls Gambit to solve for the equilibria
	[nfg_gm, allEqa] = call_gambit_eqm( nfg_gm, [MALT_HOME 'extProgs/' get( nfg_gm, 'fileName' ) '_code.eqm' ] );
end

% Determine what needs to be returned: one equilibrium or all
if ( howmany == 1)
	return_eqm = allEqa( :, :, 1 );
elseif ( howmany == 0 )
	return_eqm = allEqa;
else
	error( '@nfg_game\return_equilibria.m: Request for unknown number of equilibria' );
end

% Update SessionObject, since game has changed.
if ( needToCreate )
	gamesAll(nGame) = {nfg_gm};
	SessionObject = set( SessionObject, 'gameList', gamesAll );
end
