function [stratValue, strat] = return_guaranteed_idr( nGame, agntNumb )

% Name: return_guaranteed_idr.m
% Location: MALT/gameClasses/@nfg_game_idr/return_guaranteed_idr.m
% Purpose:  Returns the guaranteed value and strategy that plays the guaranteed value,
%           in a reduced payoff matrix after iterated dominance removal
% Input Parameters:  number of the game being played (iterated dominance removal)
%                    number of the agent
% Output Parameters: Guaranteed value of the idr game for the agent
%                    and the strategy that plays that guaranteed value
%                    * optional* the global SessionObject might be updated

% Make global variables visible
global SessionObject
global MALT_HOME

% Obtain the game list and the normal_form_game_idr object
gamesAll = get( SessionObject, 'gameList' );
nfg_gm_idr = gamesAll{nGame};

% Get the current value and strategies after IDR,
% these may be empty
allGuaranteedIdr = get( nfg_gm_idr, 'guaranteed_idr' );
allGuaranteedIdrStrat = get( nfg_gm_idr, 'guaranteed_idr_strategies' );
allPayoffsIdr = get( nfg_gm_idr, 'payoffs_idr' );
needToCreate = 0;

if isempty( allGuaranteedIdr ) % Check if the guaranteed payoffs have been generated
	needToCreate = 1;
	if isempty( allPayoffsIdr ) % ie. not created before
		% Call gambit to create the IDR strategies
		nfg_gm_idr = call_gambit_idr( nfg_gm_idr, [MALT_HOME 'extProgs/' get( nfg_gm, 'fileName' ) '.idr'] ); 
	end
	% Do the update on the guaranteed values
	nfg_gm_idr = call_guaranteed_idr( nfg_gm_idr );
	% Get the values and strategies
	allGuaranteedIdr = get( nfg_gm_idr, 'guaranteed_idr' );
	allGuaranteedIdrStrat = get( nfg_gm_idr, 'guaranteed_idr_strategies' );
end

% Determine which agent to return
stratValue = allGuaranteedIdr( agntNumb );
strat = allGuaranteedIdrStrat( agntNumb, : );

% Update the game
gamesAll(nGame) = {nfg_gm_idr};
% Resave it to the SessionObject
SessionObject = set( SessionObject, 'gameList', gamesAll );
