function highest_eqm = return_highest_equilibrium( nGame, whichAgent )

% Name: return_highest_equilibrium.m
% Location: MALT/sessionClasses/GlobalFiles/Normal_Form_Games/return_highest_equilibrium.m
% Purpose: Returns the equilibrium that has the highest payoff for an agent
% Input Parameters:	Number of game being played
%							Number of the agent (used to identify which payoff matrix)
% Output Parameters:	Agent's distribution over actions,
%                    that plays the agent's strategy for that equilibrium
%                    *optional* global SessionObject may be updated

% Make global variables visible
global SessionObject;

needToCreate = 0;
% Obtain all the equilibria
allEqm = return_equilibria( nGame, 0 );

numEqm = size( allEqm, 3 ); % Gives the number of equilibria
valEqm = zeros( 1, numEqm ); % Create a storage for the value of the equilibria

% Run through the list of equilibria and obtain their values for an agent
for runEqm = 1:numEqm
	valEqm( 1, runEqm ) = value( nGame, allEqm(:, :, runEqm), whichAgent );
end

% Determine the payoff with the maximum value
maxValEqm = find( valEqm == max( valEqm ) );
if ( length( maxValEqm ) > 1 )
	maxValEqm = maxValEqm(1);
end

% Get the agent's strategy for this equilibrium
highest_eqmAll = allEqm(:, :, maxValEqm);
highest_eqm = highest_eqmAll( whichAgent, : ); % Return just the agent's distribution

% If we want to return the equilibrium strategy for both agents, then return highest_eqmAll, rather than highest_eqm

