function return_strat = return_idr_strategy( gameNumber, whichAgent )

% Name: return_idr_strategy.m
% Location: MALT/gameClasses/@nfg_game_idr/return_idr_strategy.m
% Purpose: Returns an array where the undominated actions of an agent have,
%          a 1 in the position and dominated actions have a 0
% Input Parameters:  normal form game idr object
% Output Parameters: array of zeros for undominated actions and
%                    *optional* might update the global SessionObject if the nfg is updated

% Make global variables visible
global SessionObject;
global MALT_HOME;

% Get the list of games and the specific normal_form_game_idr object
gamesAll = get( SessionObject, 'gameList' );
nfg_gm_idr = gamesAll{gameNumber};

needToCreate = 0;
% Obtain the undominated strategies
allUndomStrats = get( nfg_gm_idr, 'undominated_strategies' );

% Check if it is empty or has been already created
if ( isempty( allUndomStrats ) )
	% Has not been created before
	needToCreate = 1;
	% Call Gambit to solve for the undominated strategies
	nfg_gm_idr = call_gambit_idr( nfg_gm_idr, [MALT_HOME 'extProgs/' get( nfg_gm_idr, 'fileName' ) '_code.idr'] );

	allUndomStrats = get( nfg_gm_idr, 'undominated_strategies' );
end

% Return the relevant agent's strategy
return_strat = allUndomStrats( whichAgent, : );

% If this needed to be created, then update the normal_form_game_idr object
if ( needToCreate )
	gamesAll( gameNumber ) = {nfg_gm_idr};
	SessionObject = set( SessionObject, 'gameList', gamesAll );
end
