function createStatistics( )

% Name: createStatistics.m
% Location: MALT/sessionClasses/@session/createrStatistics.m
% Purpose:  Takes in a session object. F
%           For all data files, each has all the metrics run on it.
%           For each data file, an equivalent statistic file is produced.
% Input Parameters:  
% Output Parameters: none

% Make global variable visible
global SessionObject
param = get( SessionObject, 'parameter' );
nRuns = get( param, 'runs' );

dtFileList = get( SessionObject, 'fileList' ); % Get the list of saved data files
allMetrics = get( SessionObject, 'metricList' ); % Gets the list the metrics
nFiles = length( dtFileList ); % Get the the number of data objects saved
nMetrics = length( allMetrics ); % Determine the number of metrics

for dtFile = 1:nFiles % Loop over all data files
	dtFileName = dtFileList{ dtFile }; % Get the name of the data file
	% File name creation for the statistics file is a bit of a hack, I suppose...
	statFileName = [dtFileName(1:end-8) 'stat.mat'] % Create the stat file name
	% Create the statistics object. Will have cell array of 2xnRuns
	stats = statistics( 2, nRuns );
	
	% Load the data file
	cDataObj = load_data( dtFileName );

	for cRun = 1:nRuns % Loop over the runs
		% Next create two empty structures for the two flips
		stStruct1 = struct;
		stStruct2 = struct;
		for cMetric = 1:nMetrics % Loop over all the metrics
			cMetricObj = allMetrics{cMetric}; % Gets us the metric
			% Now create the metric statistics for that run and the two flips
			metName = get( cMetricObj, 'name' );
			met_stat1 = run_metric( cMetricObj, cDataObj, 1, cRun );
			met_stat2 = run_metric( cMetricObj, cDataObj, 2, cRun );
			% Now save the two metric statistics into structures,
			% where we can reference the structure by the metric name
			stStruct1 = setfield( stStruct1, metName, met_stat1 );
			stStruct2 = setfield( stStruct2, metName, met_stat2 );
		end % All metrics have run_metric on a specific run number
		
		% Add this to the statistics object
		stats = add_to_statistics( stats, stStruct1, 1, cRun );
		stats = add_to_statistics( stats, stStruct2, 2, cRun );
	end

	% Now save this statistics object
	save( statFileName, 'stats' );
	disp( ['Created statistics file ' statFileName ] );
end
