function stat_met = metric_statistics( varargin )

% Name: metric_statistic.m
% Location: MALT/statisticsClasses/@metric_statistics/metric_statistics.m
% Purpose:  Constructor method for the metric statistics class
%           Stores the results produced by a metrics object
% Input Parameters:	No parameters - defaults used
%                   1 parameter   - copy the object
%                   5 parameters  - name of the metric
%                                 - labels for the plot/visualisation
%                                 - properties of the graph and new values
%                                 - list of algorithm names
%                                 - results generated by the metric
%                   6 parameters  - name of the metric
%                                 - labels for the plot/visualisation
%                                 - properties of the graph and new values
%                                 - list of algorithm names
%                                 - results generated by the metric
%                                 - comments field that can be used
% Output Parameters: Metric statistics object

switch nargin
case 0 % Create default metric statistics object
	stat_met.name = '';
	stat_met.labels = {};
	stat_met.properties = {};
	stat_met.algorithms = {'' ''};
	stat_met.results = [];
	stat_met.comments = '';
	stat_met = class( stat_met, 'metric_statistics' );
case 1 % Copy a metric statistics object
	if ( isa( varargin{1}, 'metric_statistics' ) )
		stat_met = varargin{1};
	else
		error( 'metric_statistics: Input argument is not a metric_statistics object' );
	end
case 5
	stat_met.name = varargin{1};
	stat_met.labels = varargin{2};
	stat_met.properties = varargin{3};
	stat_met.algorithms = varargin{4};
	stat_met.results = varargin{5};
	stat_met.comments = '';
	stat_met = class( stat_met, 'metric_statistics' );
case 6
	stat_met.name = varargin{1};
	stat_met.labels = varargin{2};
	stat_met.properties = varargin{3};
	stat_met.algorithms = varargin{4};
	stat_met.results = varargin{5};
	stat_met.comments = varargin{6};
	stat_met = class( stat_met, 'metric_statistics' );
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo parameters - defaults used\n1 Parameter - Object to copy\n5 Parameters - Name of the metric used,\n\tlabels for the visualisation methods,\n\tcell list of properties of the graph to change and the new values,\n\tcell list of the algorithm names,\n\tresults of the metric\n6 Parameters - Name of the metric used,\n\tlabels for the visualisation methods,\n\tcell list of properties of the graph to change and the new values,\n\tcell list of the algorithm names,\n\t results of the metric' );
	disp( error_disp );
	error( 'metric_statistic.m: Incorrect number of input arguments' );
end
