function barVsl = bar_visual( varargin )

% Name: bar_visual.m
% Location: MALT/visualClasses/@bar_visual/bar_visual.m
% Purpose: Constructor for the bar_visual class
%          Creates a bar_visual object
% Input Parameters:  no Parameters - default created
%                    1 Parameter - Object to copy
%                    3 Parameters - Cell list of labelling for parsing
%                                   Cell list of properties for the graph
%                                   Cell list of legend values for the graph
% Output Parameters: bar_visual object

switch nargin
case 0 % Create default bar_visual object
	barVsl.name = 'bar plot';
	
	% We want to automatically set the extra parameters needed 
	% for the free variables and aggregation methods
	aggregationForAll = 1; % Requires an aggregation method for each non-selected free variable
	aggregationAllowed = {'mean' 'median' 'total'}; % Aggregation methods usable
	errorBarsAllowed = 1; % Able to use error bars with this method
	freeVarsDisallowed = {'iterations'}; % All free variables allowed
	extraFeatures = {}; % No extra features for now
	% bar_visual class inherits from the visual class
	vsl = visual( 'bar plot', {}, {}, {},...
					aggregationForAll, aggregationAllowed, errorBarsAllowed,...
					freeVarsDisallowed, extraFeatures );
	barVsl = class( barVsl, 'bar_visual', vsl );
case 1 % Copy another bar_visual object
	if ( isa( varargin(1), 'bar_visual' ) )
		barVsl = varargin{1};
	else
		error( 'bar_visual.m: Input argument is not a bar_visual object' );
	end
case 3
	barVsl.name = 'bar plot';
	% Now we also want to automatically set the extra parameters 
	% for the free variables and aggregation methods
	aggregationForAll = 1; % All non-selected free variables need to be aggregated
	aggregationAllowed = {'mean', 'median', 'total'}; % Aggregation methods available
	errorBarsAllowed = 1; % Able to use error bars on this method
	freeVarsDisallowed = {'iterations'}; % If one of the selected free variables is iterations, you can't provide a bar graph for each and every iteration
	extraFeatures = {}; % No extra features, for now
	vsl = visual( 'bar plot', varargin{1}, varargin{2}, varargin{3}, aggregationForAll, aggregationAllowed, errorBarsAllowed, freeVarsDisallowed, extraFeatures );
	barVsl = class( barVsl, 'bar_visual', vsl );
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - default created\n1 Parameter - object to copy\n3 Parameters - Cell list of labelling for parsing\n\tCell list of properties for the graph\n\tCell list of legend values for the graph' );
   disp( error_disp );
   error( 'bar_visual.m: Incorrect number of input arguments' );
end % switch: nargin
 
