%function run_visual = run_visual( varargin )
function run_visual( varargin )

% Name: run_visual.m
% Location: MALT/visualClasses/@bar_visual/run_visual.m
% Purpose: Runs the visualisation method bar_visual
%			  Produces graphs and saves them
% Input Parameters:  2 Parameters - Visual object (bar_visual)
%                                   plot_data structure
% Output Parameters: None, produces graph/plot and saves it to a file

% Make the global variables visible
global MALT_HOME
global SESSION_NAME
global STORAGE_DIRECTORY

% Check that all parameters are as expected
if ( nargin ~= 2 )
	error( '@bar_visual/run_visual.m: Expected two input parameters -- visual object and a structure' );
end

if ~( isa( varargin{1}, 'bar_visual' ) )
	error( '@bar_visual/run_visual.m: Expected first parameter to be a visual object' );
end

if ~( isa( varargin{2}, 'struct' ) )
	error( '@bar_visual/run_visual.m: Expected second parameter to be a structure' );
end

% Save the input parameters to variables
barVsl = varargin{1};
plot_dataStruct = varargin{2};

if ( isfield( plot_dataStruct, 'medianData' ) )
	% Using error bars, 'medianData' is included in the structure
	figHandle = figure; % Create a figure for graphing
	hold;

	% Take the median data
	medData = plot_dataStruct.medianData;
	lowData = plot_dataStruct.lowerData;
	uppData = plot_dataStruct.upperData;

	nRows = size( medData, 1 );
	if ( nRows == 1 )
		bar( medData );
	else
		bar([1:nRows], medData )
	end

%	TODO: NEED TO WORK OUT WAY TO HANDLE ERROR BARS HERE
	
else
	% Not using error bars
	pltData = plot_dataStruct.data; % Take data
	figHandle = figure; % Create figure for graphing
	hold;

	nRows = size( pltData, 1 );

	if ( nRows == 1 )
		bar( pltData );
	else
		bar([1:nRows], pltData );
	end
end

% Make the graph changes of labels and such
xl = xlabel( get( barVsl, 'labelX' ) ); % Add the x-axis label
set( xl, {'interpreter' 'FontSize'}, {'none' 15} );
yl = ylabel( get( barVsl, 'labelY' ) ); % Add the y-axis label
set( yl, {'interpreter' 'FontSize'}, {'none' 15} );
tl = title( get( barVsl, 'title' ) ); % Add title of the graph
set( tl, {'interpreter' 'FontSize'}, {'none' 15} );
set( figHandle, get( barVsl, 'propList' ), get( barVsl, 'propValue' ) );
set( gca, get( barVsl, 'gcaTitles' ), get( barVsl, 'gcaLabels' ) );
set( gca, 'FontSize', 15 )
if ( ~isempty( get( barVsl, 'legends' ) ) )
	le = legend( get( barVsl, 'legends' ), 'Location', 'BestOutside' ); % Add the legend
	set( le, 'interpreter', 'none' ); % with no Latex interpreter
end
hold off % Take hold off of the figure
