function bxVsl = boxplot_visual( varargin )

% Name: boxplot_visual.m
% Location: MALT/visualClasses/@boxplot_visual/boxplot_visual.m
% Purpose: Constructor for the boxplot_visual class
%          Creates a boxplot_visual object
% Input Parameters:  no Parameters - default created
%                    1 Parameter -  Object to copy
%                    3 Parameters - Cell list of labelling for parsing
%                                   Cell list of properties for the graph
%                                   Cell list of legend values for the graph
% Output Parameters: boxplot_visual object

switch nargin
case 0 % Create default boxplot_visual object
	bxVsl.name = 'boxplot';

	% We want to automatically set the extra parameters needed 
	% for the free variables and aggregation methods
	aggregationForAll = 0; % Requires an aggregation method for each non-selected free variable
%	aggregationAllowed = {'mean' 'median' 'total'}; % Aggregation methods usable
	aggregationAllowed = {'none'}; % Aggregation methods usable
%	errorBarsAllowed = 1; % Able to use error bars with this method
	errorBarsAllowed = 0; % Able to use error bars with this method
	freeVarsDisallowed = {'iterations'}; % All free variables allowed
	extraFeatures = {}; % No extra features for now
	% boxplot_visual object inherits from the visual object
	vsl = visual( 'boxplot', {}, {}, {},...
					aggregationForAll, aggregationAllowed, errorBarsAllowed,...
					freeVarsDisallowed, extraFeatures );
	bxVsl = class( bxVsl, 'boxplot_visual', vsl );
case 1 % Copy another boxplot_visual object
	if ( isa( varargin(1), 'boxplot_visual' ) )
		bxVsl = varargin{1};
	else
		error( 'boxplot_visual.m: Input argument is not a boxplot_visual object' );
	end
case 3
	bxVsl.name = 'boxplot';
	% Now we also want to automatically set the extra parameters 
	% for the free variables and aggregation methods
	aggregationForAll = 0; % All non-selected free variables need to be aggregated
%	aggregationAllowed = {'mean', 'median', 'total'}; % Aggregation methods available
	aggregationAllowed = {'none'}; % Aggregation methods usable
%	errorBarsAllowed = 1; % Able to use error bars on this method
                         % error bars are part of the plot, so aren't seperate
	errorBarsAllowed = 0; % Since implicit in the metric, don't include it as a seperate option
	freeVarsDisallowed = {'iterations'}; % If one of the selected free variables is iterations, you can't provide a boxplot for each and every iteration
	extraFeatures = {}; % No extra features, for now
	% boxplot_visual object inherits from the visual object
	vsl = visual( 'boxplot', varargin{1}, varargin{2}, varargin{3}, aggregationForAll, aggregationAllowed, errorBarsAllowed, freeVarsDisallowed, extraFeatures );
	bxVsl = class( bxVsl, 'boxplot_visual', vsl );
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - default created\n1 Parameter - object to copy\n3 Parameters - Cell list of labelling for parsing\n\tCell list of properties for the graph\n\tCell list of legend values for the graph' );
   disp( error_disp );
   error( 'boxplot_visual.m: Incorrect number of input arguments' );
end % switch: nargin
