function htVsl = heat_visual( varargin )

% Name: heat_visual
% Location: MALT/visualClasses/@heat_visual/heat_visual.m
% Purpose: Constructor for the heat_visual class
%          Creates a heat_visual object
% Input Parameters:  no Parameters - default created
%                    1 Parameter - Object to copy
%                    4 Parameters - Cell list of labelling for parsing
%                                   Cell list of properties for the graph
%                                   Cell list of legend values for the graph
%                                   1x2 vector of [#rows #cols] in heatMap
% Output Parameters: heat_visual object

switch nargin
case 0 % Create default heat_visual object
	htVsl.heatMap = []; % A place to store all of the heat map values
	htVsl.name = 'heat map';

	% We want to automatically set the extra parameters needed 
	% for the free variables and aggregation methods
	aggregationForAll = 0; % Some non-selected free variables don't require aggregation
	aggregationAllowed = {'mean' 'median' 'none' 'total'}; % Aggregation methods available
	errorBarsAllowed = 0; % No error bars allowed for this visualisation
	freeVarsDisallowed = {}; % All free variables allowed
	extraFeatures = {}; % No extra features for now
	% heat_visual class inherits from the visual class
	vsl = visual( 'heat map', {}, {}, {},...
	      aggregationForAll, aggregationAllowed, errorBarsAllowed,...
			freeVarsDisallowed, extraFeatures );
	htVsl = class( htVsl, 'heat_visual', vsl );
case 1 % Copy another heat_visual object
	if ( isa( varargin(1), 'heat_visual' ) )
		htVsl = varargin{1};
	else
		error( 'heat_visual.m: Input argument is not a heat visual object' );
	end
case 4 % Create a heat visual object
	heatSize = varargin{4};
	if ( length( heatSize ) ~= 2 )
		error( 'heat_visual.m: Expect a 1x2 array containing dimensions of heat map' );
	else
		% Preallocate space for the heatmap
		htVsl.heatMap = zeros( heatSize(1), heatSize(2) ); % 
		
		% We want to automatically set the extra parameters needed 
		% for the free variables and aggregation methods
		aggregationForAll = 0; % Some non-selected free variables don't require aggregation
		aggregationAllowed = {'mean' 'median' 'none' 'total'}; % Aggregation methods available
		errorBarsAllowed = 0; % No error bars allowed for this visualisation
		freeVarsDisallowed = {}; % All free variables allowed
		extraFeatures = {}; % No extra features for now
		% heat_visual class inherits from the visual class
		vsl = visual( 'heat map', varargin{1}, varargin{2}, varargin{3},...
		      aggregationForAll, aggregationAllowed, errorBarsAllowed,...
				freeVarsDisallowed, extraFeatures );
		htVsl = class( htVsl, 'heat_visual', vsl );
	end
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - default created\n1 Parameter - object to copy\n4 Parameters - Cell list of labelling for parsing\n\tCell list of properties for the graph\n\tCell list of legend values for the graph\n\t1x2 vector containing number of rows and number of columns in the heat map' );
	disp( error_disp );
	error( 'heat_visual.m: Incorrect number of input arguments' );
end % switch: narargin
