function [plot_data plVsl] = agg_visual( plVsl, plot_data, condAgg, freeWhere, condFree, val4dFree, metricStatObj, whichOrder, counterArray, errorBarStatus, condIterations, condRuns )

% Name: agg_visual.m
% Location: MALT/visualClasses/@plot_visual/agg_visual.m
% Purpose:  Continually includes new data in the format wanted by the visualisation object
% Input Parameters: 10 Parameters - Visual object (plot_visual)
%                                  Current set of data (that has been previously added to)
%                                  Type of aggregation wanted
%                                  Position of where to save (according to current "value" of the first (and possibly second) free variables
%                                  Names of the free variables
%                                  array containing values corresponding to the dimensions of the 4d matrix that correspond to the free variables
%                                  Metric statistic object
%                                  Order of the agents
%                                  Counter array, with current loop counter for agent1, agent2, game and run
%                                  Error bar status - on (1) or off (0)
%											  Iteration start and to values
%                                  Runs start and to values
%
% Output Parameters: Updated plot_data variable
%                    Visual object = plot visual (possibly updated)

% This plot just uses the data from the first agent - ignores the others
runData = get_results_from_metric_stat( metricStatObj, whichOrder );
if ( size( runData, 2 ) ~= 1 )
   % ie. this is a metric across iterations
	runData = runData( condIterations(1):condIterations(2) ); % restrict to the iterations that are requested
   % If the size == 1, ie. there is a single metric value for each run and per game,
   % then we don't want to do anything
end
	
if find( strcmp( 'iterations', lower( condFree ) ) )
	% ie. iterations is one of the free variables
	% We know data must be a vector or 2d matrix, since won't store 
	% 'iterations' in the 4d matrix

	if ( length( condFree ) == 1 )
		% Only have a single free variable, which is iterations
		plot_data( 1, : ) = plot_data( 1, : ) + runData;
	else
		% Two free variables are selected
		plot_data( freeWhere(2), : ) = plot_data( freeWhere(2), : ) + runData;
	end
else
	% 'iterations' is not one of the free variables
	% need to determine if we are using a 4d array or not
	if ( ndims( plot_data ) == 4 )
		% Note, I could also check the errorbar status or see if the aggMethod,
		% is 'none' and that would suffice - checking the number of dimensions,
		% has the same use

		% This adds the sum of the metric for that instance of the game,
		% to the relevant agent pair, generator and instance
		plot_data( counterArray{1}, counterArray{2}, counterArray{3}, counterArray{4} - condRuns(1) + 1 ) = plot_data( counterArray{1}, counterArray{2}, counterArray{3}, counterArray{4} - condRuns(1) + 1 ) + sum( runData );

	else
		% We aren't using errorbars
		% 'iterations' is also not a free variable, so we are working on
		% a 2d matrix and thus should just add sum( runData ) in

		% July 12 2005: Changes made below
		% If statements below
		% This is to ensure that the freeWhere's point to the correct place
		% This is to ensure that we save the run data into the correct position

		if isequal( lower( condFree{1} ), 'runs' )
			freeWhere(1) = freeWhere(1) - condRuns(1) + 1;
		elseif isequal( lower( condFree{2} ), 'runs' )
			freeWhere(2) = freeWhere(2) - condRuns(1) + 1;
		end
	
		% Again adding the sum of the metric results for this instance,
		% but this time only to a 2d matrix
		plot_data( freeWhere(2), freeWhere(1) ) = plot_data( freeWhere(2), freeWhere(1) ) + sum( runData );			
	end % if: ndims)
end % if: find( 'iterations' )
