function plotVsl = plot_visual( varargin )

% Name: plot_visual.m
% Location: MALT/visualClasses/@plot_visual/plot_visual.m
% Purpose: Constructor for the plot_visual class
%          Creates a plot_visual object
% Input Parameters:  no Parameters - default created
%                    1 Parameter - Cell list of labelling for parsing
%                    3 Parameters - Cell list of labelling for parsing
%                                   Cell list of properties for the graph
%                                   Cell list of legend values for the graph
% Output Parameters: plot_visual object

switch nargin
case 0 % Create default plot_visual object
	plotVsl.name = 'line plot';
	% We want to automatically set the extra parameters needed 
	% for the free variables and aggregation methods
	aggregationForAll = 1; % Requires an aggregation method for each non-selected free variable
	aggregationAllowed = {'mean' 'median' 'total'}; % Aggregation methods usable
	errorBarsAllowed = 1; % Able to use error bars with this method
	freeVarsDisallowed = {}; % All free variables allowed
	extraFeatures = {}; % No extra features for now
	% plot_visual class inherits from the visual class
	vsl = visual( 'line plot', {}, {}, {},...
					aggregationForAll, aggregationAllowed, errorBarsAllowed,...
					freeVarsDisallowed, extraFeatures );
	plotVsl = class( plotVsl, 'plot_visual', vsl );
case 1 % Copy another plot_visual object
	if ( isa( varargin{1}, 'plot_visual' ) )
		plotVsl = varargin{1};
	else
		error( 'plot_visual.m: Input argument is not a plot object' )
	end
case 3 % Create a plot visual object
	plotVsl.name = 'line plot';
	
	% We want to automatically set the extra parameters needed 
	% for the free variables and aggregation methods
	aggregationForAll = 1; % Requires an aggregation method for each non-selected free variable
	aggregationAllowed = {'mean' 'median' 'total'}; % Aggregation methods usable
	errorBarsAllowed = 1; % Able to use error bars with this method
	freeVarsDisallowed = {}; % All free variables allowed
	extraFeatures = {}; % No extra features for now
	% plot_visual class inherits from the visual class
	vsl = visual( 'line plot', varargin{1}, varargin{2}, varargin{3},...
					aggregationForAll, aggregationAllowed, errorBarsAllowed,...
					freeVarsDisallowed, extraFeatures );
	plotVsl = class( plotVsl, 'plot_visual', vsl );
otherwise
   error_disp = sprintf( 'Valid parameters:\nNo Parameters - default created\n1 Parameter - object to copy\n2 Parameters - Cell list of labelling for parsing\n\tCell list of properties for the graph\n\tCell list of legend values for the graph' );
   disp( error_disp );
   error( 'plot_visual.m: Incorrect number of input arguments' );
end % switch: nargin
