function run_visual = run_visual( varargin )

% Name: run_visual.m
% Location: MALT/visualClasses/@plot_visual/run_visual.m
% Purpose: Runs the visualisation method plot_visual
%			  Produces graphs and saves them
% Input Parameters:  2 Parameters - Visual object (plot_visual)
%                                   plot_data structure
% Output Parameters: None, produces graph/plot and saves it to a file

% Make the global variables visible
global MALT_HOME
global SESSION_NAME
global STORAGE_DIRECTORY

% Check that the input parameters are all as expected
if ( nargin ~= 2 )
	error( '@plot_visual/run_visual.m: Expected two input parameters -- visual object and a structure' );
end

if ~( isa( varargin{1}, 'plot_visual' ) )
	error( '@plot_visual/run_visual.m: Expected first parameter to be a visual object' );
end

if ~( isa( varargin{2}, 'struct' ) )
	error( '@plot_visual/run_visual.m: Expected second parameter to be a structure' );
end

% Save the input parameters to variables
ptVsl = varargin{1};
plot_dataStruct = varargin{2};
% Want to make sure each line in the plot is a different colour, with a different symbol and type of line
colourLineup = get_lists( 'colourLineup-line-col' );

if ( isfield( plot_dataStruct, 'medianData' ) )
	% Using error bars, 'medianData' is included in the structure
	figHandle = figure; % Set the figure
	hold; % hold it
	% Retrieve the values of the median, lowe and upper data sets
	medData = plot_dataStruct.medianData;
	lowData = plot_dataStruct.lowerData;
	uppData = plot_dataStruct.upperData;

	pltPoints = [1:size( medData, 2 )];
	for rowPoint = 1:size( medData, 1 )
		% Run the errorbar function with the data
		errorbar( pltPoints, medData( rowPoint, : ), abs( medData( rowPoint, : ) - lowData( rowPoint, : ) ), abs( uppData( rowPoint, : ) - medData( rowPoint, : ) ), colourLineup{ rowPoint } );

	end
	
else
	% Not using error bars
	pltData = plot_dataStruct.data;
	figHandle = figure;
	hold;

	% Plot one line per row
	for runLoop = 1:size( pltData, 1 )
		x = pltData( runLoop, : );
		plot( pltData( runLoop, : ), colourLineup{ runLoop } );
	end
end

textSize = 15;
% Make the visual graph changes
xl = xlabel( get( ptVsl, 'labelX' ) ); % Add the x-axis label
set( xl, {'interpreter' 'FontSize'}, {'none' textSize} );
yl = ylabel( get( ptVsl, 'labelY' ) ); % Add the y-axis label
set( yl, {'interpreter' 'FontSize'}, {'none' textSize} );
tl = title( get( ptVsl, 'title' ) ); % Add title of the graph
set( tl, {'interpreter' 'FontSize'}, {'none' textSize} );
set( figHandle, get( ptVsl, 'propList' ), get( ptVsl, 'propValue' ) );
set( gca, get( ptVsl, 'gcaTitles' ), get( ptVsl, 'gcaLabels' ) );
set( gca, 'FontSize', textSize );
le = legend( get( ptVsl, 'legends' ), 'Location', 'BestOutside' ); % Add the grap
set( le, 'interpreter', 'none' );
hold off % Unhold the graph
