function st3Vsl = scatter3_visual( varargin )

% Name: scatter3_visual.m
% Location: MALT/visualClasses/@scatter3_visual/scatter3_visual.m
% Purpose: Constructor for the scatter3_visual class
%          Creates a scatter3_visual object
% Input Parameters:  no Parameters - default created
%                    1 Parameter - Object to copy
%                    3 Parameters - Cell list of labelling for parsing
%                                   Cell list of properties for the graph
%                                   Cell list of legend values for the graph
% Output Parameters: scatter3_visual object

switch nargin
case 0 % Create default scatter3_visual object
	st3Vsl.name = '3d scatter plot';
	% We want to automatically set the extra parameters needed 
	% for the free variables and aggregation methods
	aggregationForAll = 0; % Some non-selected free variables don't require aggregation
	aggregationAllowed = {'mean' 'median' 'none' 'total'}; % Aggregation methods available
	errorBarsAllowed = 0; % No error bars allowed for this visualisation
	freeVarsDisallowed = {}; % All free variables allowed
	extraFeatures = {}; % No extra features for now
	% scatter3_visual class inherits from the visual class
	vsl = visual( '3d scatter plot', {}, {}, {},...
		      aggregationForAll, aggregationAllowed, errorBarsAllowed,...
				freeVarsDisallowed, extraFeatures );
	st3Vsl = class( st3Vsl, 'scatter3_visual', vsl );
case 1 % Copy another scatter3_visual object
	if ( isa( varargin(1), 'scatter3_visual' ) )
		st3Vsl = varargin{1};
	else
		error( 'scatter3_visual.m: Input argument is not a scatter3 visual object' );
	end
case 3 % Create a scatter3 visual object
	st3Vsl.name = '3d scatter plot';
		
	% We want to automatically set the extra parameters needed 
	% for the free variables and aggregation methods
	aggregationForAll = 0; % Some non-selected free variables don't require aggregation
	aggregationAllowed = {'mean' 'median' 'none' 'total'}; % Aggregation methods available
	errorBarsAllowed = 0; % No error bars allowed for this visualisation
	freeVarsDisallowed = {}; % All free variables allowed
	extraFeatures = {}; % No extra features for now
	% scatter3_visual class inherits from the visual class
	vsl = visual( '3d scatter plot', varargin{1}, varargin{2}, varargin{3},...
		      aggregationForAll, aggregationAllowed, errorBarsAllowed,...
				freeVarsDisallowed, extraFeatures );
	st3Vsl = class( st3Vsl, 'scatter3_visual', vsl );
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - default created\n1 Parameter - object to copy\n3 Parameters - Cell list of labelling for parsing\n\tCell list of properties for the graph\n\tCell list of legend values for the graph' );
	disp( error_disp );
	error( 'scatter3_visual.m: Incorrect number of input arguments' );
end % switch: narargin
