function [plot_data stVsl] = agg_visual( stVsl, plot_data, condAgg, freeWhere, condFree, val4dFree, metricStatObj, whichOrder, counterArray, errorBarStatus, condIterations, condRuns )

% Name: agg_visual.m
% Location: MALT/visualClasses/@scatter_visual/agg_visual.m
% Purpose:  Continually includes new data in the format wanted by the visualisation object
% Input Parameters: 10 Parameters - Visual object (bar_visual)
%                                  Current set of data (that has been previously added to)
%                                  Type of aggregation wanted
%                                  Position of where to save (according to current "value" of the first (and possibly second) free variables
%                                  Names of the free variables
%                                  array containing values corresponding to the dimensions of the 4d matrix that correspond to the free variables
%                                  Metric statistic object
%                                  Order of the agents
%                                  Counter array, with current loop counter for agent1, agent2, game and run
%                                  Error bar status - on (1) or off (0)
%											  Iteration start and to values
%                                  Runs start and to values
%
% Output Parameters: Updated plot_data variable
%                    Visual object = scatter_visual (possibly updated)

% This metric needs data from both agents
% First get the main agent that we want
runDataRequested = get_results_from_metric_stat( metricStatObj, whichOrder );
if ( size( runDataRequested, 2 ) ~= 1 )
   % ie. this is a metric across iterations
	runDataRequested = runDataRequested( condIterations(1):condIterations(2) );
   % If the size == 1, ie. there is a single metric value for each run and per game,
   % then we don't want to do anything
end

if ( length( condFree ) == 1 ) % We have a single free variable selected
	% Get the y-valued data
	yData = plot_data.yData;
	% Sum it up and add it into the 4d matrix in the correct place
	yData( counterArray{1}, counterArray{2}, counterArray{3}, counterArray{4} - condRuns(1) + 1 ) = yData( counterArray{1}, counterArray{2}, counterArray{3}, counterArray{4} - condRuns(1) + 1 ) + sum( runDataRequested );

	% Then we want to set the x-value of the corresponding point to be the current counter value of the free variable. This is given by val4dFree, which has 1st agent = 1, 2nd agent = 2, game = 3, run = 4
	xData = plot_data.xData;
	xData( counterArray{1}, counterArray{2}, counterArray{3}, counterArray{4} - condRuns(1) + 1 ) = counterArray{ val4dFree(1) };
else
	% We have two free variables selected, need the second set of data
	if ( whichOrder == 1 )
		otherVal = 2;
	else
		otherVal = 1;
	end
	runDataExtra = get_results_from_metric_stat( metricStatObj, otherVal );
	% Save the first agent data to the x-plot_data
	% and save the second agent data to the y-plot data
	% Add the sum of the metric values for that instance,
	% to the correct element of the 4d matrix
	xData = plot_data.xData;
	xData( counterArray{1}, counterArray{2}, counterArray{3}, counterArray{4} - condRuns(1) + 1 ) = xData( counterArray{1}, counterArray{2}, counterArray{3}, counterArray{4} - condRuns(1) + 1 ) + sum( runDataRequested );
	yData = plot_data.yData;
	yData( counterArray{1}, counterArray{2}, counterArray{3}, counterArray{4} - condRuns(1) + 1 ) = yData( counterArray{1}, counterArray{2}, counterArray{3}, counterArray{4} - condRuns(1) + 1 ) + sum( runDataExtra );
end

% Return the data values
plot_data.xData = xData;
plot_data.yData = yData;
