function [dataStore stVsl] = plot_data_format( stVsl, freeLengths, freeNames, condFree, aggMethod, errorbarStatus, lengthValues, metricObj )

% Name: plot_data_format.m
% Location: MALT/visualClasses/@scatter_visual/plot_data_format.m
% Purpose:  Creates the data structure where all of the data will be stored,
%           This is the data from a metric, that will be visualised
% Input Parameters:  5 Parameters - scatter visual object
%                                   array of lengths of free variables
%                                   array of labels within each free variable
%                                   names of free variables
%                                   method of aggregation on the non-selected free variables
%                                   array of length values for agents, games, runs
%                                   metric object
% 
% Output Parameters: data store variable, for storing the data
%                    updated scatter visual object

% Preallocate two 4d matrices for storing the data,
% for the x and y values of the points
dataStore1 = zeros( lengthValues{1}, lengthValues{2}, lengthValues{3}, lengthValues{4} );

dataStore2 = zeros( lengthValues{1}, lengthValues{2}, lengthValues{3}, lengthValues{4} );

% Preallocate a structure to hold these two matrices
dataStore = struct( 'xData', {dataStore1}, 'yData', {dataStore2} );

if ( length( condFree ) == 1 )
	% Single free variable selected -- Plot it along x-axis
	% Set some graph values
	stVsl = set( stVsl, 'labelX', condFree{1} );
	stVsl = set( stVsl, 'labelY', get( metricObj, 'displayName' ) );
	cLabelNames = get( stVsl, 'gcaTitles' );
	newLabelNames = { cLabelNames{1:end} 'XTickLabel' 'XTick' };
	stVsl = set( stVsl, 'gcaTitles', newLabelNames );
	cLabels = get( stVsl, 'gcaLabels' );
	newLabels = { cLabels{1:end} freeNames{1} [1:length( freeNames{1} )] };
	stVsl = set( stVsl, 'gcaLabels', newLabels );
else
	% Two free variables selected - now plot their "combined" values

	% Not sure yet, what I will write here...
	% maybe this --
	stVsl = set( stVsl, 'labelX', ['agent 1 ' get( metricObj, 'displayName' )] );
	stVsl = set( stVsl, 'labelY', ['agent 2 ' get( metricObj, 'displayName' )] );
end
