function run_visual( varargin )

% Name: run_visual.m
% Location: MALT/visualClasses/@scatter_visual/run_visual.m
% Purpose: Runs the visualisation method scatter_visual
%			  Produces graphs and saves them
% Input Parameters:  2 Parameters - Visual object (scatter_visual)
%                                   plot_data structure
% Output Parameters: None, produces graph/plot and saves it to a file

% Make all global variables visible
global MALT_HOME
global SESSION_NAME
global STORAGE_DIRECTORY

% Check that the input is the correct objects
if ( nargin ~= 2 )
	error( '@scatter_visual/run_visual.m: Expected two input parameters -- visual object and a structure' );
end

if ~( isa( varargin{1}, 'scatter_visual' ) )
	error( '@scatter_visual/run_visual.m: Expected first parameter to be a visual object' );
end

if ~( isa( varargin{2}, 'struct' ) )
	error( '@scatter_visual/run_visual.m: Expected second parameter to be a structure' );
end

% Copy the input parameters to variables
stVsl = varargin{1};
plot_dataStruct = varargin{2};

% Take the values of the points of the x- and y- axes
xData = plot_dataStruct.xData;
yData = plot_dataStruct.yData;

colourLineup = get_lists( 'colourLineup' );
figHandle = figure;
hold;
% For each instance, produce a scatter plot with the x- and y-points
for runLoop = 1:size( xData, 1 )
	scatter( xData( runLoop, : ), yData( runLoop, : ), colourLineup{runLoop} );

end

% Make the visual graph changes
if ~isempty( get( stVsl, 'legends' ) )
	le = legend( get( stVsl, 'legends' ), 'Location', 'BestOutside' ); % Add the graph legends
	set( le, 'interpreter', 'none' );
end

textSize = 14;
xl = xlabel( get( stVsl, 'labelX' ) ); % Add the x-axis label
set( xl, {'interpreter' 'fontSize'}, {'none' textSize} );
yl = ylabel( get( stVsl, 'labelY' ) ); % Add the y-axis label
set( yl, {'interpreter' 'fontSize'}, {'none' textSize} );
tl = title( get( stVsl, 'title' ) ); % Add title of the graph
set( tl, {'interpreter' 'fontSize'}, {'none' textSize} );
set( figHandle, get( stVsl, 'propList' ), get( stVsl, 'propValue' ) );
set( gca, get( stVsl, 'gcaTitles' ), get( stVsl, 'gcaLabels' ) );
set( gca, 'fontSize', textSize )
hold off; % unhold the graph
