function stVsl = scatter_visual( varargin )

% Name: scatter_visual.m
% Location: MALT/visualClasses/@scatter_visual/scatter_visual.m
% Purpose: Constructor for the scatter_visual class
%          Creates a scatter_visual object
% Input Parameters:  no Parameters - default created
%                    1 Parameter - Object to copy
%                    3 Parameters - Cell list of labelling for parsing
%                                   Cell list of properties for the graph
%                                   Cell list of legend values for the graph
% Output Parameters: scatter_visual object

switch nargin
case 0 % Create default scatter_visual object
	stVsl.name = 'scatter plot';

	% We want to automatically set the extra parameters needed 
	% for the free variables and aggregation methods
	aggregationForAll = 0; % Some non-selected free variables don't require aggregation
	aggregationAllowed = {'none'}; % Aggregation methods available
	errorBarsAllowed = 0; % No error bars allowed for this visualisation
	freeVarsDisallowed = {'iterations'}; % All free variables allowed
	extraFeatures = {}; % No extra features for now
	% scatter_visual class inherits from the visual class
	vsl = visual( 'scatter plot', {}, {}, {},...
		      aggregationForAll, aggregationAllowed, errorBarsAllowed,...
				freeVarsDisallowed, extraFeatures );	
	stVsl = class( stVsl, 'scatter_visual', vsl );
case 1 % Copy another scatter_visual object
	if ( isa( varargin(1), 'scatter_visual' ) )
		stVsl = varargin{1};
	else
		error( 'scatter_visual.m: Input argument is not a scatter visual object' );
	end
case 3 % Create a scatter visual object
	stVsl.name = 'scatter plot';
		
	% We want to automatically set the extra parameters needed 
	% for the free variables and aggregation methods
	aggregationForAll = 0; % Some non-selected free variables don't require aggregation
	aggregationAllowed = {'none'}; % Aggregation methods available
	errorBarsAllowed = 0; % No error bars allowed for this visualisation
	freeVarsDisallowed = {'iterations'}; % All free variables allowed
	extraFeatures = {}; % No extra features for now
	% scatter_visual class inherits from the visual class
	vsl = visual( 'scatter plot', varargin{1}, varargin{2}, varargin{3},...
		      aggregationForAll, aggregationAllowed, errorBarsAllowed,...
				freeVarsDisallowed, extraFeatures );
	stVsl = class( stVsl, 'scatter_visual', vsl );
otherwise
	error_disp = sprintf( 'Valid parameters:\nNo Parameters - default created\n1 Parameter - object to copy\n3 Parameters - Cell list of labelling for parsing\n\tCell list of properties for the graph\n\tCell list of legend values for the graph' );
	disp( error_disp );
	error( 'scatter_visual.m: Incorrect number of input arguments' );
end % switch: narargin
